<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'petó: persona, persona, pell molt clara i pell bastant clara',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'petó: persona, persona, pell molt clara i pell morena',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'petó: persona, persona, pell molt clara i pell fosca',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'petó: persona, persona, pell molt clara i pell molt fosca',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'petó: persona, persona, pell bastant clara i pell molt clara',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'petó: persona, persona, pell bastant clara i pell morena',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'petó: persona, persona, pell bastant clara i pell fosca',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'petó: persona, persona, pell bastant clara i pell molt fosca',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'petó: persona, persona, pell morena i pell molt clara',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'petó: persona, persona, pell morena i pell bastant clara',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'petó: persona, persona, pell morena i pell fosca',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'petó: persona, persona, pell morena i pell molt fosca',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'petó: persona, persona, pell fosca i pell molt clara',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'petó: persona, persona, pell fosca i pell bastant clara',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'petó: persona, persona, pell fosca i pell morena',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'petó: persona, persona, pell fosca i pell molt fosca',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'petó: persona, persona, pell molt fosca i pell molt clara',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'petó: persona, persona, pell molt fosca i pell bastant clara',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'petó: persona, persona, pell molt fosca i pell morena',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'petó: persona, persona, pell molt fosca i pell fosca',
    '👨🏻‍❤‍💋‍👨🏻' => 'petó: home, home i pell molt clara',
    '👨🏻‍❤‍💋‍👨🏼' => 'petó: home, home, pell molt clara i pell bastant clara',
    '👨🏻‍❤‍💋‍👨🏽' => 'petó: home, home, pell molt clara i pell morena',
    '👨🏻‍❤‍💋‍👨🏾' => 'petó: home, home, pell molt clara i pell fosca',
    '👨🏻‍❤‍💋‍👨🏿' => 'petó: home, home, pell molt clara i pell molt fosca',
    '👨🏼‍❤‍💋‍👨🏻' => 'petó: home, home, pell bastant clara i pell molt clara',
    '👨🏼‍❤‍💋‍👨🏼' => 'petó: home, home i pell bastant clara',
    '👨🏼‍❤‍💋‍👨🏽' => 'petó: home, home, pell bastant clara i pell morena',
    '👨🏼‍❤‍💋‍👨🏾' => 'petó: home, home, pell bastant clara i pell fosca',
    '👨🏼‍❤‍💋‍👨🏿' => 'petó: home, home, pell bastant clara i pell molt fosca',
    '👨🏽‍❤‍💋‍👨🏻' => 'petó: home, home, pell morena i pell molt clara',
    '👨🏽‍❤‍💋‍👨🏼' => 'petó: home, home, pell morena i pell bastant clara',
    '👨🏽‍❤‍💋‍👨🏽' => 'petó: home, home i pell morena',
    '👨🏽‍❤‍💋‍👨🏾' => 'petó: home, home, pell morena i pell fosca',
    '👨🏽‍❤‍💋‍👨🏿' => 'petó: home, home, pell morena i pell molt fosca',
    '👨🏾‍❤‍💋‍👨🏻' => 'petó: home, home, pell fosca i pell molt clara',
    '👨🏾‍❤‍💋‍👨🏼' => 'petó: home, home, pell fosca i pell bastant clara',
    '👨🏾‍❤‍💋‍👨🏽' => 'petó: home, home, pell fosca i pell morena',
    '👨🏾‍❤‍💋‍👨🏾' => 'petó: home, home i pell fosca',
    '👨🏾‍❤‍💋‍👨🏿' => 'petó: home, home, pell fosca i pell molt fosca',
    '👨🏿‍❤‍💋‍👨🏻' => 'petó: home, home, pell molt fosca i pell molt clara',
    '👨🏿‍❤‍💋‍👨🏼' => 'petó: home, home, pell molt fosca i pell bastant clara',
    '👨🏿‍❤‍💋‍👨🏽' => 'petó: home, home, pell molt fosca i pell morena',
    '👨🏿‍❤‍💋‍👨🏾' => 'petó: home, home, pell molt fosca i pell fosca',
    '👨🏿‍❤‍💋‍👨🏿' => 'petó: home, home i pell molt fosca',
    '👩🏻‍❤‍💋‍👨🏻' => 'petó: dona, home i pell molt clara',
    '👩🏻‍❤‍💋‍👨🏼' => 'petó: dona, home, pell molt clara i pell bastant clara',
    '👩🏻‍❤‍💋‍👨🏽' => 'petó: dona, home, pell molt clara i pell morena',
    '👩🏻‍❤‍💋‍👨🏾' => 'petó: dona, home, pell molt clara i pell fosca',
    '👩🏻‍❤‍💋‍👨🏿' => 'petó: dona, home, pell molt clara i pell molt fosca',
    '👩🏼‍❤‍💋‍👨🏻' => 'petó: dona, home, pell bastant clara i pell molt clara',
    '👩🏼‍❤‍💋‍👨🏼' => 'petó: dona, home i pell bastant clara',
    '👩🏼‍❤‍💋‍👨🏽' => 'petó: dona, home, pell bastant clara i pell morena',
    '👩🏼‍❤‍💋‍👨🏾' => 'petó: dona, home, pell bastant clara i pell fosca',
    '👩🏼‍❤‍💋‍👨🏿' => 'petó: dona, home, pell bastant clara i pell molt fosca',
    '👩🏽‍❤‍💋‍👨🏻' => 'petó: dona, home, pell morena i pell molt clara',
    '👩🏽‍❤‍💋‍👨🏼' => 'petó: dona, home, pell morena i pell bastant clara',
    '👩🏽‍❤‍💋‍👨🏽' => 'petó: dona, home i pell morena',
    '👩🏽‍❤‍💋‍👨🏾' => 'petó: dona, home, pell morena i pell fosca',
    '👩🏽‍❤‍💋‍👨🏿' => 'petó: dona, home, pell morena i pell molt fosca',
    '👩🏾‍❤‍💋‍👨🏻' => 'petó: dona, home, pell fosca i pell molt clara',
    '👩🏾‍❤‍💋‍👨🏼' => 'petó: dona, home, pell fosca i pell bastant clara',
    '👩🏾‍❤‍💋‍👨🏽' => 'petó: dona, home, pell fosca i pell morena',
    '👩🏾‍❤‍💋‍👨🏾' => 'petó: dona, home i pell fosca',
    '👩🏾‍❤‍💋‍👨🏿' => 'petó: dona, home, pell fosca i pell molt fosca',
    '👩🏿‍❤‍💋‍👨🏻' => 'petó: dona, home, pell molt fosca i pell molt clara',
    '👩🏿‍❤‍💋‍👨🏼' => 'petó: dona, home, pell molt fosca i pell bastant clara',
    '👩🏿‍❤‍💋‍👨🏽' => 'petó: dona, home, pell molt fosca i pell morena',
    '👩🏿‍❤‍💋‍👨🏾' => 'petó: dona, home, pell molt fosca i pell fosca',
    '👩🏿‍❤‍💋‍👨🏿' => 'petó: dona, home i pell molt fosca',
    '👩🏻‍❤‍💋‍👩🏻' => 'petó: dona, dona i pell molt clara',
    '👩🏻‍❤‍💋‍👩🏼' => 'petó: dona, dona, pell molt clara i pell bastant clara',
    '👩🏻‍❤‍💋‍👩🏽' => 'petó: dona, dona, pell molt clara i pell morena',
    '👩🏻‍❤‍💋‍👩🏾' => 'petó: dona, dona, pell molt clara i pell fosca',
    '👩🏻‍❤‍💋‍👩🏿' => 'petó: dona, dona, pell molt clara i pell molt fosca',
    '👩🏼‍❤‍💋‍👩🏻' => 'petó: dona, dona, pell bastant clara i pell molt clara',
    '👩🏼‍❤‍💋‍👩🏼' => 'petó: dona, dona i pell bastant clara',
    '👩🏼‍❤‍💋‍👩🏽' => 'petó: dona, dona, pell bastant clara i pell morena',
    '👩🏼‍❤‍💋‍👩🏾' => 'petó: dona, dona, pell bastant clara i pell fosca',
    '👩🏼‍❤‍💋‍👩🏿' => 'petó: dona, dona, pell bastant clara i pell molt fosca',
    '👩🏽‍❤‍💋‍👩🏻' => 'petó: dona, dona, pell morena i pell molt clara',
    '👩🏽‍❤‍💋‍👩🏼' => 'petó: dona, dona, pell morena i pell bastant clara',
    '👩🏽‍❤‍💋‍👩🏽' => 'petó: dona, dona i pell morena',
    '👩🏽‍❤‍💋‍👩🏾' => 'petó: dona, dona, pell morena i pell fosca',
    '👩🏽‍❤‍💋‍👩🏿' => 'petó: dona, dona, pell morena i pell molt fosca',
    '👩🏾‍❤‍💋‍👩🏻' => 'petó: dona, dona, pell fosca i pell molt clara',
    '👩🏾‍❤‍💋‍👩🏼' => 'petó: dona, dona, pell fosca i pell bastant clara',
    '👩🏾‍❤‍💋‍👩🏽' => 'petó: dona, dona, pell fosca i pell morena',
    '👩🏾‍❤‍💋‍👩🏾' => 'petó: dona, dona i pell fosca',
    '👩🏾‍❤‍💋‍👩🏿' => 'petó: dona, dona, pell fosca i pell molt fosca',
    '👩🏿‍❤‍💋‍👩🏻' => 'petó: dona, dona, pell molt fosca i pell molt clara',
    '👩🏿‍❤‍💋‍👩🏼' => 'petó: dona, dona, pell molt fosca i pell bastant clara',
    '👩🏿‍❤‍💋‍👩🏽' => 'petó: dona, dona, pell molt fosca i pell morena',
    '👩🏿‍❤‍💋‍👩🏾' => 'petó: dona, dona, pell molt fosca i pell fosca',
    '👩🏿‍❤‍💋‍👩🏿' => 'petó: dona, dona i pell molt fosca',
    '🧑🏻‍🫯‍🧑🏼' => 'persones que lluiten: pell molt clara i pell bastant clara',
    '🧑🏻‍🫯‍🧑🏽' => 'persones que lluiten: pell molt clara i pell morena',
    '🧑🏻‍🫯‍🧑🏾' => 'persones que lluiten: pell molt clara i pell fosca',
    '🧑🏻‍🫯‍🧑🏿' => 'persones que lluiten: pell molt clara i pell molt fosca',
    '🧑🏼‍🫯‍🧑🏻' => 'persones que lluiten: pell bastant clara i pell molt clara',
    '🧑🏼‍🫯‍🧑🏽' => 'persones que lluiten: pell bastant clara i pell morena',
    '🧑🏼‍🫯‍🧑🏾' => 'persones que lluiten: pell bastant clara i pell fosca',
    '🧑🏼‍🫯‍🧑🏿' => 'persones que lluiten: pell bastant clara i pell molt fosca',
    '🧑🏽‍🫯‍🧑🏻' => 'persones que lluiten: pell morena i pell molt clara',
    '🧑🏽‍🫯‍🧑🏼' => 'persones que lluiten: pell morena i pell bastant clara',
    '🧑🏽‍🫯‍🧑🏾' => 'persones que lluiten: pell morena i pell fosca',
    '🧑🏽‍🫯‍🧑🏿' => 'persones que lluiten: pell morena i pell molt fosca',
    '🧑🏾‍🫯‍🧑🏻' => 'persones que lluiten: pell fosca i pell molt clara',
    '🧑🏾‍🫯‍🧑🏼' => 'persones que lluiten: pell fosca i pell bastant clara',
    '🧑🏾‍🫯‍🧑🏽' => 'persones que lluiten: pell fosca i pell morena',
    '🧑🏾‍🫯‍🧑🏿' => 'persones que lluiten: pell fosca i pell molt fosca',
    '🧑🏿‍🫯‍🧑🏻' => 'persones que lluiten: pell molt fosca i pell molt clara',
    '🧑🏿‍🫯‍🧑🏼' => 'persones que lluiten: pell molt fosca i pell bastant clara',
    '🧑🏿‍🫯‍🧑🏽' => 'persones que lluiten: pell molt fosca i pell morena',
    '🧑🏿‍🫯‍🧑🏾' => 'persones que lluiten: pell molt fosca i pell fosca',
    '🧑🏻‍❤‍🧑🏼' => 'parella amb un cor: persona, persona, pell molt clara i pell bastant clara',
    '🧑🏻‍❤‍🧑🏽' => 'parella amb un cor: persona, persona, pell molt clara i pell morena',
    '🧑🏻‍❤‍🧑🏾' => 'parella amb un cor: persona, persona, pell molt clara i pell fosca',
    '🧑🏻‍❤‍🧑🏿' => 'parella amb un cor: persona, persona, pell molt clara i pell molt fosca',
    '🧑🏼‍❤‍🧑🏻' => 'parella amb un cor: persona, persona, pell bastant clara i pell molt clara',
    '🧑🏼‍❤‍🧑🏽' => 'parella amb un cor: persona, persona, pell bastant clara i pell morena',
    '🧑🏼‍❤‍🧑🏾' => 'parella amb un cor: persona, persona, pell bastant clara i pell fosca',
    '🧑🏼‍❤‍🧑🏿' => 'parella amb un cor: persona, persona, pell bastant clara i pell molt fosca',
    '🧑🏽‍❤‍🧑🏻' => 'parella amb un cor: persona, persona, pell morena i pell molt clara',
    '🧑🏽‍❤‍🧑🏼' => 'parella amb un cor: persona, persona, pell morena i pell bastant clara',
    '🧑🏽‍❤‍🧑🏾' => 'parella amb un cor: persona, persona, pell morena i pell fosca',
    '🧑🏽‍❤‍🧑🏿' => 'parella amb un cor: persona, persona, pell morena i pell molt fosca',
    '🧑🏾‍❤‍🧑🏻' => 'parella amb un cor: persona, persona, pell fosca i pell molt clara',
    '🧑🏾‍❤‍🧑🏼' => 'parella amb un cor: persona, persona, pell fosca i pell bastant clara',
    '🧑🏾‍❤‍🧑🏽' => 'parella amb un cor: persona, persona, pell fosca i pell morena',
    '🧑🏾‍❤‍🧑🏿' => 'parella amb un cor: persona, persona, pell fosca i pell molt fosca',
    '🧑🏿‍❤‍🧑🏻' => 'parella amb un cor: persona, persona, pell molt fosca i pell molt clara',
    '🧑🏿‍❤‍🧑🏼' => 'parella amb un cor: persona, persona, pell molt fosca i pell bastant clara',
    '🧑🏿‍❤‍🧑🏽' => 'parella amb un cor: persona, persona, pell molt fosca i pell morena',
    '🧑🏿‍❤‍🧑🏾' => 'parella amb un cor: persona, persona, pell molt fosca i pell fosca',
    '🧑🏻‍🐰‍🧑🏼' => 'persones que ballen disfressades: pell molt clara i pell bastant clara',
    '🧑🏻‍🐰‍🧑🏽' => 'persones que ballen disfressades: pell molt clara i pell morena',
    '🧑🏻‍🐰‍🧑🏾' => 'persones que ballen disfressades: pell molt clara i pell fosca',
    '🧑🏻‍🐰‍🧑🏿' => 'persones que ballen disfressades: pell molt clara i pell molt fosca',
    '🧑🏼‍🐰‍🧑🏻' => 'persones que ballen disfressades: pell bastant clara i pell molt clara',
    '🧑🏼‍🐰‍🧑🏽' => 'persones que ballen disfressades: pell bastant clara i pell morena',
    '🧑🏼‍🐰‍🧑🏾' => 'persones que ballen disfressades: pell bastant clara i pell fosca',
    '🧑🏼‍🐰‍🧑🏿' => 'persones que ballen disfressades: pell bastant clara i pell molt fosca',
    '🧑🏽‍🐰‍🧑🏻' => 'persones que ballen disfressades: pell morena i pell molt clara',
    '🧑🏽‍🐰‍🧑🏼' => 'persones que ballen disfressades: pell morena i pell bastant clara',
    '🧑🏽‍🐰‍🧑🏾' => 'persones que ballen disfressades: pell morena i pell fosca',
    '🧑🏽‍🐰‍🧑🏿' => 'persones que ballen disfressades: pell morena i pell molt fosca',
    '🧑🏾‍🐰‍🧑🏻' => 'persones que ballen disfressades: pell fosca i pell molt clara',
    '🧑🏾‍🐰‍🧑🏼' => 'persones que ballen disfressades: pell fosca i pell bastant clara',
    '🧑🏾‍🐰‍🧑🏽' => 'persones que ballen disfressades: pell fosca i pell morena',
    '🧑🏾‍🐰‍🧑🏿' => 'persones que ballen disfressades: pell fosca i pell molt fosca',
    '🧑🏿‍🐰‍🧑🏻' => 'persones que ballen disfressades: pell molt fosca i pell molt clara',
    '🧑🏿‍🐰‍🧑🏼' => 'persones que ballen disfressades: pell molt fosca i pell bastant clara',
    '🧑🏿‍🐰‍🧑🏽' => 'persones que ballen disfressades: pell molt fosca i pell morena',
    '🧑🏿‍🐰‍🧑🏾' => 'persones que ballen disfressades: pell molt fosca i pell fosca',
    '👨🏻‍🫯‍👨🏼' => 'jugadors de lluita: pell molt clara i pell bastant clara',
    '👨🏻‍🫯‍👨🏽' => 'jugadors de lluita: pell molt clara i pell morena',
    '👨🏻‍🫯‍👨🏾' => 'jugadors de lluita: pell molt clara i pell fosca',
    '👨🏻‍🫯‍👨🏿' => 'jugadors de lluita: pell molt clara i pell molt fosca',
    '👨🏼‍🫯‍👨🏻' => 'jugadors de lluita: pell bastant clara i pell molt clara',
    '👨🏼‍🫯‍👨🏽' => 'jugadors de lluita: pell bastant clara i pell morena',
    '👨🏼‍🫯‍👨🏾' => 'jugadors de lluita: pell bastant clara i pell fosca',
    '👨🏼‍🫯‍👨🏿' => 'jugadors de lluita: pell bastant clara i pell molt fosca',
    '👨🏽‍🫯‍👨🏻' => 'jugadors de lluita: pell morena i pell molt clara',
    '👨🏽‍🫯‍👨🏼' => 'jugadors de lluita: pell morena i pell bastant clara',
    '👨🏽‍🫯‍👨🏾' => 'jugadors de lluita: pell morena i pell fosca',
    '👨🏽‍🫯‍👨🏿' => 'jugadors de lluita: pell morena i pell molt fosca',
    '👨🏾‍🫯‍👨🏻' => 'jugadors de lluita: pell fosca i pell molt clara',
    '👨🏾‍🫯‍👨🏼' => 'jugadors de lluita: pell fosca i pell bastant clara',
    '👨🏾‍🫯‍👨🏽' => 'jugadors de lluita: pell fosca i pell morena',
    '👨🏾‍🫯‍👨🏿' => 'jugadors de lluita: pell fosca i pell molt fosca',
    '👨🏿‍🫯‍👨🏻' => 'jugadors de lluita: pell molt fosca i pell molt clara',
    '👨🏿‍🫯‍👨🏼' => 'jugadors de lluita: pell molt fosca i pell bastant clara',
    '👨🏿‍🫯‍👨🏽' => 'jugadors de lluita: pell molt fosca i pell morena',
    '👨🏿‍🫯‍👨🏾' => 'jugadors de lluita: pell molt fosca i pell fosca',
    '👨🏻‍❤‍👨🏻' => 'parella amb un cor: home, home i pell molt clara',
    '👨🏻‍❤‍👨🏼' => 'parella amb un cor: home, home, pell molt clara i pell bastant clara',
    '👨🏻‍❤‍👨🏽' => 'parella amb un cor: home, home, pell molt clara i pell morena',
    '👨🏻‍❤‍👨🏾' => 'parella amb un cor: home, home, pell molt clara i pell fosca',
    '👨🏻‍❤‍👨🏿' => 'parella amb un cor: home, home, pell molt clara i pell molt fosca',
    '👨🏼‍❤‍👨🏻' => 'parella amb un cor: home, home, pell bastant clara i pell molt clara',
    '👨🏼‍❤‍👨🏼' => 'parella amb un cor: home, home i pell bastant clara',
    '👨🏼‍❤‍👨🏽' => 'parella amb un cor: home, home, pell bastant clara i pell morena',
    '👨🏼‍❤‍👨🏾' => 'parella amb un cor: home, home, pell bastant clara i pell fosca',
    '👨🏼‍❤‍👨🏿' => 'parella amb un cor: home, home, pell bastant clara i pell molt fosca',
    '👨🏽‍❤‍👨🏻' => 'parella amb un cor: home, home, pell morena i pell molt clara',
    '👨🏽‍❤‍👨🏼' => 'parella amb un cor: home, home, pell morena i pell bastant clara',
    '👨🏽‍❤‍👨🏽' => 'parella amb un cor: home, home i pell morena',
    '👨🏽‍❤‍👨🏾' => 'parella amb un cor: home, home, pell morena i pell fosca',
    '👨🏽‍❤‍👨🏿' => 'parella amb un cor: home, home, pell morena i pell molt fosca',
    '👨🏾‍❤‍👨🏻' => 'parella amb un cor: home, home, pell fosca i pell molt clara',
    '👨🏾‍❤‍👨🏼' => 'parella amb un cor: home, home, pell fosca i pell bastant clara',
    '👨🏾‍❤‍👨🏽' => 'parella amb un cor: home, home, pell fosca i pell morena',
    '👨🏾‍❤‍👨🏾' => 'parella amb un cor: home, home i pell fosca',
    '👨🏾‍❤‍👨🏿' => 'parella amb un cor: home, home, pell fosca i pell molt fosca',
    '👨🏿‍❤‍👨🏻' => 'parella amb un cor: home, home, pell molt fosca i pell molt clara',
    '👨🏿‍❤‍👨🏼' => 'parella amb un cor: home, home, pell molt fosca i pell bastant clara',
    '👨🏿‍❤‍👨🏽' => 'parella amb un cor: home, home, pell molt fosca i pell morena',
    '👨🏿‍❤‍👨🏾' => 'parella amb un cor: home, home, pell molt fosca i pell fosca',
    '👨🏿‍❤‍👨🏿' => 'parella amb un cor: home, home i pell molt fosca',
    '👨🏻‍🐰‍👨🏼' => 'homes que ballen disfressats: pell molt clara i pell bastant clara',
    '👨🏻‍🐰‍👨🏽' => 'homes que ballen disfressats: pell molt clara i pell morena',
    '👨🏻‍🐰‍👨🏾' => 'homes que ballen disfressats: pell molt clara i pell fosca',
    '👨🏻‍🐰‍👨🏿' => 'homes que ballen disfressats: pell molt clara i pell molt fosca',
    '👨🏼‍🐰‍👨🏻' => 'homes que ballen disfressats: pell bastant clara i pell molt clara',
    '👨🏼‍🐰‍👨🏽' => 'homes que ballen disfressats: pell bastant clara i pell morena',
    '👨🏼‍🐰‍👨🏾' => 'homes que ballen disfressats: pell bastant clara i pell fosca',
    '👨🏼‍🐰‍👨🏿' => 'homes que ballen disfressats: pell bastant clara i pell molt fosca',
    '👨🏽‍🐰‍👨🏻' => 'homes que ballen disfressats: pell morena i pell molt clara',
    '👨🏽‍🐰‍👨🏼' => 'homes que ballen disfressats: pell morena i pell bastant clara',
    '👨🏽‍🐰‍👨🏾' => 'homes que ballen disfressats: pell morena i pell fosca',
    '👨🏽‍🐰‍👨🏿' => 'homes que ballen disfressats: pell morena i pell molt fosca',
    '👨🏾‍🐰‍👨🏻' => 'homes que ballen disfressats: pell fosca i pell molt clara',
    '👨🏾‍🐰‍👨🏼' => 'homes que ballen disfressats: pell fosca i pell bastant clara',
    '👨🏾‍🐰‍👨🏽' => 'homes que ballen disfressats: pell fosca i pell morena',
    '👨🏾‍🐰‍👨🏿' => 'homes que ballen disfressats: pell fosca i pell molt fosca',
    '👨🏿‍🐰‍👨🏻' => 'homes que ballen disfressats: pell molt fosca i pell molt clara',
    '👨🏿‍🐰‍👨🏼' => 'homes que ballen disfressats: pell molt fosca i pell bastant clara',
    '👨🏿‍🐰‍👨🏽' => 'homes que ballen disfressats: pell molt fosca i pell morena',
    '👨🏿‍🐰‍👨🏾' => 'homes que ballen disfressats: pell molt fosca i pell fosca',
    '👩🏻‍🫯‍👩🏼' => 'jugadores de lluita: pell molt clara i pell bastant clara',
    '👩🏻‍🫯‍👩🏽' => 'jugadores de lluita: pell molt clara i pell morena',
    '👩🏻‍🫯‍👩🏾' => 'jugadores de lluita: pell molt clara i pell fosca',
    '👩🏻‍🫯‍👩🏿' => 'jugadores de lluita: pell molt clara i pell molt fosca',
    '👩🏼‍🫯‍👩🏻' => 'jugadores de lluita: pell bastant clara i pell molt clara',
    '👩🏼‍🫯‍👩🏽' => 'jugadores de lluita: pell bastant clara i pell morena',
    '👩🏼‍🫯‍👩🏾' => 'jugadores de lluita: pell bastant clara i pell fosca',
    '👩🏼‍🫯‍👩🏿' => 'jugadores de lluita: pell bastant clara i pell molt fosca',
    '👩🏽‍🫯‍👩🏻' => 'jugadores de lluita: pell morena i pell molt clara',
    '👩🏽‍🫯‍👩🏼' => 'jugadores de lluita: pell morena i pell bastant clara',
    '👩🏽‍🫯‍👩🏾' => 'jugadores de lluita: pell morena i pell fosca',
    '👩🏽‍🫯‍👩🏿' => 'jugadores de lluita: pell morena i pell molt fosca',
    '👩🏾‍🫯‍👩🏻' => 'jugadores de lluita: pell fosca i pell molt clara',
    '👩🏾‍🫯‍👩🏼' => 'jugadores de lluita: pell fosca i pell bastant clara',
    '👩🏾‍🫯‍👩🏽' => 'jugadores de lluita: pell fosca i pell morena',
    '👩🏾‍🫯‍👩🏿' => 'jugadores de lluita: pell fosca i pell molt fosca',
    '👩🏿‍🫯‍👩🏻' => 'jugadores de lluita: pell molt fosca i pell molt clara',
    '👩🏿‍🫯‍👩🏼' => 'jugadores de lluita: pell molt fosca i pell bastant clara',
    '👩🏿‍🫯‍👩🏽' => 'jugadores de lluita: pell molt fosca i pell morena',
    '👩🏿‍🫯‍👩🏾' => 'jugadores de lluita: pell molt fosca i pell fosca',
    '👩🏻‍❤‍👨🏻' => 'parella amb un cor: dona, home i pell molt clara',
    '👩🏻‍❤‍👨🏼' => 'parella amb un cor: dona, home, pell molt clara i pell bastant clara',
    '👩🏻‍❤‍👨🏽' => 'parella amb un cor: dona, home, pell molt clara i pell morena',
    '👩🏻‍❤‍👨🏾' => 'parella amb un cor: dona, home, pell molt clara i pell fosca',
    '👩🏻‍❤‍👨🏿' => 'parella amb un cor: dona, home, pell molt clara i pell molt fosca',
    '👩🏼‍❤‍👨🏻' => 'parella amb un cor: dona, home, pell bastant clara i pell molt clara',
    '👩🏼‍❤‍👨🏼' => 'parella amb un cor: dona, home i pell bastant clara',
    '👩🏼‍❤‍👨🏽' => 'parella amb un cor: dona, home, pell bastant clara i pell morena',
    '👩🏼‍❤‍👨🏾' => 'parella amb un cor: dona, home, pell bastant clara i pell fosca',
    '👩🏼‍❤‍👨🏿' => 'parella amb un cor: dona, home, pell bastant clara i pell molt fosca',
    '👩🏽‍❤‍👨🏻' => 'parella amb un cor: dona, home, pell morena i pell molt clara',
    '👩🏽‍❤‍👨🏼' => 'parella amb un cor: dona, home, pell morena i pell bastant clara',
    '👩🏽‍❤‍👨🏽' => 'parella amb un cor: dona, home i pell morena',
    '👩🏽‍❤‍👨🏾' => 'parella amb un cor: dona, home, pell morena i pell fosca',
    '👩🏽‍❤‍👨🏿' => 'parella amb un cor: dona, home, pell morena i pell molt fosca',
    '👩🏾‍❤‍👨🏻' => 'parella amb un cor: dona, home, pell fosca i pell molt clara',
    '👩🏾‍❤‍👨🏼' => 'parella amb un cor: dona, home, pell fosca i pell bastant clara',
    '👩🏾‍❤‍👨🏽' => 'parella amb un cor: dona, home, pell fosca i pell morena',
    '👩🏾‍❤‍👨🏾' => 'parella amb un cor: dona, home i pell fosca',
    '👩🏾‍❤‍👨🏿' => 'parella amb un cor: dona, home, pell fosca i pell molt fosca',
    '👩🏿‍❤‍👨🏻' => 'parella amb un cor: dona, home, pell molt fosca i pell molt clara',
    '👩🏿‍❤‍👨🏼' => 'parella amb un cor: dona, home, pell molt fosca i pell bastant clara',
    '👩🏿‍❤‍👨🏽' => 'parella amb un cor: dona, home, pell molt fosca i pell morena',
    '👩🏿‍❤‍👨🏾' => 'parella amb un cor: dona, home, pell molt fosca i pell fosca',
    '👩🏿‍❤‍👨🏿' => 'parella amb un cor: dona, home i pell molt fosca',
    '👩🏻‍❤‍👩🏻' => 'parella amb un cor: dona, dona i pell molt clara',
    '👩🏻‍❤‍👩🏼' => 'parella amb un cor: dona, dona, pell molt clara i pell bastant clara',
    '👩🏻‍❤‍👩🏽' => 'parella amb un cor: dona, dona, pell molt clara i pell morena',
    '👩🏻‍❤‍👩🏾' => 'parella amb un cor: dona, dona, pell molt clara i pell fosca',
    '👩🏻‍❤‍👩🏿' => 'parella amb un cor: dona, dona, pell molt clara i pell molt fosca',
    '👩🏼‍❤‍👩🏻' => 'parella amb un cor: dona, dona, pell bastant clara i pell molt clara',
    '👩🏼‍❤‍👩🏼' => 'parella amb un cor: dona, dona i pell bastant clara',
    '👩🏼‍❤‍👩🏽' => 'parella amb un cor: dona, dona, pell bastant clara i pell morena',
    '👩🏼‍❤‍👩🏾' => 'parella amb un cor: dona, dona, pell bastant clara i pell fosca',
    '👩🏼‍❤‍👩🏿' => 'parella amb un cor: dona, dona, pell bastant clara i pell molt fosca',
    '👩🏽‍❤‍👩🏻' => 'parella amb un cor: dona, dona, pell morena i pell molt clara',
    '👩🏽‍❤‍👩🏼' => 'parella amb un cor: dona, dona, pell morena i pell bastant clara',
    '👩🏽‍❤‍👩🏽' => 'parella amb un cor: dona, dona i pell morena',
    '👩🏽‍❤‍👩🏾' => 'parella amb un cor: dona, dona, pell morena i pell fosca',
    '👩🏽‍❤‍👩🏿' => 'parella amb un cor: dona, dona, pell morena i pell molt fosca',
    '👩🏾‍❤‍👩🏻' => 'parella amb un cor: dona, dona, pell fosca i pell molt clara',
    '👩🏾‍❤‍👩🏼' => 'parella amb un cor: dona, dona, pell fosca i pell bastant clara',
    '👩🏾‍❤‍👩🏽' => 'parella amb un cor: dona, dona, pell fosca i pell morena',
    '👩🏾‍❤‍👩🏾' => 'parella amb un cor: dona, dona i pell fosca',
    '👩🏾‍❤‍👩🏿' => 'parella amb un cor: dona, dona, pell fosca i pell molt fosca',
    '👩🏿‍❤‍👩🏻' => 'parella amb un cor: dona, dona, pell molt fosca i pell molt clara',
    '👩🏿‍❤‍👩🏼' => 'parella amb un cor: dona, dona, pell molt fosca i pell bastant clara',
    '👩🏿‍❤‍👩🏽' => 'parella amb un cor: dona, dona, pell molt fosca i pell morena',
    '👩🏿‍❤‍👩🏾' => 'parella amb un cor: dona, dona, pell molt fosca i pell fosca',
    '👩🏿‍❤‍👩🏿' => 'parella amb un cor: dona, dona i pell molt fosca',
    '👩🏻‍🐰‍👩🏼' => 'dones que ballen disfressades: pell molt clara i pell bastant clara',
    '👩🏻‍🐰‍👩🏽' => 'dones que ballen disfressades: pell molt clara i pell morena',
    '👩🏻‍🐰‍👩🏾' => 'dones que ballen disfressades: pell molt clara i pell fosca',
    '👩🏻‍🐰‍👩🏿' => 'dones que ballen disfressades: pell molt clara i pell molt fosca',
    '👩🏼‍🐰‍👩🏻' => 'dones que ballen disfressades: pell bastant clara i pell molt clara',
    '👩🏼‍🐰‍👩🏽' => 'dones que ballen disfressades: pell bastant clara i pell morena',
    '👩🏼‍🐰‍👩🏾' => 'dones que ballen disfressades: pell bastant clara i pell fosca',
    '👩🏼‍🐰‍👩🏿' => 'dones que ballen disfressades: pell bastant clara i pell molt fosca',
    '👩🏽‍🐰‍👩🏻' => 'dones que ballen disfressades: pell morena i pell molt clara',
    '👩🏽‍🐰‍👩🏼' => 'dones que ballen disfressades: pell morena i pell bastant clara',
    '👩🏽‍🐰‍👩🏾' => 'dones que ballen disfressades: pell morena i pell fosca',
    '👩🏽‍🐰‍👩🏿' => 'dones que ballen disfressades: pell morena i pell molt fosca',
    '👩🏾‍🐰‍👩🏻' => 'dones que ballen disfressades: pell fosca i pell molt clara',
    '👩🏾‍🐰‍👩🏼' => 'dones que ballen disfressades: pell fosca i pell bastant clara',
    '👩🏾‍🐰‍👩🏽' => 'dones que ballen disfressades: pell fosca i pell morena',
    '👩🏾‍🐰‍👩🏿' => 'dones que ballen disfressades: pell fosca i pell molt fosca',
    '👩🏿‍🐰‍👩🏻' => 'dones que ballen disfressades: pell molt fosca i pell molt clara',
    '👩🏿‍🐰‍👩🏼' => 'dones que ballen disfressades: pell molt fosca i pell bastant clara',
    '👩🏿‍🐰‍👩🏽' => 'dones que ballen disfressades: pell molt fosca i pell morena',
    '👩🏿‍🐰‍👩🏾' => 'dones que ballen disfressades: pell molt fosca i pell fosca',
    '🧑🏻‍🤝‍🧑🏻' => 'persones que s’agafen de la mà: pell molt clara',
    '🧑🏻‍🤝‍🧑🏼' => 'persones que s’agafen de la mà: pell molt clara i pell bastant clara',
    '🧑🏻‍🤝‍🧑🏽' => 'persones que s’agafen de la mà: pell molt clara i pell morena',
    '🧑🏻‍🤝‍🧑🏾' => 'persones que s’agafen de la mà: pell molt clara i pell fosca',
    '🧑🏻‍🤝‍🧑🏿' => 'persones que s’agafen de la mà: pell molt clara i pell molt fosca',
    '🧑🏼‍🤝‍🧑🏻' => 'persones que s’agafen de la mà: pell bastant clara i pell molt clara',
    '🧑🏼‍🤝‍🧑🏼' => 'persones que s’agafen de la mà: pell bastant clara',
    '🧑🏼‍🤝‍🧑🏽' => 'persones que s’agafen de la mà: pell bastant clara i pell morena',
    '🧑🏼‍🤝‍🧑🏾' => 'persones que s’agafen de la mà: pell bastant clara i pell fosca',
    '🧑🏼‍🤝‍🧑🏿' => 'persones que s’agafen de la mà: pell bastant clara i pell molt fosca',
    '🧑🏽‍🤝‍🧑🏻' => 'persones que s’agafen de la mà: pell morena i pell molt clara',
    '🧑🏽‍🤝‍🧑🏼' => 'persones que s’agafen de la mà: pell morena i pell bastant clara',
    '🧑🏽‍🤝‍🧑🏽' => 'persones que s’agafen de la mà: pell morena',
    '🧑🏽‍🤝‍🧑🏾' => 'persones que s’agafen de la mà: pell morena i pell fosca',
    '🧑🏽‍🤝‍🧑🏿' => 'persones que s’agafen de la mà: pell morena i pell molt fosca',
    '🧑🏾‍🤝‍🧑🏻' => 'persones que s’agafen de la mà: pell fosca i pell molt clara',
    '🧑🏾‍🤝‍🧑🏼' => 'persones que s’agafen de la mà: pell fosca i pell bastant clara',
    '🧑🏾‍🤝‍🧑🏽' => 'persones que s’agafen de la mà: pell fosca i pell morena',
    '🧑🏾‍🤝‍🧑🏾' => 'persones que s’agafen de la mà: pell fosca',
    '🧑🏾‍🤝‍🧑🏿' => 'persones que s’agafen de la mà: pell fosca i pell molt fosca',
    '🧑🏿‍🤝‍🧑🏻' => 'persones que s’agafen de la mà: pell molt fosca i pell molt clara',
    '🧑🏿‍🤝‍🧑🏼' => 'persones que s’agafen de la mà: pell molt fosca i pell bastant clara',
    '🧑🏿‍🤝‍🧑🏽' => 'persones que s’agafen de la mà: pell molt fosca i pell morena',
    '🧑🏿‍🤝‍🧑🏾' => 'persones que s’agafen de la mà: pell molt fosca i pell fosca',
    '🧑🏿‍🤝‍🧑🏿' => 'persones que s’agafen de la mà: pell molt fosca',
    '👩🏻‍🤝‍👩🏼' => 'dones que s’agafen de la mà: pell molt clara i pell bastant clara',
    '👩🏻‍🤝‍👩🏽' => 'dones que s’agafen de la mà: pell molt clara i pell morena',
    '👩🏻‍🤝‍👩🏾' => 'dones que s’agafen de la mà: pell molt clara i pell fosca',
    '👩🏻‍🤝‍👩🏿' => 'dones que s’agafen de la mà: pell molt clara i pell molt fosca',
    '👩🏼‍🤝‍👩🏻' => 'dones que s’agafen de la mà: pell bastant clara i pell molt clara',
    '👩🏼‍🤝‍👩🏽' => 'dones que s’agafen de la mà: pell bastant clara i pell morena',
    '👩🏼‍🤝‍👩🏾' => 'dones que s’agafen de la mà: pell bastant clara i pell fosca',
    '👩🏼‍🤝‍👩🏿' => 'dones que s’agafen de la mà: pell bastant clara i pell molt fosca',
    '👩🏽‍🤝‍👩🏻' => 'dones que s’agafen de la mà: pell morena i pell molt clara',
    '👩🏽‍🤝‍👩🏼' => 'dones que s’agafen de la mà: pell morena i pell bastant clara',
    '👩🏽‍🤝‍👩🏾' => 'dones que s’agafen de la mà: pell morena i pell fosca',
    '👩🏽‍🤝‍👩🏿' => 'dones que s’agafen de la mà: pell morena i pell molt fosca',
    '👩🏾‍🤝‍👩🏻' => 'dones que s’agafen de la mà: pell fosca i pell molt clara',
    '👩🏾‍🤝‍👩🏼' => 'dones que s’agafen de la mà: pell fosca i pell bastant clara',
    '👩🏾‍🤝‍👩🏽' => 'dones que s’agafen de la mà: pell fosca i pell morena',
    '👩🏾‍🤝‍👩🏿' => 'dones que s’agafen de la mà: pell fosca i pell molt fosca',
    '👩🏿‍🤝‍👩🏻' => 'dones que s’agafen de la mà: pell molt fosca i pell molt clara',
    '👩🏿‍🤝‍👩🏼' => 'dones que s’agafen de la mà: pell molt fosca i pell bastant clara',
    '👩🏿‍🤝‍👩🏽' => 'dones que s’agafen de la mà: pell molt fosca i pell morena',
    '👩🏿‍🤝‍👩🏾' => 'dones que s’agafen de la mà: pell molt fosca i pell fosca',
    '👩🏻‍🤝‍👨🏼' => 'home i dona que s’agafen de la mà: pell molt clara i pell bastant clara',
    '👩🏻‍🤝‍👨🏽' => 'home i dona que s’agafen de la mà: pell molt clara i pell morena',
    '👩🏻‍🤝‍👨🏾' => 'home i dona que s’agafen de la mà: pell molt clara i pell fosca',
    '👩🏻‍🤝‍👨🏿' => 'home i dona que s’agafen de la mà: pell molt clara i pell molt fosca',
    '👩🏼‍🤝‍👨🏻' => 'home i dona que s’agafen de la mà: pell bastant clara i pell molt clara',
    '👩🏼‍🤝‍👨🏽' => 'home i dona que s’agafen de la mà: pell bastant clara i pell morena',
    '👩🏼‍🤝‍👨🏾' => 'home i dona que s’agafen de la mà: pell bastant clara i pell fosca',
    '👩🏼‍🤝‍👨🏿' => 'home i dona que s’agafen de la mà: pell bastant clara i pell molt fosca',
    '👩🏽‍🤝‍👨🏻' => 'home i dona que s’agafen de la mà: pell morena i pell molt clara',
    '👩🏽‍🤝‍👨🏼' => 'home i dona que s’agafen de la mà: pell morena i pell bastant clara',
    '👩🏽‍🤝‍👨🏾' => 'home i dona que s’agafen de la mà: pell morena i pell fosca',
    '👩🏽‍🤝‍👨🏿' => 'home i dona que s’agafen de la mà: pell morena i pell molt fosca',
    '👩🏾‍🤝‍👨🏻' => 'home i dona que s’agafen de la mà: pell fosca i pell molt clara',
    '👩🏾‍🤝‍👨🏼' => 'home i dona que s’agafen de la mà: pell fosca i pell bastant clara',
    '👩🏾‍🤝‍👨🏽' => 'home i dona que s’agafen de la mà: pell fosca i pell morena',
    '👩🏾‍🤝‍👨🏿' => 'home i dona que s’agafen de la mà: pell fosca i pell molt fosca',
    '👩🏿‍🤝‍👨🏻' => 'home i dona que s’agafen de la mà: pell molt fosca i pell molt clara',
    '👩🏿‍🤝‍👨🏼' => 'home i dona que s’agafen de la mà: pell molt fosca i pell bastant clara',
    '👩🏿‍🤝‍👨🏽' => 'home i dona que s’agafen de la mà: pell molt fosca i pell morena',
    '👩🏿‍🤝‍👨🏾' => 'home i dona que s’agafen de la mà: pell molt fosca i pell fosca',
    '👨🏻‍🤝‍👨🏼' => 'homes que s’agafen de la mà: pell molt clara i pell bastant clara',
    '👨🏻‍🤝‍👨🏽' => 'homes que s’agafen de la mà: pell molt clara i pell morena',
    '👨🏻‍🤝‍👨🏾' => 'homes que s’agafen de la mà: pell molt clara i pell fosca',
    '👨🏻‍🤝‍👨🏿' => 'homes que s’agafen de la mà: pell molt clara i pell molt fosca',
    '👨🏼‍🤝‍👨🏻' => 'homes que s’agafen de la mà: pell bastant clara i pell molt clara',
    '👨🏼‍🤝‍👨🏽' => 'homes que s’agafen de la mà: pell bastant clara i pell morena',
    '👨🏼‍🤝‍👨🏾' => 'homes que s’agafen de la mà: pell bastant clara i pell fosca',
    '👨🏼‍🤝‍👨🏿' => 'homes que s’agafen de la mà: pell bastant clara i pell molt fosca',
    '👨🏽‍🤝‍👨🏻' => 'homes que s’agafen de la mà: pell morena i pell molt clara',
    '👨🏽‍🤝‍👨🏼' => 'homes que s’agafen de la mà: pell morena i pell bastant clara',
    '👨🏽‍🤝‍👨🏾' => 'homes que s’agafen de la mà: pell morena i pell fosca',
    '👨🏽‍🤝‍👨🏿' => 'homes que s’agafen de la mà: pell morena i pell molt fosca',
    '👨🏾‍🤝‍👨🏻' => 'homes que s’agafen de la mà: pell fosca i pell molt clara',
    '👨🏾‍🤝‍👨🏼' => 'homes que s’agafen de la mà: pell fosca i pell bastant clara',
    '👨🏾‍🤝‍👨🏽' => 'homes que s’agafen de la mà: pell fosca i pell morena',
    '👨🏾‍🤝‍👨🏿' => 'homes que s’agafen de la mà: pell fosca i pell molt fosca',
    '👨🏿‍🤝‍👨🏻' => 'homes que s’agafen de la mà: pell molt fosca i pell molt clara',
    '👨🏿‍🤝‍👨🏼' => 'homes que s’agafen de la mà: pell molt fosca i pell bastant clara',
    '👨🏿‍🤝‍👨🏽' => 'homes que s’agafen de la mà: pell molt fosca i pell morena',
    '👨🏿‍🤝‍👨🏾' => 'homes que s’agafen de la mà: pell molt fosca i pell fosca',
    '👩‍❤‍💋‍👨' => 'petó: dona i home',
    '👨‍❤‍💋‍👨' => 'petó: home i home',
    '👩‍❤‍💋‍👩' => 'petó: dona i dona',
    '👨‍👩‍👧‍👦' => 'família: home, dona, noia i noi',
    '👨‍👩‍👦‍👦' => 'família: home, dona, noi i noi',
    '👨‍👩‍👧‍👧' => 'família: home, dona, noia i noia',
    '👨‍👨‍👧‍👦' => 'família: home, home, noia i noi',
    '👨‍👨‍👦‍👦' => 'família: home, home, noi i noi',
    '👨‍👨‍👧‍👧' => 'família: home, home, noia i noia',
    '👩‍👩‍👧‍👦' => 'família: dona, dona, noia i noi',
    '👩‍👩‍👦‍👦' => 'família: dona, dona, noi i noi',
    '👩‍👩‍👧‍👧' => 'família: dona, dona, noia i noia',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bandera: Anglaterra',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bandera: Escòcia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bandera: Gal·les',
    '🧑‍🧑‍🧒‍🧒' => 'família: adult, adult, infant, infant',
    '🚶🏻‍♀‍➡' => 'dona que camina: pell molt clara i que mira a la dreta',
    '🚶🏼‍♀‍➡' => 'dona que camina: pell bastant clara i que mira a la dreta',
    '🚶🏽‍♀‍➡' => 'dona que camina: pell morena i que mira a la dreta',
    '🚶🏾‍♀‍➡' => 'dona que camina: pell fosca i que mira a la dreta',
    '🚶🏿‍♀‍➡' => 'dona que camina: pell molt fosca i que mira a la dreta',
    '🚶🏻‍♂‍➡' => 'home que camina: pell molt clara i que mira a la dreta',
    '🚶🏼‍♂‍➡' => 'home que camina: pell bastant clara i que mira a la dreta',
    '🚶🏽‍♂‍➡' => 'home que camina: pell morena i que mira a la dreta',
    '🚶🏾‍♂‍➡' => 'home que camina: pell fosca i que mira a la dreta',
    '🚶🏿‍♂‍➡' => 'home que camina: pell molt fosca i que mira a la dreta',
    '🧎🏻‍♀‍➡' => 'dona agenollada: pell molt clara i que mira a la dreta',
    '🧎🏼‍♀‍➡' => 'dona agenollada: pell bastant clara i que mira a la dreta',
    '🧎🏽‍♀‍➡' => 'dona agenollada: pell morena i que mira a la dreta',
    '🧎🏾‍♀‍➡' => 'dona agenollada: pell fosca i que mira a la dreta',
    '🧎🏿‍♀‍➡' => 'dona agenollada: pell molt fosca i que mira a la dreta',
    '🧎🏻‍♂‍➡' => 'home agenollat: pell molt clara i que mira a la dreta',
    '🧎🏼‍♂‍➡' => 'home agenollat: pell bastant clara i que mira a la dreta',
    '🧎🏽‍♂‍➡' => 'home agenollat: pell morena i que mira a la dreta',
    '🧎🏾‍♂‍➡' => 'home agenollat: pell fosca i que mira a la dreta',
    '🧎🏿‍♂‍➡' => 'home agenollat: pell molt fosca i que mira a la dreta',
    '🧑🏻‍🦯‍➡' => 'persona amb un bastó per a invidents: pell molt clara i que mira a la dreta',
    '🧑🏼‍🦯‍➡' => 'persona amb un bastó per a invidents: pell bastant clara i que mira a la dreta',
    '🧑🏽‍🦯‍➡' => 'persona amb un bastó per a invidents: pell morena i que mira a la dreta',
    '🧑🏾‍🦯‍➡' => 'persona amb un bastó per a invidents: pell fosca i que mira a la dreta',
    '🧑🏿‍🦯‍➡' => 'persona amb un bastó per a invidents: pell molt fosca i que mira a la dreta',
    '👨🏻‍🦯‍➡' => 'home amb un bastó per a invidents: pell molt clara i que mira a la dreta',
    '👨🏼‍🦯‍➡' => 'home amb un bastó per a invidents: pell bastant clara i que mira a la dreta',
    '👨🏽‍🦯‍➡' => 'home amb un bastó per a invidents: pell morena i que mira a la dreta',
    '👨🏾‍🦯‍➡' => 'home amb un bastó per a invidents: pell fosca i que mira a la dreta',
    '👨🏿‍🦯‍➡' => 'home amb un bastó per a invidents: pell molt fosca i que mira a la dreta',
    '👩🏻‍🦯‍➡' => 'dona amb un bastó per a invidents: pell molt clara i que mira a la dreta',
    '👩🏼‍🦯‍➡' => 'dona amb un bastó per a invidents: pell bastant clara i que mira a la dreta',
    '👩🏽‍🦯‍➡' => 'dona amb un bastó per a invidents: pell morena i que mira a la dreta',
    '👩🏾‍🦯‍➡' => 'dona amb un bastó per a invidents: pell fosca i que mira a la dreta',
    '👩🏿‍🦯‍➡' => 'dona amb un bastó per a invidents: pell molt fosca i que mira a la dreta',
    '🧑🏻‍🦼‍➡' => 'persona amb una cadira de rodes elèctrica: pell molt clara i que mira a la dreta',
    '🧑🏼‍🦼‍➡' => 'persona amb una cadira de rodes elèctrica: pell bastant clara i que mira a la dreta',
    '🧑🏽‍🦼‍➡' => 'persona amb una cadira de rodes elèctrica: pell morena i que mira a la dreta',
    '🧑🏾‍🦼‍➡' => 'persona amb una cadira de rodes elèctrica: pell fosca i que mira a la dreta',
    '🧑🏿‍🦼‍➡' => 'persona amb una cadira de rodes elèctrica: pell molt fosca i que mira a la dreta',
    '👨🏻‍🦼‍➡' => 'home amb una cadira de rodes elèctrica: pell molt clara i que mira a la dreta',
    '👨🏼‍🦼‍➡' => 'home amb una cadira de rodes elèctrica: pell bastant clara i que mira a la dreta',
    '👨🏽‍🦼‍➡' => 'home amb una cadira de rodes elèctrica: pell morena i que mira a la dreta',
    '👨🏾‍🦼‍➡' => 'home amb una cadira de rodes elèctrica: pell fosca i que mira a la dreta',
    '👨🏿‍🦼‍➡' => 'home amb una cadira de rodes elèctrica: pell molt fosca i que mira a la dreta',
    '👩🏻‍🦼‍➡' => 'dona amb una cadira de rodes elèctrica: pell molt clara i que mira a la dreta',
    '👩🏼‍🦼‍➡' => 'dona amb una cadira de rodes elèctrica: pell bastant clara i que mira a la dreta',
    '👩🏽‍🦼‍➡' => 'dona amb una cadira de rodes elèctrica: pell morena i que mira a la dreta',
    '👩🏾‍🦼‍➡' => 'dona amb una cadira de rodes elèctrica: pell fosca i que mira a la dreta',
    '👩🏿‍🦼‍➡' => 'dona amb una cadira de rodes elèctrica: pell molt fosca i que mira a la dreta',
    '🧑🏻‍🦽‍➡' => 'persona amb una cadira de rodes manual: pell molt clara i que mira a la dreta',
    '🧑🏼‍🦽‍➡' => 'persona amb una cadira de rodes manual: pell bastant clara i que mira a la dreta',
    '🧑🏽‍🦽‍➡' => 'persona amb una cadira de rodes manual: pell morena i que mira a la dreta',
    '🧑🏾‍🦽‍➡' => 'persona amb una cadira de rodes manual: pell fosca i que mira a la dreta',
    '🧑🏿‍🦽‍➡' => 'persona amb una cadira de rodes manual: pell molt fosca i que mira a la dreta',
    '👨🏻‍🦽‍➡' => 'home amb una cadira de rodes manual: pell molt clara i que mira a la dreta',
    '👨🏼‍🦽‍➡' => 'home amb una cadira de rodes manual: pell bastant clara i que mira a la dreta',
    '👨🏽‍🦽‍➡' => 'home amb una cadira de rodes manual: pell morena i que mira a la dreta',
    '👨🏾‍🦽‍➡' => 'home amb una cadira de rodes manual: pell fosca i que mira a la dreta',
    '👨🏿‍🦽‍➡' => 'home amb una cadira de rodes manual: pell molt fosca i que mira a la dreta',
    '👩🏻‍🦽‍➡' => 'dona amb una cadira de rodes manual: pell molt clara i que mira a la dreta',
    '👩🏼‍🦽‍➡' => 'dona amb una cadira de rodes manual: pell bastant clara i que mira a la dreta',
    '👩🏽‍🦽‍➡' => 'dona amb una cadira de rodes manual: pell morena i que mira a la dreta',
    '👩🏾‍🦽‍➡' => 'dona amb una cadira de rodes manual: pell fosca i que mira a la dreta',
    '👩🏿‍🦽‍➡' => 'dona amb una cadira de rodes manual: pell molt fosca i que mira a la dreta',
    '🏃🏻‍♀‍➡' => 'dona que corre: pell molt clara i que mira a la dreta',
    '🏃🏼‍♀‍➡' => 'dona que corre: pell bastant clara i que mira a la dreta',
    '🏃🏽‍♀‍➡' => 'dona que corre: pell morena i que mira a la dreta',
    '🏃🏾‍♀‍➡' => 'dona que corre: pell fosca i que mira a la dreta',
    '🏃🏿‍♀‍➡' => 'dona que corre: pell molt fosca i que mira a la dreta',
    '🏃🏻‍♂‍➡' => 'home que corre: pell molt clara i que mira a la dreta',
    '🏃🏼‍♂‍➡' => 'home que corre: pell bastant clara i que mira a la dreta',
    '🏃🏽‍♂‍➡' => 'home que corre: pell morena i que mira a la dreta',
    '🏃🏾‍♂‍➡' => 'home que corre: pell fosca i que mira a la dreta',
    '🏃🏿‍♂‍➡' => 'home que corre: pell molt fosca i que mira a la dreta',
    '🫱🏻‍🫲🏼' => 'encaixada de mans: pell molt clara i pell bastant clara',
    '🫱🏻‍🫲🏽' => 'encaixada de mans: pell molt clara i pell morena',
    '🫱🏻‍🫲🏾' => 'encaixada de mans: pell molt clara i pell fosca',
    '🫱🏻‍🫲🏿' => 'encaixada de mans: pell molt clara i pell molt fosca',
    '🫱🏼‍🫲🏻' => 'encaixada de mans: pell bastant clara i pell molt clara',
    '🫱🏼‍🫲🏽' => 'encaixada de mans: pell bastant clara i pell morena',
    '🫱🏼‍🫲🏾' => 'encaixada de mans: pell bastant clara i pell fosca',
    '🫱🏼‍🫲🏿' => 'encaixada de mans: pell bastant clara i pell molt fosca',
    '🫱🏽‍🫲🏻' => 'encaixada de mans: pell morena i pell molt clara',
    '🫱🏽‍🫲🏼' => 'encaixada de mans: pell morena i pell bastant clara',
    '🫱🏽‍🫲🏾' => 'encaixada de mans: pell morena i pell fosca',
    '🫱🏽‍🫲🏿' => 'encaixada de mans: pell morena i pell molt fosca',
    '🫱🏾‍🫲🏻' => 'encaixada de mans: pell fosca i pell molt clara',
    '🫱🏾‍🫲🏼' => 'encaixada de mans: pell fosca i pell bastant clara',
    '🫱🏾‍🫲🏽' => 'encaixada de mans: pell fosca i pell morena',
    '🫱🏾‍🫲🏿' => 'encaixada de mans: pell fosca i pell molt fosca',
    '🫱🏿‍🫲🏻' => 'encaixada de mans: pell molt fosca i pell molt clara',
    '🫱🏿‍🫲🏼' => 'encaixada de mans: pell molt fosca i pell bastant clara',
    '🫱🏿‍🫲🏽' => 'encaixada de mans: pell molt fosca i pell morena',
    '🫱🏿‍🫲🏾' => 'encaixada de mans: pell molt fosca i pell fosca',
    '🚶‍♀‍➡' => 'dona que camina: que mira a la dreta',
    '🚶‍♂‍➡' => 'home que camina: que mira a la dreta',
    '🧎‍♀‍➡' => 'dona agenollada: que mira a la dreta',
    '🧎‍♂‍➡' => 'home agenollat: que mira a la dreta',
    '🧑‍🦯‍➡' => 'persona amb un bastó per a invidents: que mira a la dreta',
    '👨‍🦯‍➡' => 'home amb un bastó per a invidents: que mira a la dreta',
    '👩‍🦯‍➡' => 'dona amb un bastó per a invidents: que mira a la dreta',
    '🧑‍🦼‍➡' => 'persona amb una cadira de rodes elèctrica: que mira a la dreta',
    '👨‍🦼‍➡' => 'home amb una cadira de rodes elèctrica: que mira a la dreta',
    '👩‍🦼‍➡' => 'dona amb una cadira de rodes elèctrica: que mira a la dreta',
    '🧑‍🦽‍➡' => 'persona amb una cadira de rodes manual: que mira a la dreta',
    '👨‍🦽‍➡' => 'home amb una cadira de rodes manual: que mira a la dreta',
    '👩‍🦽‍➡' => 'dona amb una cadira de rodes manual: que mira a la dreta',
    '🏃‍♀‍➡' => 'dona que corre: que mira a la dreta',
    '🏃‍♂‍➡' => 'home que corre: que mira a la dreta',
    '👩‍❤‍👨' => 'parella amb un cor: dona i home',
    '👨‍❤‍👨' => 'parella amb un cor: home i home',
    '👩‍❤‍👩' => 'parella amb un cor: dona i dona',
    '👨‍👩‍👦' => 'família: home, dona i noi',
    '👨‍👩‍👧' => 'família: home, dona i noia',
    '👨‍👨‍👦' => 'família: home, home i noi',
    '👨‍👨‍👧' => 'família: home, home i noia',
    '👩‍👩‍👦' => 'família: dona, dona i noi',
    '👩‍👩‍👧' => 'família: dona, dona i noia',
    '👨‍👦‍👦' => 'família: home, noi i noi',
    '👨‍👧‍👦' => 'família: home, noia i noi',
    '👨‍👧‍👧' => 'família: home, noia i noia',
    '👩‍👦‍👦' => 'família: dona, noi i noi',
    '👩‍👧‍👦' => 'família: dona, noia i noi',
    '👩‍👧‍👧' => 'família: dona, noia i noia',
    '🧑‍🤝‍🧑' => 'persones que s’agafen de la mà',
    '🧑‍🧑‍🧒' => 'família: adult, adult, infant',
    '🧑‍🧒‍🧒' => 'família: adult, infant, infant',
    '🧑🏻‍🦰' => 'persona: pell molt clara i cabells vermells',
    '🧑🏼‍🦰' => 'persona: pell bastant clara i cabells vermells',
    '🧑🏽‍🦰' => 'persona: pell morena i cabells vermells',
    '🧑🏾‍🦰' => 'persona: pell fosca i cabells vermells',
    '🧑🏿‍🦰' => 'persona: pell molt fosca i cabells vermells',
    '🧑🏻‍🦱' => 'persona: pell molt clara i cabells arrissats',
    '🧑🏼‍🦱' => 'persona: pell bastant clara i cabells arrissats',
    '🧑🏽‍🦱' => 'persona: pell morena i cabells arrissats',
    '🧑🏾‍🦱' => 'persona: pell fosca i cabells arrissats',
    '🧑🏿‍🦱' => 'persona: pell molt fosca i cabells arrissats',
    '🧑🏻‍🦳' => 'persona: pell molt clara i cabells blancs',
    '🧑🏼‍🦳' => 'persona: pell bastant clara i cabells blancs',
    '🧑🏽‍🦳' => 'persona: pell morena i cabells blancs',
    '🧑🏾‍🦳' => 'persona: pell fosca i cabells blancs',
    '🧑🏿‍🦳' => 'persona: pell molt fosca i cabells blancs',
    '🧑🏻‍🦲' => 'persona: pell molt clara i calvície',
    '🧑🏼‍🦲' => 'persona: pell bastant clara i calvície',
    '🧑🏽‍🦲' => 'persona: pell morena i calvície',
    '🧑🏾‍🦲' => 'persona: pell fosca i calvície',
    '🧑🏿‍🦲' => 'persona: pell molt fosca i calvície',
    '🧑🏻‍🩰' => 'ballarí de ballet: pell molt clara',
    '🧑🏼‍🩰' => 'ballarí de ballet: pell bastant clara',
    '🧑🏽‍🩰' => 'ballarí de ballet: pell morena',
    '🧑🏾‍🩰' => 'ballarí de ballet: pell fosca',
    '🧑🏿‍🩰' => 'ballarí de ballet: pell molt fosca',
    '🧔🏻‍♂' => 'home: pell molt clara i barba',
    '🧔🏼‍♂' => 'home: pell bastant clara i barba',
    '🧔🏽‍♂' => 'home: pell morena i barba',
    '🧔🏾‍♂' => 'home: pell fosca i barba',
    '🧔🏿‍♂' => 'home: pell molt fosca i barba',
    '👱🏻‍♂' => 'home: pell molt clara i cabell ros',
    '👱🏼‍♂' => 'home: pell bastant clara i cabell ros',
    '👱🏽‍♂' => 'home: pell morena i cabell ros',
    '👱🏾‍♂' => 'home: pell fosca i cabell ros',
    '👱🏿‍♂' => 'home: pell molt fosca i cabell ros',
    '👨🏻‍🦰' => 'home: pell molt clara i cabells vermells',
    '👨🏼‍🦰' => 'home: pell bastant clara i cabells vermells',
    '👨🏽‍🦰' => 'home: pell morena i cabells vermells',
    '👨🏾‍🦰' => 'home: pell fosca i cabells vermells',
    '👨🏿‍🦰' => 'home: pell molt fosca i cabells vermells',
    '👨🏻‍🦱' => 'home: pell molt clara i cabells arrissats',
    '👨🏼‍🦱' => 'home: pell bastant clara i cabells arrissats',
    '👨🏽‍🦱' => 'home: pell morena i cabells arrissats',
    '👨🏾‍🦱' => 'home: pell fosca i cabells arrissats',
    '👨🏿‍🦱' => 'home: pell molt fosca i cabells arrissats',
    '👨🏻‍🦳' => 'home: pell molt clara i cabells blancs',
    '👨🏼‍🦳' => 'home: pell bastant clara i cabells blancs',
    '👨🏽‍🦳' => 'home: pell morena i cabells blancs',
    '👨🏾‍🦳' => 'home: pell fosca i cabells blancs',
    '👨🏿‍🦳' => 'home: pell molt fosca i cabells blancs',
    '👨🏻‍🦲' => 'home: pell molt clara i calvície',
    '👨🏼‍🦲' => 'home: pell bastant clara i calvície',
    '👨🏽‍🦲' => 'home: pell morena i calvície',
    '👨🏾‍🦲' => 'home: pell fosca i calvície',
    '👨🏿‍🦲' => 'home: pell molt fosca i calvície',
    '🧔🏻‍♀' => 'dona: pell molt clara i barba',
    '🧔🏼‍♀' => 'dona: pell bastant clara i barba',
    '🧔🏽‍♀' => 'dona: pell morena i barba',
    '🧔🏾‍♀' => 'dona: pell fosca i barba',
    '🧔🏿‍♀' => 'dona: pell molt fosca i barba',
    '👱🏻‍♀' => 'dona: pell molt clara i cabell ros',
    '👱🏼‍♀' => 'dona: pell bastant clara i cabell ros',
    '👱🏽‍♀' => 'dona: pell morena i cabell ros',
    '👱🏾‍♀' => 'dona: pell fosca i cabell ros',
    '👱🏿‍♀' => 'dona: pell molt fosca i cabell ros',
    '👩🏻‍🦰' => 'dona: pell molt clara i cabells vermells',
    '👩🏼‍🦰' => 'dona: pell bastant clara i cabells vermells',
    '👩🏽‍🦰' => 'dona: pell morena i cabells vermells',
    '👩🏾‍🦰' => 'dona: pell fosca i cabells vermells',
    '👩🏿‍🦰' => 'dona: pell molt fosca i cabells vermells',
    '👩🏻‍🦱' => 'dona: pell molt clara i cabells arrissats',
    '👩🏼‍🦱' => 'dona: pell bastant clara i cabells arrissats',
    '👩🏽‍🦱' => 'dona: pell morena i cabells arrissats',
    '👩🏾‍🦱' => 'dona: pell fosca i cabells arrissats',
    '👩🏿‍🦱' => 'dona: pell molt fosca i cabells arrissats',
    '👩🏻‍🦳' => 'dona: pell molt clara i cabells blancs',
    '👩🏼‍🦳' => 'dona: pell bastant clara i cabells blancs',
    '👩🏽‍🦳' => 'dona: pell morena i cabells blancs',
    '👩🏾‍🦳' => 'dona: pell fosca i cabells blancs',
    '👩🏿‍🦳' => 'dona: pell molt fosca i cabells blancs',
    '👩🏻‍🦲' => 'dona: pell molt clara i calvície',
    '👩🏼‍🦲' => 'dona: pell bastant clara i calvície',
    '👩🏽‍🦲' => 'dona: pell morena i calvície',
    '👩🏾‍🦲' => 'dona: pell fosca i calvície',
    '👩🏿‍🦲' => 'dona: pell molt fosca i calvície',
    '🙍🏻‍♂' => 'home emmurriat: pell molt clara',
    '🙍🏼‍♂' => 'home emmurriat: pell bastant clara',
    '🙍🏽‍♂' => 'home emmurriat: pell morena',
    '🙍🏾‍♂' => 'home emmurriat: pell fosca',
    '🙍🏿‍♂' => 'home emmurriat: pell molt fosca',
    '🙍🏻‍♀' => 'dona emmurriada: pell molt clara',
    '🙍🏼‍♀' => 'dona emmurriada: pell bastant clara',
    '🙍🏽‍♀' => 'dona emmurriada: pell morena',
    '🙍🏾‍♀' => 'dona emmurriada: pell fosca',
    '🙍🏿‍♀' => 'dona emmurriada: pell molt fosca',
    '🙎🏻‍♂' => 'home enutjat: pell molt clara',
    '🙎🏼‍♂' => 'home enutjat: pell bastant clara',
    '🙎🏽‍♂' => 'home enutjat: pell morena',
    '🙎🏾‍♂' => 'home enutjat: pell fosca',
    '🙎🏿‍♂' => 'home enutjat: pell molt fosca',
    '🙎🏻‍♀' => 'dona enutjada: pell molt clara',
    '🙎🏼‍♀' => 'dona enutjada: pell bastant clara',
    '🙎🏽‍♀' => 'dona enutjada: pell morena',
    '🙎🏾‍♀' => 'dona enutjada: pell fosca',
    '🙎🏿‍♀' => 'dona enutjada: pell molt fosca',
    '🙅🏻‍♂' => 'home amb gest de negació: pell molt clara',
    '🙅🏼‍♂' => 'home amb gest de negació: pell bastant clara',
    '🙅🏽‍♂' => 'home amb gest de negació: pell morena',
    '🙅🏾‍♂' => 'home amb gest de negació: pell fosca',
    '🙅🏿‍♂' => 'home amb gest de negació: pell molt fosca',
    '🙅🏻‍♀' => 'dona amb gest de negació: pell molt clara',
    '🙅🏼‍♀' => 'dona amb gest de negació: pell bastant clara',
    '🙅🏽‍♀' => 'dona amb gest de negació: pell morena',
    '🙅🏾‍♀' => 'dona amb gest de negació: pell fosca',
    '🙅🏿‍♀' => 'dona amb gest de negació: pell molt fosca',
    '🙆🏻‍♂' => 'home amb gest d’aprovació: pell molt clara',
    '🙆🏼‍♂' => 'home amb gest d’aprovació: pell bastant clara',
    '🙆🏽‍♂' => 'home amb gest d’aprovació: pell morena',
    '🙆🏾‍♂' => 'home amb gest d’aprovació: pell fosca',
    '🙆🏿‍♂' => 'home amb gest d’aprovació: pell molt fosca',
    '🙆🏻‍♀' => 'dona amb gest d’aprovació: pell molt clara',
    '🙆🏼‍♀' => 'dona amb gest d’aprovació: pell bastant clara',
    '🙆🏽‍♀' => 'dona amb gest d’aprovació: pell morena',
    '🙆🏾‍♀' => 'dona amb gest d’aprovació: pell fosca',
    '🙆🏿‍♀' => 'dona amb gest d’aprovació: pell molt fosca',
    '💁🏻‍♂' => 'home amb mà inclinada cap amunt: pell molt clara',
    '💁🏼‍♂' => 'home amb mà inclinada cap amunt: pell bastant clara',
    '💁🏽‍♂' => 'home amb mà inclinada cap amunt: pell morena',
    '💁🏾‍♂' => 'home amb mà inclinada cap amunt: pell fosca',
    '💁🏿‍♂' => 'home amb mà inclinada cap amunt: pell molt fosca',
    '💁🏻‍♀' => 'dona amb mà inclinada cap amunt: pell molt clara',
    '💁🏼‍♀' => 'dona amb mà inclinada cap amunt: pell bastant clara',
    '💁🏽‍♀' => 'dona amb mà inclinada cap amunt: pell morena',
    '💁🏾‍♀' => 'dona amb mà inclinada cap amunt: pell fosca',
    '💁🏿‍♀' => 'dona amb mà inclinada cap amunt: pell molt fosca',
    '🙋🏻‍♂' => 'home amb la mà aixecada: pell molt clara',
    '🙋🏼‍♂' => 'home amb la mà aixecada: pell bastant clara',
    '🙋🏽‍♂' => 'home amb la mà aixecada: pell morena',
    '🙋🏾‍♂' => 'home amb la mà aixecada: pell fosca',
    '🙋🏿‍♂' => 'home amb la mà aixecada: pell molt fosca',
    '🙋🏻‍♀' => 'dona amb la mà aixecada: pell molt clara',
    '🙋🏼‍♀' => 'dona amb la mà aixecada: pell bastant clara',
    '🙋🏽‍♀' => 'dona amb la mà aixecada: pell morena',
    '🙋🏾‍♀' => 'dona amb la mà aixecada: pell fosca',
    '🙋🏿‍♀' => 'dona amb la mà aixecada: pell molt fosca',
    '🧏🏻‍♂' => 'home sord: pell molt clara',
    '🧏🏼‍♂' => 'home sord: pell bastant clara',
    '🧏🏽‍♂' => 'home sord: pell morena',
    '🧏🏾‍♂' => 'home sord: pell fosca',
    '🧏🏿‍♂' => 'home sord: pell molt fosca',
    '🧏🏻‍♀' => 'dona sorda: pell molt clara',
    '🧏🏼‍♀' => 'dona sorda: pell bastant clara',
    '🧏🏽‍♀' => 'dona sorda: pell morena',
    '🧏🏾‍♀' => 'dona sorda: pell fosca',
    '🧏🏿‍♀' => 'dona sorda: pell molt fosca',
    '🙇🏻‍♂' => 'home capcot: pell molt clara',
    '🙇🏼‍♂' => 'home capcot: pell bastant clara',
    '🙇🏽‍♂' => 'home capcot: pell morena',
    '🙇🏾‍♂' => 'home capcot: pell fosca',
    '🙇🏿‍♂' => 'home capcot: pell molt fosca',
    '🙇🏻‍♀' => 'dona capcota: pell molt clara',
    '🙇🏼‍♀' => 'dona capcota: pell bastant clara',
    '🙇🏽‍♀' => 'dona capcota: pell morena',
    '🙇🏾‍♀' => 'dona capcota: pell fosca',
    '🙇🏿‍♀' => 'dona capcota: pell molt fosca',
    '🤦🏻‍♂' => 'home amb la mà a la cara: pell molt clara',
    '🤦🏼‍♂' => 'home amb la mà a la cara: pell bastant clara',
    '🤦🏽‍♂' => 'home amb la mà a la cara: pell morena',
    '🤦🏾‍♂' => 'home amb la mà a la cara: pell fosca',
    '🤦🏿‍♂' => 'home amb la mà a la cara: pell molt fosca',
    '🤦🏻‍♀' => 'dona amb la mà a la cara: pell molt clara',
    '🤦🏼‍♀' => 'dona amb la mà a la cara: pell bastant clara',
    '🤦🏽‍♀' => 'dona amb la mà a la cara: pell morena',
    '🤦🏾‍♀' => 'dona amb la mà a la cara: pell fosca',
    '🤦🏿‍♀' => 'dona amb la mà a la cara: pell molt fosca',
    '🤷🏻‍♂' => 'home que arronsa les espatlles: pell molt clara',
    '🤷🏼‍♂' => 'home que arronsa les espatlles: pell bastant clara',
    '🤷🏽‍♂' => 'home que arronsa les espatlles: pell morena',
    '🤷🏾‍♂' => 'home que arronsa les espatlles: pell fosca',
    '🤷🏿‍♂' => 'home que arronsa les espatlles: pell molt fosca',
    '🤷🏻‍♀' => 'dona que arronsa les espatlles: pell molt clara',
    '🤷🏼‍♀' => 'dona que arronsa les espatlles: pell bastant clara',
    '🤷🏽‍♀' => 'dona que arronsa les espatlles: pell morena',
    '🤷🏾‍♀' => 'dona que arronsa les espatlles: pell fosca',
    '🤷🏿‍♀' => 'dona que arronsa les espatlles: pell molt fosca',
    '🧑🏻‍⚕' => 'professional de la salut: pell molt clara',
    '🧑🏼‍⚕' => 'professional de la salut: pell bastant clara',
    '🧑🏽‍⚕' => 'professional de la salut: pell morena',
    '🧑🏾‍⚕' => 'professional de la salut: pell fosca',
    '🧑🏿‍⚕' => 'professional de la salut: pell molt fosca',
    '👨🏻‍⚕' => 'home professional de la salut: pell molt clara',
    '👨🏼‍⚕' => 'home professional de la salut: pell bastant clara',
    '👨🏽‍⚕' => 'home professional de la salut: pell morena',
    '👨🏾‍⚕' => 'home professional de la salut: pell fosca',
    '👨🏿‍⚕' => 'home professional de la salut: pell molt fosca',
    '👩🏻‍⚕' => 'dona professional de la salut: pell molt clara',
    '👩🏼‍⚕' => 'dona professional de la salut: pell bastant clara',
    '👩🏽‍⚕' => 'dona professional de la salut: pell morena',
    '👩🏾‍⚕' => 'dona professional de la salut: pell fosca',
    '👩🏿‍⚕' => 'dona professional de la salut: pell molt fosca',
    '🧑🏻‍🎓' => 'estudiant: pell molt clara',
    '🧑🏼‍🎓' => 'estudiant: pell bastant clara',
    '🧑🏽‍🎓' => 'estudiant: pell morena',
    '🧑🏾‍🎓' => 'estudiant: pell fosca',
    '🧑🏿‍🎓' => 'estudiant: pell molt fosca',
    '👨🏻‍🎓' => 'noi estudiant: pell molt clara',
    '👨🏼‍🎓' => 'noi estudiant: pell bastant clara',
    '👨🏽‍🎓' => 'noi estudiant: pell morena',
    '👨🏾‍🎓' => 'noi estudiant: pell fosca',
    '👨🏿‍🎓' => 'noi estudiant: pell molt fosca',
    '👩🏻‍🎓' => 'noia estudiant: pell molt clara',
    '👩🏼‍🎓' => 'noia estudiant: pell bastant clara',
    '👩🏽‍🎓' => 'noia estudiant: pell morena',
    '👩🏾‍🎓' => 'noia estudiant: pell fosca',
    '👩🏿‍🎓' => 'noia estudiant: pell molt fosca',
    '🧑🏻‍🏫' => 'professor: pell molt clara',
    '🧑🏼‍🏫' => 'professor: pell bastant clara',
    '🧑🏽‍🏫' => 'professor: pell morena',
    '🧑🏾‍🏫' => 'professor: pell fosca',
    '🧑🏿‍🏫' => 'professor: pell molt fosca',
    '👨🏻‍🏫' => 'home professor: pell molt clara',
    '👨🏼‍🏫' => 'home professor: pell bastant clara',
    '👨🏽‍🏫' => 'home professor: pell morena',
    '👨🏾‍🏫' => 'home professor: pell fosca',
    '👨🏿‍🏫' => 'home professor: pell molt fosca',
    '👩🏻‍🏫' => 'professora: pell molt clara',
    '👩🏼‍🏫' => 'professora: pell bastant clara',
    '👩🏽‍🏫' => 'professora: pell morena',
    '👩🏾‍🏫' => 'professora: pell fosca',
    '👩🏿‍🏫' => 'professora: pell molt fosca',
    '🧑🏻‍⚖' => 'jutge: pell molt clara',
    '🧑🏼‍⚖' => 'jutge: pell bastant clara',
    '🧑🏽‍⚖' => 'jutge: pell morena',
    '🧑🏾‍⚖' => 'jutge: pell fosca',
    '🧑🏿‍⚖' => 'jutge: pell molt fosca',
    '👨🏻‍⚖' => 'home jutge: pell molt clara',
    '👨🏼‍⚖' => 'home jutge: pell bastant clara',
    '👨🏽‍⚖' => 'home jutge: pell morena',
    '👨🏾‍⚖' => 'home jutge: pell fosca',
    '👨🏿‍⚖' => 'home jutge: pell molt fosca',
    '👩🏻‍⚖' => 'jutgessa: pell molt clara',
    '👩🏼‍⚖' => 'jutgessa: pell bastant clara',
    '👩🏽‍⚖' => 'jutgessa: pell morena',
    '👩🏾‍⚖' => 'jutgessa: pell fosca',
    '👩🏿‍⚖' => 'jutgessa: pell molt fosca',
    '🧑🏻‍🌾' => 'agricultor: pell molt clara',
    '🧑🏼‍🌾' => 'agricultor: pell bastant clara',
    '🧑🏽‍🌾' => 'agricultor: pell morena',
    '🧑🏾‍🌾' => 'agricultor: pell fosca',
    '🧑🏿‍🌾' => 'agricultor: pell molt fosca',
    '👨🏻‍🌾' => 'home pagès: pell molt clara',
    '👨🏼‍🌾' => 'home pagès: pell bastant clara',
    '👨🏽‍🌾' => 'home pagès: pell morena',
    '👨🏾‍🌾' => 'home pagès: pell fosca',
    '👨🏿‍🌾' => 'home pagès: pell molt fosca',
    '👩🏻‍🌾' => 'agricultora: pell molt clara',
    '👩🏼‍🌾' => 'agricultora: pell bastant clara',
    '👩🏽‍🌾' => 'agricultora: pell morena',
    '👩🏾‍🌾' => 'agricultora: pell fosca',
    '👩🏿‍🌾' => 'agricultora: pell molt fosca',
    '🧑🏻‍🍳' => 'cuiner: pell molt clara',
    '🧑🏼‍🍳' => 'cuiner: pell bastant clara',
    '🧑🏽‍🍳' => 'cuiner: pell morena',
    '🧑🏾‍🍳' => 'cuiner: pell fosca',
    '🧑🏿‍🍳' => 'cuiner: pell molt fosca',
    '👨🏻‍🍳' => 'home cuiner: pell molt clara',
    '👨🏼‍🍳' => 'home cuiner: pell bastant clara',
    '👨🏽‍🍳' => 'home cuiner: pell morena',
    '👨🏾‍🍳' => 'home cuiner: pell fosca',
    '👨🏿‍🍳' => 'home cuiner: pell molt fosca',
    '👩🏻‍🍳' => 'cuinera: pell molt clara',
    '👩🏼‍🍳' => 'cuinera: pell bastant clara',
    '👩🏽‍🍳' => 'cuinera: pell morena',
    '👩🏾‍🍳' => 'cuinera: pell fosca',
    '👩🏿‍🍳' => 'cuinera: pell molt fosca',
    '🧑🏻‍🔧' => 'mecànic: pell molt clara',
    '🧑🏼‍🔧' => 'mecànic: pell bastant clara',
    '🧑🏽‍🔧' => 'mecànic: pell morena',
    '🧑🏾‍🔧' => 'mecànic: pell fosca',
    '🧑🏿‍🔧' => 'mecànic: pell molt fosca',
    '👨🏻‍🔧' => 'home mecànic: pell molt clara',
    '👨🏼‍🔧' => 'home mecànic: pell bastant clara',
    '👨🏽‍🔧' => 'home mecànic: pell morena',
    '👨🏾‍🔧' => 'home mecànic: pell fosca',
    '👨🏿‍🔧' => 'home mecànic: pell molt fosca',
    '👩🏻‍🔧' => 'mecànica: pell molt clara',
    '👩🏼‍🔧' => 'mecànica: pell bastant clara',
    '👩🏽‍🔧' => 'mecànica: pell morena',
    '👩🏾‍🔧' => 'mecànica: pell fosca',
    '👩🏿‍🔧' => 'mecànica: pell molt fosca',
    '🧑🏻‍🏭' => 'operari: pell molt clara',
    '🧑🏼‍🏭' => 'operari: pell bastant clara',
    '🧑🏽‍🏭' => 'operari: pell morena',
    '🧑🏾‍🏭' => 'operari: pell fosca',
    '🧑🏿‍🏭' => 'operari: pell molt fosca',
    '👨🏻‍🏭' => 'home operari: pell molt clara',
    '👨🏼‍🏭' => 'home operari: pell bastant clara',
    '👨🏽‍🏭' => 'home operari: pell morena',
    '👨🏾‍🏭' => 'home operari: pell fosca',
    '👨🏿‍🏭' => 'home operari: pell molt fosca',
    '👩🏻‍🏭' => 'operària: pell molt clara',
    '👩🏼‍🏭' => 'operària: pell bastant clara',
    '👩🏽‍🏭' => 'operària: pell morena',
    '👩🏾‍🏭' => 'operària: pell fosca',
    '👩🏿‍🏭' => 'operària: pell molt fosca',
    '🧑🏻‍💼' => 'treballador d’oficina: pell molt clara',
    '🧑🏼‍💼' => 'treballador d’oficina: pell bastant clara',
    '🧑🏽‍💼' => 'treballador d’oficina: pell morena',
    '🧑🏾‍💼' => 'treballador d’oficina: pell fosca',
    '🧑🏿‍💼' => 'treballador d’oficina: pell molt fosca',
    '👨🏻‍💼' => 'home treballador d’oficina: pell molt clara',
    '👨🏼‍💼' => 'home treballador d’oficina: pell bastant clara',
    '👨🏽‍💼' => 'home treballador d’oficina: pell morena',
    '👨🏾‍💼' => 'home treballador d’oficina: pell fosca',
    '👨🏿‍💼' => 'home treballador d’oficina: pell molt fosca',
    '👩🏻‍💼' => 'treballadora d’oficina: pell molt clara',
    '👩🏼‍💼' => 'treballadora d’oficina: pell bastant clara',
    '👩🏽‍💼' => 'treballadora d’oficina: pell morena',
    '👩🏾‍💼' => 'treballadora d’oficina: pell fosca',
    '👩🏿‍💼' => 'treballadora d’oficina: pell molt fosca',
    '🧑🏻‍🔬' => 'científic: pell molt clara',
    '🧑🏼‍🔬' => 'científic: pell bastant clara',
    '🧑🏽‍🔬' => 'científic: pell morena',
    '🧑🏾‍🔬' => 'científic: pell fosca',
    '🧑🏿‍🔬' => 'científic: pell molt fosca',
    '👨🏻‍🔬' => 'home científic: pell molt clara',
    '👨🏼‍🔬' => 'home científic: pell bastant clara',
    '👨🏽‍🔬' => 'home científic: pell morena',
    '👨🏾‍🔬' => 'home científic: pell fosca',
    '👨🏿‍🔬' => 'home científic: pell molt fosca',
    '👩🏻‍🔬' => 'científica: pell molt clara',
    '👩🏼‍🔬' => 'científica: pell bastant clara',
    '👩🏽‍🔬' => 'científica: pell morena',
    '👩🏾‍🔬' => 'científica: pell fosca',
    '👩🏿‍🔬' => 'científica: pell molt fosca',
    '🧑🏻‍💻' => 'tecnòleg: pell molt clara',
    '🧑🏼‍💻' => 'tecnòleg: pell bastant clara',
    '🧑🏽‍💻' => 'tecnòleg: pell morena',
    '🧑🏾‍💻' => 'tecnòleg: pell fosca',
    '🧑🏿‍💻' => 'tecnòleg: pell molt fosca',
    '👨🏻‍💻' => 'home tecnòleg: pell molt clara',
    '👨🏼‍💻' => 'home tecnòleg: pell bastant clara',
    '👨🏽‍💻' => 'home tecnòleg: pell morena',
    '👨🏾‍💻' => 'home tecnòleg: pell fosca',
    '👨🏿‍💻' => 'home tecnòleg: pell molt fosca',
    '👩🏻‍💻' => 'tecnòloga: pell molt clara',
    '👩🏼‍💻' => 'tecnòloga: pell bastant clara',
    '👩🏽‍💻' => 'tecnòloga: pell morena',
    '👩🏾‍💻' => 'tecnòloga: pell fosca',
    '👩🏿‍💻' => 'tecnòloga: pell molt fosca',
    '🧑🏻‍🎤' => 'cantant: pell molt clara',
    '🧑🏼‍🎤' => 'cantant: pell bastant clara',
    '🧑🏽‍🎤' => 'cantant: pell morena',
    '🧑🏾‍🎤' => 'cantant: pell fosca',
    '🧑🏿‍🎤' => 'cantant: pell molt fosca',
    '👨🏻‍🎤' => 'cantant home: pell molt clara',
    '👨🏼‍🎤' => 'cantant home: pell bastant clara',
    '👨🏽‍🎤' => 'cantant home: pell morena',
    '👨🏾‍🎤' => 'cantant home: pell fosca',
    '👨🏿‍🎤' => 'cantant home: pell molt fosca',
    '👩🏻‍🎤' => 'cantant dona: pell molt clara',
    '👩🏼‍🎤' => 'cantant dona: pell bastant clara',
    '👩🏽‍🎤' => 'cantant dona: pell morena',
    '👩🏾‍🎤' => 'cantant dona: pell fosca',
    '👩🏿‍🎤' => 'cantant dona: pell molt fosca',
    '🧑🏻‍🎨' => 'artista: pell molt clara',
    '🧑🏼‍🎨' => 'artista: pell bastant clara',
    '🧑🏽‍🎨' => 'artista: pell morena',
    '🧑🏾‍🎨' => 'artista: pell fosca',
    '🧑🏿‍🎨' => 'artista: pell molt fosca',
    '👨🏻‍🎨' => 'artista home: pell molt clara',
    '👨🏼‍🎨' => 'artista home: pell bastant clara',
    '👨🏽‍🎨' => 'artista home: pell morena',
    '👨🏾‍🎨' => 'artista home: pell fosca',
    '👨🏿‍🎨' => 'artista home: pell molt fosca',
    '👩🏻‍🎨' => 'artista dona: pell molt clara',
    '👩🏼‍🎨' => 'artista dona: pell bastant clara',
    '👩🏽‍🎨' => 'artista dona: pell morena',
    '👩🏾‍🎨' => 'artista dona: pell fosca',
    '👩🏿‍🎨' => 'artista dona: pell molt fosca',
    '🧑🏻‍✈' => 'pilot: pell molt clara',
    '🧑🏼‍✈' => 'pilot: pell bastant clara',
    '🧑🏽‍✈' => 'pilot: pell morena',
    '🧑🏾‍✈' => 'pilot: pell fosca',
    '🧑🏿‍✈' => 'pilot: pell molt fosca',
    '👨🏻‍✈' => 'home pilot: pell molt clara',
    '👨🏼‍✈' => 'home pilot: pell bastant clara',
    '👨🏽‍✈' => 'home pilot: pell morena',
    '👨🏾‍✈' => 'home pilot: pell fosca',
    '👨🏿‍✈' => 'home pilot: pell molt fosca',
    '👩🏻‍✈' => 'dona pilot: pell molt clara',
    '👩🏼‍✈' => 'dona pilot: pell bastant clara',
    '👩🏽‍✈' => 'dona pilot: pell morena',
    '👩🏾‍✈' => 'dona pilot: pell fosca',
    '👩🏿‍✈' => 'dona pilot: pell molt fosca',
    '🧑🏻‍🚀' => 'astronauta: pell molt clara',
    '🧑🏼‍🚀' => 'astronauta: pell bastant clara',
    '🧑🏽‍🚀' => 'astronauta: pell morena',
    '🧑🏾‍🚀' => 'astronauta: pell fosca',
    '🧑🏿‍🚀' => 'astronauta: pell molt fosca',
    '👨🏻‍🚀' => 'home astronauta: pell molt clara',
    '👨🏼‍🚀' => 'home astronauta: pell bastant clara',
    '👨🏽‍🚀' => 'home astronauta: pell morena',
    '👨🏾‍🚀' => 'home astronauta: pell fosca',
    '👨🏿‍🚀' => 'home astronauta: pell molt fosca',
    '👩🏻‍🚀' => 'dona astronauta: pell molt clara',
    '👩🏼‍🚀' => 'dona astronauta: pell bastant clara',
    '👩🏽‍🚀' => 'dona astronauta: pell morena',
    '👩🏾‍🚀' => 'dona astronauta: pell fosca',
    '👩🏿‍🚀' => 'dona astronauta: pell molt fosca',
    '🧑🏻‍🚒' => 'bomber: pell molt clara',
    '🧑🏼‍🚒' => 'bomber: pell bastant clara',
    '🧑🏽‍🚒' => 'bomber: pell morena',
    '🧑🏾‍🚒' => 'bomber: pell fosca',
    '🧑🏿‍🚒' => 'bomber: pell molt fosca',
    '👨🏻‍🚒' => 'home bomber: pell molt clara',
    '👨🏼‍🚒' => 'home bomber: pell bastant clara',
    '👨🏽‍🚒' => 'home bomber: pell morena',
    '👨🏾‍🚒' => 'home bomber: pell fosca',
    '👨🏿‍🚒' => 'home bomber: pell molt fosca',
    '👩🏻‍🚒' => 'bombera: pell molt clara',
    '👩🏼‍🚒' => 'bombera: pell bastant clara',
    '👩🏽‍🚒' => 'bombera: pell morena',
    '👩🏾‍🚒' => 'bombera: pell fosca',
    '👩🏿‍🚒' => 'bombera: pell molt fosca',
    '👮🏻‍♂' => 'agent de policia home: pell molt clara',
    '👮🏼‍♂' => 'agent de policia home: pell bastant clara',
    '👮🏽‍♂' => 'agent de policia home: pell morena',
    '👮🏾‍♂' => 'agent de policia home: pell fosca',
    '👮🏿‍♂' => 'agent de policia home: pell molt fosca',
    '👮🏻‍♀' => 'agent de policia dona: pell molt clara',
    '👮🏼‍♀' => 'agent de policia dona: pell bastant clara',
    '👮🏽‍♀' => 'agent de policia dona: pell morena',
    '👮🏾‍♀' => 'agent de policia dona: pell fosca',
    '👮🏿‍♀' => 'agent de policia dona: pell molt fosca',
    '🕵🏻‍♂' => 'detectiu home: pell molt clara',
    '🕵🏼‍♂' => 'detectiu home: pell bastant clara',
    '🕵🏽‍♂' => 'detectiu home: pell morena',
    '🕵🏾‍♂' => 'detectiu home: pell fosca',
    '🕵🏿‍♂' => 'detectiu home: pell molt fosca',
    '🕵🏻‍♀' => 'detectiu dona: pell molt clara',
    '🕵🏼‍♀' => 'detectiu dona: pell bastant clara',
    '🕵🏽‍♀' => 'detectiu dona: pell morena',
    '🕵🏾‍♀' => 'detectiu dona: pell fosca',
    '🕵🏿‍♀' => 'detectiu dona: pell molt fosca',
    '💂🏻‍♂' => 'home guarda: pell molt clara',
    '💂🏼‍♂' => 'home guarda: pell bastant clara',
    '💂🏽‍♂' => 'home guarda: pell morena',
    '💂🏾‍♂' => 'home guarda: pell fosca',
    '💂🏿‍♂' => 'home guarda: pell molt fosca',
    '💂🏻‍♀' => 'dona guarda: pell molt clara',
    '💂🏼‍♀' => 'dona guarda: pell bastant clara',
    '💂🏽‍♀' => 'dona guarda: pell morena',
    '💂🏾‍♀' => 'dona guarda: pell fosca',
    '💂🏿‍♀' => 'dona guarda: pell molt fosca',
    '👷🏻‍♂' => 'home paleta: pell molt clara',
    '👷🏼‍♂' => 'home paleta: pell bastant clara',
    '👷🏽‍♂' => 'home paleta: pell morena',
    '👷🏾‍♂' => 'home paleta: pell fosca',
    '👷🏿‍♂' => 'home paleta: pell molt fosca',
    '👷🏻‍♀' => 'dona paleta: pell molt clara',
    '👷🏼‍♀' => 'dona paleta: pell bastant clara',
    '👷🏽‍♀' => 'dona paleta: pell morena',
    '👷🏾‍♀' => 'dona paleta: pell fosca',
    '👷🏿‍♀' => 'dona paleta: pell molt fosca',
    '👳🏻‍♂' => 'home amb turbant: pell molt clara',
    '👳🏼‍♂' => 'home amb turbant: pell bastant clara',
    '👳🏽‍♂' => 'home amb turbant: pell morena',
    '👳🏾‍♂' => 'home amb turbant: pell fosca',
    '👳🏿‍♂' => 'home amb turbant: pell molt fosca',
    '👳🏻‍♀' => 'dona amb turbant: pell molt clara',
    '👳🏼‍♀' => 'dona amb turbant: pell bastant clara',
    '👳🏽‍♀' => 'dona amb turbant: pell morena',
    '👳🏾‍♀' => 'dona amb turbant: pell fosca',
    '👳🏿‍♀' => 'dona amb turbant: pell molt fosca',
    '🤵🏻‍♂' => 'home amb esmòquing: pell molt clara',
    '🤵🏼‍♂' => 'home amb esmòquing: pell bastant clara',
    '🤵🏽‍♂' => 'home amb esmòquing: pell morena',
    '🤵🏾‍♂' => 'home amb esmòquing: pell fosca',
    '🤵🏿‍♂' => 'home amb esmòquing: pell molt fosca',
    '🤵🏻‍♀' => 'dona amb esmòquing: pell molt clara',
    '🤵🏼‍♀' => 'dona amb esmòquing: pell bastant clara',
    '🤵🏽‍♀' => 'dona amb esmòquing: pell morena',
    '🤵🏾‍♀' => 'dona amb esmòquing: pell fosca',
    '🤵🏿‍♀' => 'dona amb esmòquing: pell molt fosca',
    '👰🏻‍♂' => 'home amb vel: pell molt clara',
    '👰🏼‍♂' => 'home amb vel: pell bastant clara',
    '👰🏽‍♂' => 'home amb vel: pell morena',
    '👰🏾‍♂' => 'home amb vel: pell fosca',
    '👰🏿‍♂' => 'home amb vel: pell molt fosca',
    '👰🏻‍♀' => 'dona amb vel: pell molt clara',
    '👰🏼‍♀' => 'dona amb vel: pell bastant clara',
    '👰🏽‍♀' => 'dona amb vel: pell morena',
    '👰🏾‍♀' => 'dona amb vel: pell fosca',
    '👰🏿‍♀' => 'dona amb vel: pell molt fosca',
    '👩🏻‍🍼' => 'dona que alleta un bebè: pell molt clara',
    '👩🏼‍🍼' => 'dona que alleta un bebè: pell bastant clara',
    '👩🏽‍🍼' => 'dona que alleta un bebè: pell morena',
    '👩🏾‍🍼' => 'dona que alleta un bebè: pell fosca',
    '👩🏿‍🍼' => 'dona que alleta un bebè: pell molt fosca',
    '👨🏻‍🍼' => 'home que alleta un bebè: pell molt clara',
    '👨🏼‍🍼' => 'home que alleta un bebè: pell bastant clara',
    '👨🏽‍🍼' => 'home que alleta un bebè: pell morena',
    '👨🏾‍🍼' => 'home que alleta un bebè: pell fosca',
    '👨🏿‍🍼' => 'home que alleta un bebè: pell molt fosca',
    '🧑🏻‍🍼' => 'persona que alleta un bebè: pell molt clara',
    '🧑🏼‍🍼' => 'persona que alleta un bebè: pell bastant clara',
    '🧑🏽‍🍼' => 'persona que alleta un bebè: pell morena',
    '🧑🏾‍🍼' => 'persona que alleta un bebè: pell fosca',
    '🧑🏿‍🍼' => 'persona que alleta un bebè: pell molt fosca',
    '🧑🏻‍🎄' => 'Noel: pell molt clara',
    '🧑🏼‍🎄' => 'Noel: pell bastant clara',
    '🧑🏽‍🎄' => 'Noel: pell morena',
    '🧑🏾‍🎄' => 'Noel: pell fosca',
    '🧑🏿‍🎄' => 'Noel: pell molt fosca',
    '🦸🏻‍♂' => 'home superheroi: pell molt clara',
    '🦸🏼‍♂' => 'home superheroi: pell bastant clara',
    '🦸🏽‍♂' => 'home superheroi: pell morena',
    '🦸🏾‍♂' => 'home superheroi: pell fosca',
    '🦸🏿‍♂' => 'home superheroi: pell molt fosca',
    '🦸🏻‍♀' => 'dona superheroïna: pell molt clara',
    '🦸🏼‍♀' => 'dona superheroïna: pell bastant clara',
    '🦸🏽‍♀' => 'dona superheroïna: pell morena',
    '🦸🏾‍♀' => 'dona superheroïna: pell fosca',
    '🦸🏿‍♀' => 'dona superheroïna: pell molt fosca',
    '🦹🏻‍♂' => 'home superdolent: pell molt clara',
    '🦹🏼‍♂' => 'home superdolent: pell bastant clara',
    '🦹🏽‍♂' => 'home superdolent: pell morena',
    '🦹🏾‍♂' => 'home superdolent: pell fosca',
    '🦹🏿‍♂' => 'home superdolent: pell molt fosca',
    '🦹🏻‍♀' => 'dona superdolenta: pell molt clara',
    '🦹🏼‍♀' => 'dona superdolenta: pell bastant clara',
    '🦹🏽‍♀' => 'dona superdolenta: pell morena',
    '🦹🏾‍♀' => 'dona superdolenta: pell fosca',
    '🦹🏿‍♀' => 'dona superdolenta: pell molt fosca',
    '🧙🏻‍♂' => 'home mag: pell molt clara',
    '🧙🏼‍♂' => 'home mag: pell bastant clara',
    '🧙🏽‍♂' => 'home mag: pell morena',
    '🧙🏾‍♂' => 'home mag: pell fosca',
    '🧙🏿‍♂' => 'home mag: pell molt fosca',
    '🧙🏻‍♀' => 'dona maga: pell molt clara',
    '🧙🏼‍♀' => 'dona maga: pell bastant clara',
    '🧙🏽‍♀' => 'dona maga: pell morena',
    '🧙🏾‍♀' => 'dona maga: pell fosca',
    '🧙🏿‍♀' => 'dona maga: pell molt fosca',
    '🧚🏻‍♂' => 'home fada: pell molt clara',
    '🧚🏼‍♂' => 'home fada: pell bastant clara',
    '🧚🏽‍♂' => 'home fada: pell morena',
    '🧚🏾‍♂' => 'home fada: pell fosca',
    '🧚🏿‍♂' => 'home fada: pell molt fosca',
    '🧚🏻‍♀' => 'dona fada: pell molt clara',
    '🧚🏼‍♀' => 'dona fada: pell bastant clara',
    '🧚🏽‍♀' => 'dona fada: pell morena',
    '🧚🏾‍♀' => 'dona fada: pell fosca',
    '🧚🏿‍♀' => 'dona fada: pell molt fosca',
    '🧛🏻‍♂' => 'home vampir: pell molt clara',
    '🧛🏼‍♂' => 'home vampir: pell bastant clara',
    '🧛🏽‍♂' => 'home vampir: pell morena',
    '🧛🏾‍♂' => 'home vampir: pell fosca',
    '🧛🏿‍♂' => 'home vampir: pell molt fosca',
    '🧛🏻‍♀' => 'dona vampir: pell molt clara',
    '🧛🏼‍♀' => 'dona vampir: pell bastant clara',
    '🧛🏽‍♀' => 'dona vampir: pell morena',
    '🧛🏾‍♀' => 'dona vampir: pell fosca',
    '🧛🏿‍♀' => 'dona vampir: pell molt fosca',
    '🧜🏻‍♂' => 'home sirena: pell molt clara',
    '🧜🏼‍♂' => 'home sirena: pell bastant clara',
    '🧜🏽‍♂' => 'home sirena: pell morena',
    '🧜🏾‍♂' => 'home sirena: pell fosca',
    '🧜🏿‍♂' => 'home sirena: pell molt fosca',
    '🧜🏻‍♀' => 'sirena: pell molt clara',
    '🧜🏼‍♀' => 'sirena: pell bastant clara',
    '🧜🏽‍♀' => 'sirena: pell morena',
    '🧜🏾‍♀' => 'sirena: pell fosca',
    '🧜🏿‍♀' => 'sirena: pell molt fosca',
    '🧝🏻‍♂' => 'home elf: pell molt clara',
    '🧝🏼‍♂' => 'home elf: pell bastant clara',
    '🧝🏽‍♂' => 'home elf: pell morena',
    '🧝🏾‍♂' => 'home elf: pell fosca',
    '🧝🏿‍♂' => 'home elf: pell molt fosca',
    '🧝🏻‍♀' => 'dona elfa: pell molt clara',
    '🧝🏼‍♀' => 'dona elfa: pell bastant clara',
    '🧝🏽‍♀' => 'dona elfa: pell morena',
    '🧝🏾‍♀' => 'dona elfa: pell fosca',
    '🧝🏿‍♀' => 'dona elfa: pell molt fosca',
    '💆🏻‍♂' => 'home que rep un massatge al cap: pell molt clara',
    '💆🏼‍♂' => 'home que rep un massatge al cap: pell bastant clara',
    '💆🏽‍♂' => 'home que rep un massatge al cap: pell morena',
    '💆🏾‍♂' => 'home que rep un massatge al cap: pell fosca',
    '💆🏿‍♂' => 'home que rep un massatge al cap: pell molt fosca',
    '💆🏻‍♀' => 'dona que rep un massatge al cap: pell molt clara',
    '💆🏼‍♀' => 'dona que rep un massatge al cap: pell bastant clara',
    '💆🏽‍♀' => 'dona que rep un massatge al cap: pell morena',
    '💆🏾‍♀' => 'dona que rep un massatge al cap: pell fosca',
    '💆🏿‍♀' => 'dona que rep un massatge al cap: pell molt fosca',
    '💇🏻‍♂' => 'home que es talla els cabells: pell molt clara',
    '💇🏼‍♂' => 'home que es talla els cabells: pell bastant clara',
    '💇🏽‍♂' => 'home que es talla els cabells: pell morena',
    '💇🏾‍♂' => 'home que es talla els cabells: pell fosca',
    '💇🏿‍♂' => 'home que es talla els cabells: pell molt fosca',
    '💇🏻‍♀' => 'dona que es talla els cabells: pell molt clara',
    '💇🏼‍♀' => 'dona que es talla els cabells: pell bastant clara',
    '💇🏽‍♀' => 'dona que es talla els cabells: pell morena',
    '💇🏾‍♀' => 'dona que es talla els cabells: pell fosca',
    '💇🏿‍♀' => 'dona que es talla els cabells: pell molt fosca',
    '🚶🏻‍♂' => 'home que camina: pell molt clara',
    '🚶🏼‍♂' => 'home que camina: pell bastant clara',
    '🚶🏽‍♂' => 'home que camina: pell morena',
    '🚶🏾‍♂' => 'home que camina: pell fosca',
    '🚶🏿‍♂' => 'home que camina: pell molt fosca',
    '🚶🏻‍♀' => 'dona que camina: pell molt clara',
    '🚶🏼‍♀' => 'dona que camina: pell bastant clara',
    '🚶🏽‍♀' => 'dona que camina: pell morena',
    '🚶🏾‍♀' => 'dona que camina: pell fosca',
    '🚶🏿‍♀' => 'dona que camina: pell molt fosca',
    '🚶🏻‍➡' => 'persona que camina: pell molt clara i que mira a la dreta',
    '🚶🏼‍➡' => 'persona que camina: pell bastant clara i que mira a la dreta',
    '🚶🏽‍➡' => 'persona que camina: pell morena i que mira a la dreta',
    '🚶🏾‍➡' => 'persona que camina: pell fosca i que mira a la dreta',
    '🚶🏿‍➡' => 'persona que camina: pell molt fosca i que mira a la dreta',
    '🧍🏻‍♂' => 'home dret: pell molt clara',
    '🧍🏼‍♂' => 'home dret: pell bastant clara',
    '🧍🏽‍♂' => 'home dret: pell morena',
    '🧍🏾‍♂' => 'home dret: pell fosca',
    '🧍🏿‍♂' => 'home dret: pell molt fosca',
    '🧍🏻‍♀' => 'dona dreta: pell molt clara',
    '🧍🏼‍♀' => 'dona dreta: pell bastant clara',
    '🧍🏽‍♀' => 'dona dreta: pell morena',
    '🧍🏾‍♀' => 'dona dreta: pell fosca',
    '🧍🏿‍♀' => 'dona dreta: pell molt fosca',
    '🧎🏻‍♂' => 'home agenollat: pell molt clara',
    '🧎🏼‍♂' => 'home agenollat: pell bastant clara',
    '🧎🏽‍♂' => 'home agenollat: pell morena',
    '🧎🏾‍♂' => 'home agenollat: pell fosca',
    '🧎🏿‍♂' => 'home agenollat: pell molt fosca',
    '🧎🏻‍♀' => 'dona agenollada: pell molt clara',
    '🧎🏼‍♀' => 'dona agenollada: pell bastant clara',
    '🧎🏽‍♀' => 'dona agenollada: pell morena',
    '🧎🏾‍♀' => 'dona agenollada: pell fosca',
    '🧎🏿‍♀' => 'dona agenollada: pell molt fosca',
    '🧎🏻‍➡' => 'persona agenollada: pell molt clara i que mira a la dreta',
    '🧎🏼‍➡' => 'persona agenollada: pell bastant clara i que mira a la dreta',
    '🧎🏽‍➡' => 'persona agenollada: pell morena i que mira a la dreta',
    '🧎🏾‍➡' => 'persona agenollada: pell fosca i que mira a la dreta',
    '🧎🏿‍➡' => 'persona agenollada: pell molt fosca i que mira a la dreta',
    '🧑🏻‍🦯' => 'persona amb un bastó per a invidents: pell molt clara',
    '🧑🏼‍🦯' => 'persona amb un bastó per a invidents: pell bastant clara',
    '🧑🏽‍🦯' => 'persona amb un bastó per a invidents: pell morena',
    '🧑🏾‍🦯' => 'persona amb un bastó per a invidents: pell fosca',
    '🧑🏿‍🦯' => 'persona amb un bastó per a invidents: pell molt fosca',
    '👨🏻‍🦯' => 'home amb un bastó per a invidents: pell molt clara',
    '👨🏼‍🦯' => 'home amb un bastó per a invidents: pell bastant clara',
    '👨🏽‍🦯' => 'home amb un bastó per a invidents: pell morena',
    '👨🏾‍🦯' => 'home amb un bastó per a invidents: pell fosca',
    '👨🏿‍🦯' => 'home amb un bastó per a invidents: pell molt fosca',
    '👩🏻‍🦯' => 'dona amb un bastó per a invidents: pell molt clara',
    '👩🏼‍🦯' => 'dona amb un bastó per a invidents: pell bastant clara',
    '👩🏽‍🦯' => 'dona amb un bastó per a invidents: pell morena',
    '👩🏾‍🦯' => 'dona amb un bastó per a invidents: pell fosca',
    '👩🏿‍🦯' => 'dona amb un bastó per a invidents: pell molt fosca',
    '🧑🏻‍🦼' => 'persona amb una cadira de rodes elèctrica: pell molt clara',
    '🧑🏼‍🦼' => 'persona amb una cadira de rodes elèctrica: pell bastant clara',
    '🧑🏽‍🦼' => 'persona amb una cadira de rodes elèctrica: pell morena',
    '🧑🏾‍🦼' => 'persona amb una cadira de rodes elèctrica: pell fosca',
    '🧑🏿‍🦼' => 'persona amb una cadira de rodes elèctrica: pell molt fosca',
    '👨🏻‍🦼' => 'home amb una cadira de rodes elèctrica: pell molt clara',
    '👨🏼‍🦼' => 'home amb una cadira de rodes elèctrica: pell bastant clara',
    '👨🏽‍🦼' => 'home amb una cadira de rodes elèctrica: pell morena',
    '👨🏾‍🦼' => 'home amb una cadira de rodes elèctrica: pell fosca',
    '👨🏿‍🦼' => 'home amb una cadira de rodes elèctrica: pell molt fosca',
    '👩🏻‍🦼' => 'dona amb una cadira de rodes elèctrica: pell molt clara',
    '👩🏼‍🦼' => 'dona amb una cadira de rodes elèctrica: pell bastant clara',
    '👩🏽‍🦼' => 'dona amb una cadira de rodes elèctrica: pell morena',
    '👩🏾‍🦼' => 'dona amb una cadira de rodes elèctrica: pell fosca',
    '👩🏿‍🦼' => 'dona amb una cadira de rodes elèctrica: pell molt fosca',
    '🧑🏻‍🦽' => 'persona amb una cadira de rodes manual: pell molt clara',
    '🧑🏼‍🦽' => 'persona amb una cadira de rodes manual: pell bastant clara',
    '🧑🏽‍🦽' => 'persona amb una cadira de rodes manual: pell morena',
    '🧑🏾‍🦽' => 'persona amb una cadira de rodes manual: pell fosca',
    '🧑🏿‍🦽' => 'persona amb una cadira de rodes manual: pell molt fosca',
    '👨🏻‍🦽' => 'home amb una cadira de rodes manual: pell molt clara',
    '👨🏼‍🦽' => 'home amb una cadira de rodes manual: pell bastant clara',
    '👨🏽‍🦽' => 'home amb una cadira de rodes manual: pell morena',
    '👨🏾‍🦽' => 'home amb una cadira de rodes manual: pell fosca',
    '👨🏿‍🦽' => 'home amb una cadira de rodes manual: pell molt fosca',
    '👩🏻‍🦽' => 'dona amb una cadira de rodes manual: pell molt clara',
    '👩🏼‍🦽' => 'dona amb una cadira de rodes manual: pell bastant clara',
    '👩🏽‍🦽' => 'dona amb una cadira de rodes manual: pell morena',
    '👩🏾‍🦽' => 'dona amb una cadira de rodes manual: pell fosca',
    '👩🏿‍🦽' => 'dona amb una cadira de rodes manual: pell molt fosca',
    '🏃🏻‍♂' => 'home que corre: pell molt clara',
    '🏃🏼‍♂' => 'home que corre: pell bastant clara',
    '🏃🏽‍♂' => 'home que corre: pell morena',
    '🏃🏾‍♂' => 'home que corre: pell fosca',
    '🏃🏿‍♂' => 'home que corre: pell molt fosca',
    '🏃🏻‍♀' => 'dona que corre: pell molt clara',
    '🏃🏼‍♀' => 'dona que corre: pell bastant clara',
    '🏃🏽‍♀' => 'dona que corre: pell morena',
    '🏃🏾‍♀' => 'dona que corre: pell fosca',
    '🏃🏿‍♀' => 'dona que corre: pell molt fosca',
    '🏃🏻‍➡' => 'persona que corre: pell molt clara i que mira a la dreta',
    '🏃🏼‍➡' => 'persona que corre: pell bastant clara i que mira a la dreta',
    '🏃🏽‍➡' => 'persona que corre: pell morena i que mira a la dreta',
    '🏃🏾‍➡' => 'persona que corre: pell fosca i que mira a la dreta',
    '🏃🏿‍➡' => 'persona que corre: pell molt fosca i que mira a la dreta',
    '👯🏻‍♀' => 'dones que ballen disfressades: pell molt clara',
    '👯🏼‍♀' => 'dones que ballen disfressades: pell bastant clara',
    '👯🏽‍♀' => 'dones que ballen disfressades: pell morena',
    '👯🏾‍♀' => 'dones que ballen disfressades: pell fosca',
    '👯🏿‍♀' => 'dones que ballen disfressades: pell molt fosca',
    '👯🏻‍♂' => 'homes que ballen disfressats: pell molt clara',
    '👯🏼‍♂' => 'homes que ballen disfressats: pell bastant clara',
    '👯🏽‍♂' => 'homes que ballen disfressats: pell morena',
    '👯🏾‍♂' => 'homes que ballen disfressats: pell fosca',
    '👯🏿‍♂' => 'homes que ballen disfressats: pell molt fosca',
    '🧖🏻‍♂' => 'home a la sauna: pell molt clara',
    '🧖🏼‍♂' => 'home a la sauna: pell bastant clara',
    '🧖🏽‍♂' => 'home a la sauna: pell morena',
    '🧖🏾‍♂' => 'home a la sauna: pell fosca',
    '🧖🏿‍♂' => 'home a la sauna: pell molt fosca',
    '🧖🏻‍♀' => 'dona a la sauna: pell molt clara',
    '🧖🏼‍♀' => 'dona a la sauna: pell bastant clara',
    '🧖🏽‍♀' => 'dona a la sauna: pell morena',
    '🧖🏾‍♀' => 'dona a la sauna: pell fosca',
    '🧖🏿‍♀' => 'dona a la sauna: pell molt fosca',
    '🧗🏻‍♂' => 'escalador: pell molt clara',
    '🧗🏼‍♂' => 'escalador: pell bastant clara',
    '🧗🏽‍♂' => 'escalador: pell morena',
    '🧗🏾‍♂' => 'escalador: pell fosca',
    '🧗🏿‍♂' => 'escalador: pell molt fosca',
    '🧗🏻‍♀' => 'escaladora: pell molt clara',
    '🧗🏼‍♀' => 'escaladora: pell bastant clara',
    '🧗🏽‍♀' => 'escaladora: pell morena',
    '🧗🏾‍♀' => 'escaladora: pell fosca',
    '🧗🏿‍♀' => 'escaladora: pell molt fosca',
    '🏌🏻‍♂' => 'home que juga a golf: pell molt clara',
    '🏌🏼‍♂' => 'home que juga a golf: pell bastant clara',
    '🏌🏽‍♂' => 'home que juga a golf: pell morena',
    '🏌🏾‍♂' => 'home que juga a golf: pell fosca',
    '🏌🏿‍♂' => 'home que juga a golf: pell molt fosca',
    '🏌🏻‍♀' => 'dona que juga a golf: pell molt clara',
    '🏌🏼‍♀' => 'dona que juga a golf: pell bastant clara',
    '🏌🏽‍♀' => 'dona que juga a golf: pell morena',
    '🏌🏾‍♀' => 'dona que juga a golf: pell fosca',
    '🏌🏿‍♀' => 'dona que juga a golf: pell molt fosca',
    '🏄🏻‍♂' => 'home que fa surf: pell molt clara',
    '🏄🏼‍♂' => 'home que fa surf: pell bastant clara',
    '🏄🏽‍♂' => 'home que fa surf: pell morena',
    '🏄🏾‍♂' => 'home que fa surf: pell fosca',
    '🏄🏿‍♂' => 'home que fa surf: pell molt fosca',
    '🏄🏻‍♀' => 'dona que fa surf: pell molt clara',
    '🏄🏼‍♀' => 'dona que fa surf: pell bastant clara',
    '🏄🏽‍♀' => 'dona que fa surf: pell morena',
    '🏄🏾‍♀' => 'dona que fa surf: pell fosca',
    '🏄🏿‍♀' => 'dona que fa surf: pell molt fosca',
    '🚣🏻‍♂' => 'home que rema en una barca: pell molt clara',
    '🚣🏼‍♂' => 'home que rema en una barca: pell bastant clara',
    '🚣🏽‍♂' => 'home que rema en una barca: pell morena',
    '🚣🏾‍♂' => 'home que rema en una barca: pell fosca',
    '🚣🏿‍♂' => 'home que rema en una barca: pell molt fosca',
    '🚣🏻‍♀' => 'dona que rema en una barca: pell molt clara',
    '🚣🏼‍♀' => 'dona que rema en una barca: pell bastant clara',
    '🚣🏽‍♀' => 'dona que rema en una barca: pell morena',
    '🚣🏾‍♀' => 'dona que rema en una barca: pell fosca',
    '🚣🏿‍♀' => 'dona que rema en una barca: pell molt fosca',
    '🏊🏻‍♂' => 'home que neda: pell molt clara',
    '🏊🏼‍♂' => 'home que neda: pell bastant clara',
    '🏊🏽‍♂' => 'home que neda: pell morena',
    '🏊🏾‍♂' => 'home que neda: pell fosca',
    '🏊🏿‍♂' => 'home que neda: pell molt fosca',
    '🏊🏻‍♀' => 'dona que neda: pell molt clara',
    '🏊🏼‍♀' => 'dona que neda: pell bastant clara',
    '🏊🏽‍♀' => 'dona que neda: pell morena',
    '🏊🏾‍♀' => 'dona que neda: pell fosca',
    '🏊🏿‍♀' => 'dona que neda: pell molt fosca',
    '⛹🏻‍♂' => 'home amb una pilota: pell molt clara',
    '⛹🏼‍♂' => 'home amb una pilota: pell bastant clara',
    '⛹🏽‍♂' => 'home amb una pilota: pell morena',
    '⛹🏾‍♂' => 'home amb una pilota: pell fosca',
    '⛹🏿‍♂' => 'home amb una pilota: pell molt fosca',
    '⛹🏻‍♀' => 'dona amb una pilota: pell molt clara',
    '⛹🏼‍♀' => 'dona amb una pilota: pell bastant clara',
    '⛹🏽‍♀' => 'dona amb una pilota: pell morena',
    '⛹🏾‍♀' => 'dona amb una pilota: pell fosca',
    '⛹🏿‍♀' => 'dona amb una pilota: pell molt fosca',
    '🏋🏻‍♂' => 'home que aixeca pesos: pell molt clara',
    '🏋🏼‍♂' => 'home que aixeca pesos: pell bastant clara',
    '🏋🏽‍♂' => 'home que aixeca pesos: pell morena',
    '🏋🏾‍♂' => 'home que aixeca pesos: pell fosca',
    '🏋🏿‍♂' => 'home que aixeca pesos: pell molt fosca',
    '🏋🏻‍♀' => 'dona que aixeca pesos: pell molt clara',
    '🏋🏼‍♀' => 'dona que aixeca pesos: pell bastant clara',
    '🏋🏽‍♀' => 'dona que aixeca pesos: pell morena',
    '🏋🏾‍♀' => 'dona que aixeca pesos: pell fosca',
    '🏋🏿‍♀' => 'dona que aixeca pesos: pell molt fosca',
    '🚴🏻‍♂' => 'ciclista home: pell molt clara',
    '🚴🏼‍♂' => 'ciclista home: pell bastant clara',
    '🚴🏽‍♂' => 'ciclista home: pell morena',
    '🚴🏾‍♂' => 'ciclista home: pell fosca',
    '🚴🏿‍♂' => 'ciclista home: pell molt fosca',
    '🚴🏻‍♀' => 'ciclista dona: pell molt clara',
    '🚴🏼‍♀' => 'ciclista dona: pell bastant clara',
    '🚴🏽‍♀' => 'ciclista dona: pell morena',
    '🚴🏾‍♀' => 'ciclista dona: pell fosca',
    '🚴🏿‍♀' => 'ciclista dona: pell molt fosca',
    '🚵🏻‍♂' => 'ciclista de muntanya home: pell molt clara',
    '🚵🏼‍♂' => 'ciclista de muntanya home: pell bastant clara',
    '🚵🏽‍♂' => 'ciclista de muntanya home: pell morena',
    '🚵🏾‍♂' => 'ciclista de muntanya home: pell fosca',
    '🚵🏿‍♂' => 'ciclista de muntanya home: pell molt fosca',
    '🚵🏻‍♀' => 'ciclista de muntanya dona: pell molt clara',
    '🚵🏼‍♀' => 'ciclista de muntanya dona: pell bastant clara',
    '🚵🏽‍♀' => 'ciclista de muntanya dona: pell morena',
    '🚵🏾‍♀' => 'ciclista de muntanya dona: pell fosca',
    '🚵🏿‍♀' => 'ciclista de muntanya dona: pell molt fosca',
    '🤸🏻‍♂' => 'home que fa la roda: pell molt clara',
    '🤸🏼‍♂' => 'home que fa la roda: pell bastant clara',
    '🤸🏽‍♂' => 'home que fa la roda: pell morena',
    '🤸🏾‍♂' => 'home que fa la roda: pell fosca',
    '🤸🏿‍♂' => 'home que fa la roda: pell molt fosca',
    '🤸🏻‍♀' => 'dona que fa la roda: pell molt clara',
    '🤸🏼‍♀' => 'dona que fa la roda: pell bastant clara',
    '🤸🏽‍♀' => 'dona que fa la roda: pell morena',
    '🤸🏾‍♀' => 'dona que fa la roda: pell fosca',
    '🤸🏿‍♀' => 'dona que fa la roda: pell molt fosca',
    '🤼🏻‍♀' => 'jugadores de lluita: pell molt clara',
    '🤼🏼‍♀' => 'jugadores de lluita: pell bastant clara',
    '🤼🏽‍♀' => 'jugadores de lluita: pell morena',
    '🤼🏾‍♀' => 'jugadores de lluita: pell fosca',
    '🤼🏿‍♀' => 'jugadores de lluita: pell molt fosca',
    '🤼🏻‍♂' => 'jugadors de lluita: pell molt clara',
    '🤼🏼‍♂' => 'jugadors de lluita: pell bastant clara',
    '🤼🏽‍♂' => 'jugadors de lluita: pell morena',
    '🤼🏾‍♂' => 'jugadors de lluita: pell fosca',
    '🤼🏿‍♂' => 'jugadors de lluita: pell molt fosca',
    '🤽🏻‍♂' => 'jugador de waterpolo: pell molt clara',
    '🤽🏼‍♂' => 'jugador de waterpolo: pell bastant clara',
    '🤽🏽‍♂' => 'jugador de waterpolo: pell morena',
    '🤽🏾‍♂' => 'jugador de waterpolo: pell fosca',
    '🤽🏿‍♂' => 'jugador de waterpolo: pell molt fosca',
    '🤽🏻‍♀' => 'jugadora de waterpolo: pell molt clara',
    '🤽🏼‍♀' => 'jugadora de waterpolo: pell bastant clara',
    '🤽🏽‍♀' => 'jugadora de waterpolo: pell morena',
    '🤽🏾‍♀' => 'jugadora de waterpolo: pell fosca',
    '🤽🏿‍♀' => 'jugadora de waterpolo: pell molt fosca',
    '🤾🏻‍♂' => 'jugador d’handbol: pell molt clara',
    '🤾🏼‍♂' => 'jugador d’handbol: pell bastant clara',
    '🤾🏽‍♂' => 'jugador d’handbol: pell morena',
    '🤾🏾‍♂' => 'jugador d’handbol: pell fosca',
    '🤾🏿‍♂' => 'jugador d’handbol: pell molt fosca',
    '🤾🏻‍♀' => 'jugadora d’handbol: pell molt clara',
    '🤾🏼‍♀' => 'jugadora d’handbol: pell bastant clara',
    '🤾🏽‍♀' => 'jugadora d’handbol: pell morena',
    '🤾🏾‍♀' => 'jugadora d’handbol: pell fosca',
    '🤾🏿‍♀' => 'jugadora d’handbol: pell molt fosca',
    '🤹🏻‍♂' => 'malabarista home: pell molt clara',
    '🤹🏼‍♂' => 'malabarista home: pell bastant clara',
    '🤹🏽‍♂' => 'malabarista home: pell morena',
    '🤹🏾‍♂' => 'malabarista home: pell fosca',
    '🤹🏿‍♂' => 'malabarista home: pell molt fosca',
    '🤹🏻‍♀' => 'malabarista dona: pell molt clara',
    '🤹🏼‍♀' => 'malabarista dona: pell bastant clara',
    '🤹🏽‍♀' => 'malabarista dona: pell morena',
    '🤹🏾‍♀' => 'malabarista dona: pell fosca',
    '🤹🏿‍♀' => 'malabarista dona: pell molt fosca',
    '🧘🏻‍♂' => 'home en la posició de lotus: pell molt clara',
    '🧘🏼‍♂' => 'home en la posició de lotus: pell bastant clara',
    '🧘🏽‍♂' => 'home en la posició de lotus: pell morena',
    '🧘🏾‍♂' => 'home en la posició de lotus: pell fosca',
    '🧘🏿‍♂' => 'home en la posició de lotus: pell molt fosca',
    '🧘🏻‍♀' => 'dona en la posició de lotus: pell molt clara',
    '🧘🏼‍♀' => 'dona en la posició de lotus: pell bastant clara',
    '🧘🏽‍♀' => 'dona en la posició de lotus: pell morena',
    '🧘🏾‍♀' => 'dona en la posició de lotus: pell fosca',
    '🧘🏿‍♀' => 'dona en la posició de lotus: pell molt fosca',
    '🧑‍🦰' => 'persona: cabells vermells',
    '🧑‍🦱' => 'persona: cabells arrissats',
    '🧑‍🦳' => 'persona: cabells blancs',
    '🧑‍🦲' => 'persona: calvície',
    '👨‍🦰' => 'home: cabells vermells',
    '👨‍🦱' => 'home: cabells arrissats',
    '👨‍🦳' => 'home: cabells blancs',
    '👨‍🦲' => 'home: calvície',
    '👩‍🦰' => 'dona: cabells vermells',
    '👩‍🦱' => 'dona: cabells arrissats',
    '👩‍🦳' => 'dona: cabells blancs',
    '👩‍🦲' => 'dona: calvície',
    '🚶‍➡' => 'persona que camina: que mira a la dreta',
    '🧎‍➡' => 'persona agenollada: que mira a la dreta',
    '🏃‍➡' => 'persona que corre: que mira a la dreta',
    '👨‍👦' => 'família: home i noi',
    '👨‍👧' => 'família: home i noia',
    '👩‍👦' => 'família: dona i noi',
    '👩‍👧' => 'família: dona i noia',
    '😶‍🌫' => 'cara entre núvols',
    '😮‍💨' => 'cara que exhala',
    '🙂‍↕' => 'cap que tremola verticalment',
    '😵‍💫' => 'cara amb ulls d’espiral',
    '❤‍🔥' => 'cor en flames',
    '❤‍🩹' => 'cor embenat',
    '👁‍🗨' => 'ull dins d’una bafarada',
    '🧔‍♂' => 'home: barba',
    '👱‍♂' => 'home: cabell ros',
    '🧔‍♀' => 'dona: barba',
    '👱‍♀' => 'dona: cabell ros',
    '🙍‍♂' => 'home emmurriat',
    '🙍‍♀' => 'dona emmurriada',
    '🙎‍♂' => 'home enutjat',
    '🙎‍♀' => 'dona enutjada',
    '🙅‍♂' => 'home amb gest de negació',
    '🙅‍♀' => 'dona amb gest de negació',
    '🙆‍♂' => 'home amb gest d’aprovació',
    '🙆‍♀' => 'dona amb gest d’aprovació',
    '💁‍♂' => 'home amb mà inclinada cap amunt',
    '💁‍♀' => 'dona amb mà inclinada cap amunt',
    '🙋‍♂' => 'home amb la mà aixecada',
    '🙋‍♀' => 'dona amb la mà aixecada',
    '🧏‍♂' => 'home sord',
    '🧏‍♀' => 'dona sorda',
    '🙇‍♂' => 'home capcot',
    '🙇‍♀' => 'dona capcota',
    '🤦‍♂' => 'home amb la mà a la cara',
    '🤦‍♀' => 'dona amb la mà a la cara',
    '🤷‍♂' => 'home que arronsa les espatlles',
    '🤷‍♀' => 'dona que arronsa les espatlles',
    '🧑‍⚕' => 'professional de la salut',
    '👨‍⚕' => 'home professional de la salut',
    '👩‍⚕' => 'dona professional de la salut',
    '🧑‍🎓' => 'estudiant',
    '👨‍🎓' => 'noi estudiant',
    '👩‍🎓' => 'noia estudiant',
    '🧑‍🏫' => 'professor',
    '👨‍🏫' => 'home professor',
    '👩‍🏫' => 'professora',
    '🧑‍⚖' => 'jutge',
    '👨‍⚖' => 'home jutge',
    '👩‍⚖' => 'jutgessa',
    '🧑‍🌾' => 'agricultor',
    '👨‍🌾' => 'home pagès',
    '👩‍🌾' => 'agricultora',
    '🧑‍🍳' => 'cuiner',
    '👨‍🍳' => 'home cuiner',
    '👩‍🍳' => 'cuinera',
    '🧑‍🔧' => 'mecànic',
    '👨‍🔧' => 'home mecànic',
    '👩‍🔧' => 'mecànica',
    '🧑‍🏭' => 'operari',
    '👨‍🏭' => 'home operari',
    '👩‍🏭' => 'operària',
    '🧑‍💼' => 'treballador d’oficina',
    '👨‍💼' => 'home treballador d’oficina',
    '👩‍💼' => 'treballadora d’oficina',
    '🧑‍🔬' => 'científic',
    '👨‍🔬' => 'home científic',
    '👩‍🔬' => 'científica',
    '🧑‍💻' => 'tecnòleg',
    '👨‍💻' => 'home tecnòleg',
    '👩‍💻' => 'tecnòloga',
    '🧑‍🎤' => 'cantant',
    '👨‍🎤' => 'cantant home',
    '👩‍🎤' => 'cantant dona',
    '🧑‍🎨' => 'artista',
    '👨‍🎨' => 'artista home',
    '👩‍🎨' => 'artista dona',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'home pilot',
    '👩‍✈' => 'dona pilot',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'home astronauta',
    '👩‍🚀' => 'dona astronauta',
    '🧑‍🚒' => 'bomber',
    '👨‍🚒' => 'home bomber',
    '👩‍🚒' => 'bombera',
    '👮‍♂' => 'agent de policia home',
    '👮‍♀' => 'agent de policia dona',
    '🕵‍♂' => 'detectiu home',
    '🕵‍♀' => 'detectiu dona',
    '💂‍♂' => 'home guarda',
    '💂‍♀' => 'dona guarda',
    '👷‍♂' => 'home paleta',
    '👷‍♀' => 'dona paleta',
    '👳‍♂' => 'home amb turbant',
    '👳‍♀' => 'dona amb turbant',
    '🤵‍♂' => 'home amb esmòquing',
    '🤵‍♀' => 'dona amb esmòquing',
    '👰‍♂' => 'home amb vel',
    '👰‍♀' => 'dona amb vel',
    '👩‍🍼' => 'dona que alleta un bebè',
    '👨‍🍼' => 'home que alleta un bebè',
    '🧑‍🍼' => 'persona que alleta un bebè',
    '🧑‍🎄' => 'Noel',
    '🦸‍♂' => 'home superheroi',
    '🦸‍♀' => 'dona superheroïna',
    '🦹‍♂' => 'home superdolent',
    '🦹‍♀' => 'dona superdolenta',
    '🧙‍♂' => 'home mag',
    '🧙‍♀' => 'dona maga',
    '🧚‍♂' => 'home fada',
    '🧚‍♀' => 'dona fada',
    '🧛‍♂' => 'home vampir',
    '🧛‍♀' => 'dona vampir',
    '🧜‍♂' => 'home sirena',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'home elf',
    '🧝‍♀' => 'dona elfa',
    '🧞‍♂' => 'home geni',
    '🧞‍♀' => 'dona geni',
    '🧟‍♂' => 'home zombi',
    '🧟‍♀' => 'dona zombi',
    '💆‍♂' => 'home que rep un massatge al cap',
    '💆‍♀' => 'dona que rep un massatge al cap',
    '💇‍♂' => 'home que es talla els cabells',
    '💇‍♀' => 'dona que es talla els cabells',
    '🚶‍♂' => 'home que camina',
    '🚶‍♀' => 'dona que camina',
    '🧍‍♂' => 'home dret',
    '🧍‍♀' => 'dona dreta',
    '🧎‍♂' => 'home agenollat',
    '🧎‍♀' => 'dona agenollada',
    '🧑‍🦯' => 'persona amb un bastó per a invidents',
    '👨‍🦯' => 'home amb un bastó per a invidents',
    '👩‍🦯' => 'dona amb un bastó per a invidents',
    '🧑‍🦼' => 'persona amb una cadira de rodes elèctrica',
    '👨‍🦼' => 'home amb una cadira de rodes elèctrica',
    '👩‍🦼' => 'dona amb una cadira de rodes elèctrica',
    '🧑‍🦽' => 'persona amb una cadira de rodes manual',
    '👨‍🦽' => 'home amb una cadira de rodes manual',
    '👩‍🦽' => 'dona amb una cadira de rodes manual',
    '🏃‍♂' => 'home que corre',
    '🏃‍♀' => 'dona que corre',
    '🧑‍🩰' => 'ballarí de ballet',
    '👯‍♂' => 'homes que ballen disfressats',
    '👯‍♀' => 'dones que ballen disfressades',
    '🧖‍♂' => 'home a la sauna',
    '🧖‍♀' => 'dona a la sauna',
    '🧗‍♂' => 'escalador',
    '🧗‍♀' => 'escaladora',
    '🏌‍♂' => 'home que juga a golf',
    '🏌‍♀' => 'dona que juga a golf',
    '🏄‍♂' => 'home que fa surf',
    '🏄‍♀' => 'dona que fa surf',
    '🚣‍♂' => 'home que rema en una barca',
    '🚣‍♀' => 'dona que rema en una barca',
    '🏊‍♂' => 'home que neda',
    '🏊‍♀' => 'dona que neda',
    '⛹‍♂' => 'home amb una pilota',
    '⛹‍♀' => 'dona amb una pilota',
    '🏋‍♂' => 'home que aixeca pesos',
    '🏋‍♀' => 'dona que aixeca pesos',
    '🚴‍♂' => 'ciclista home',
    '🚴‍♀' => 'ciclista dona',
    '🚵‍♂' => 'ciclista de muntanya home',
    '🚵‍♀' => 'ciclista de muntanya dona',
    '🤸‍♂' => 'home que fa la roda',
    '🤸‍♀' => 'dona que fa la roda',
    '🤼‍♂' => 'jugadors de lluita',
    '🤼‍♀' => 'jugadores de lluita',
    '🤽‍♂' => 'jugador de waterpolo',
    '🤽‍♀' => 'jugadora de waterpolo',
    '🤾‍♂' => 'jugador d’handbol',
    '🤾‍♀' => 'jugadora d’handbol',
    '🤹‍♂' => 'malabarista home',
    '🤹‍♀' => 'malabarista dona',
    '🧘‍♂' => 'home en la posició de lotus',
    '🧘‍♀' => 'dona en la posició de lotus',
    '🧑‍🧒' => 'família: adult, infant',
    '🐕‍🦺' => 'gos de servei',
    '🐈‍⬛' => 'gat negre',
    '🐻‍❄' => 'os polar',
    '🐦‍⬛' => 'ocell negre',
    '🐦‍🔥' => 'fènix',
    '🍋‍🟩' => 'llima',
    '🍄‍🟫' => 'bolet marró',
    '⛓‍💥' => 'cadena trencada',
    '🏳‍🌈' => 'bandera de l’arc de Sant Martí',
    '🏳‍⚧' => 'bandera transgènere',
    '🏴‍☠' => 'bandera pirata',
    '👋🏻' => 'mà que saluda: pell molt clara',
    '👋🏼' => 'mà que saluda: pell bastant clara',
    '👋🏽' => 'mà que saluda: pell morena',
    '👋🏾' => 'mà que saluda: pell fosca',
    '👋🏿' => 'mà que saluda: pell molt fosca',
    '🤚🏻' => 'revers de la mà: pell molt clara',
    '🤚🏼' => 'revers de la mà: pell bastant clara',
    '🤚🏽' => 'revers de la mà: pell morena',
    '🤚🏾' => 'revers de la mà: pell fosca',
    '🤚🏿' => 'revers de la mà: pell molt fosca',
    '🖐🏻' => 'mà oberta: pell molt clara',
    '🖐🏼' => 'mà oberta: pell bastant clara',
    '🖐🏽' => 'mà oberta: pell morena',
    '🖐🏾' => 'mà oberta: pell fosca',
    '🖐🏿' => 'mà oberta: pell molt fosca',
    '✋🏻' => 'mà aixecada: pell molt clara',
    '✋🏼' => 'mà aixecada: pell bastant clara',
    '✋🏽' => 'mà aixecada: pell morena',
    '✋🏾' => 'mà aixecada: pell fosca',
    '✋🏿' => 'mà aixecada: pell molt fosca',
    '🖖🏻' => 'salutació vulcaniana: pell molt clara',
    '🖖🏼' => 'salutació vulcaniana: pell bastant clara',
    '🖖🏽' => 'salutació vulcaniana: pell morena',
    '🖖🏾' => 'salutació vulcaniana: pell fosca',
    '🖖🏿' => 'salutació vulcaniana: pell molt fosca',
    '🫱🏻' => 'mà cap a la dreta: pell molt clara',
    '🫱🏼' => 'mà cap a la dreta: pell bastant clara',
    '🫱🏽' => 'mà cap a la dreta: pell morena',
    '🫱🏾' => 'mà cap a la dreta: pell fosca',
    '🫱🏿' => 'mà cap a la dreta: pell molt fosca',
    '🫲🏻' => 'mà cap a l’esquerra: pell molt clara',
    '🫲🏼' => 'mà cap a l’esquerra: pell bastant clara',
    '🫲🏽' => 'mà cap a l’esquerra: pell morena',
    '🫲🏾' => 'mà cap a l’esquerra: pell fosca',
    '🫲🏿' => 'mà cap a l’esquerra: pell molt fosca',
    '🫳🏻' => 'mà amb el palmell cap avall: pell molt clara',
    '🫳🏼' => 'mà amb el palmell cap avall: pell bastant clara',
    '🫳🏽' => 'mà amb el palmell cap avall: pell morena',
    '🫳🏾' => 'mà amb el palmell cap avall: pell fosca',
    '🫳🏿' => 'mà amb el palmell cap avall: pell molt fosca',
    '🫴🏻' => 'mà amb el palmell cap amunt: pell molt clara',
    '🫴🏼' => 'mà amb el palmell cap amunt: pell bastant clara',
    '🫴🏽' => 'mà amb el palmell cap amunt: pell morena',
    '🫴🏾' => 'mà amb el palmell cap amunt: pell fosca',
    '🫴🏿' => 'mà amb el palmell cap amunt: pell molt fosca',
    '🫷🏻' => 'mà que empeny cap a l’esquerra: pell molt clara',
    '🫷🏼' => 'mà que empeny cap a l’esquerra: pell bastant clara',
    '🫷🏽' => 'mà que empeny cap a l’esquerra: pell morena',
    '🫷🏾' => 'mà que empeny cap a l’esquerra: pell fosca',
    '🫷🏿' => 'mà que empeny cap a l’esquerra: pell molt fosca',
    '🫸🏻' => 'mà que empeny cap a la dreta: pell molt clara',
    '🫸🏼' => 'mà que empeny cap a la dreta: pell bastant clara',
    '🫸🏽' => 'mà que empeny cap a la dreta: pell morena',
    '🫸🏾' => 'mà que empeny cap a la dreta: pell fosca',
    '🫸🏿' => 'mà que empeny cap a la dreta: pell molt fosca',
    '👌🏻' => 'senyal d’aprovació amb la mà: pell molt clara',
    '👌🏼' => 'senyal d’aprovació amb la mà: pell bastant clara',
    '👌🏽' => 'senyal d’aprovació amb la mà: pell morena',
    '👌🏾' => 'senyal d’aprovació amb la mà: pell fosca',
    '👌🏿' => 'senyal d’aprovació amb la mà: pell molt fosca',
    '🤌🏻' => 'dits junts: pell molt clara',
    '🤌🏼' => 'dits junts: pell bastant clara',
    '🤌🏽' => 'dits junts: pell morena',
    '🤌🏾' => 'dits junts: pell fosca',
    '🤌🏿' => 'dits junts: pell molt fosca',
    '🤏🏻' => 'mà que pessiga: pell molt clara',
    '🤏🏼' => 'mà que pessiga: pell bastant clara',
    '🤏🏽' => 'mà que pessiga: pell morena',
    '🤏🏾' => 'mà que pessiga: pell fosca',
    '🤏🏿' => 'mà que pessiga: pell molt fosca',
    '✌🏻' => 'senyal de la victòria: pell molt clara',
    '✌🏼' => 'senyal de la victòria: pell bastant clara',
    '✌🏽' => 'senyal de la victòria: pell morena',
    '✌🏾' => 'senyal de la victòria: pell fosca',
    '✌🏿' => 'senyal de la victòria: pell molt fosca',
    '🤞🏻' => 'dits creuats: pell molt clara',
    '🤞🏼' => 'dits creuats: pell bastant clara',
    '🤞🏽' => 'dits creuats: pell morena',
    '🤞🏾' => 'dits creuats: pell fosca',
    '🤞🏿' => 'dits creuats: pell molt fosca',
    '🫰🏻' => 'mà amb el dit índex i el polze creuats: pell molt clara',
    '🫰🏼' => 'mà amb el dit índex i el polze creuats: pell bastant clara',
    '🫰🏽' => 'mà amb el dit índex i el polze creuats: pell morena',
    '🫰🏾' => 'mà amb el dit índex i el polze creuats: pell fosca',
    '🫰🏿' => 'mà amb el dit índex i el polze creuats: pell molt fosca',
    '🤟🏻' => 'gest de t’estimo: pell molt clara',
    '🤟🏼' => 'gest de t’estimo: pell bastant clara',
    '🤟🏽' => 'gest de t’estimo: pell morena',
    '🤟🏾' => 'gest de t’estimo: pell fosca',
    '🤟🏿' => 'gest de t’estimo: pell molt fosca',
    '🤘🏻' => 'dits en forma de banyes: pell molt clara',
    '🤘🏼' => 'dits en forma de banyes: pell bastant clara',
    '🤘🏽' => 'dits en forma de banyes: pell morena',
    '🤘🏾' => 'dits en forma de banyes: pell fosca',
    '🤘🏿' => 'dits en forma de banyes: pell molt fosca',
    '🤙🏻' => 'mà que representa una trucada: pell molt clara',
    '🤙🏼' => 'mà que representa una trucada: pell bastant clara',
    '🤙🏽' => 'mà que representa una trucada: pell morena',
    '🤙🏾' => 'mà que representa una trucada: pell fosca',
    '🤙🏿' => 'mà que representa una trucada: pell molt fosca',
    '👈🏻' => 'dit índex que apunta cap a l’esquerra: pell molt clara',
    '👈🏼' => 'dit índex que apunta cap a l’esquerra: pell bastant clara',
    '👈🏽' => 'dit índex que apunta cap a l’esquerra: pell morena',
    '👈🏾' => 'dit índex que apunta cap a l’esquerra: pell fosca',
    '👈🏿' => 'dit índex que apunta cap a l’esquerra: pell molt fosca',
    '👉🏻' => 'dit índex que apunta cap a la dreta: pell molt clara',
    '👉🏼' => 'dit índex que apunta cap a la dreta: pell bastant clara',
    '👉🏽' => 'dit índex que apunta cap a la dreta: pell morena',
    '👉🏾' => 'dit índex que apunta cap a la dreta: pell fosca',
    '👉🏿' => 'dit índex que apunta cap a la dreta: pell molt fosca',
    '👆🏻' => 'dit índex que apunta cap amunt: pell molt clara',
    '👆🏼' => 'dit índex que apunta cap amunt: pell bastant clara',
    '👆🏽' => 'dit índex que apunta cap amunt: pell morena',
    '👆🏾' => 'dit índex que apunta cap amunt: pell fosca',
    '👆🏿' => 'dit índex que apunta cap amunt: pell molt fosca',
    '🖕🏻' => 'dit del cor: pell molt clara',
    '🖕🏼' => 'dit del cor: pell bastant clara',
    '🖕🏽' => 'dit del cor: pell morena',
    '🖕🏾' => 'dit del cor: pell fosca',
    '🖕🏿' => 'dit del cor: pell molt fosca',
    '👇🏻' => 'dit índex que apunta cap avall: pell molt clara',
    '👇🏼' => 'dit índex que apunta cap avall: pell bastant clara',
    '👇🏽' => 'dit índex que apunta cap avall: pell morena',
    '👇🏾' => 'dit índex que apunta cap avall: pell fosca',
    '👇🏿' => 'dit índex que apunta cap avall: pell molt fosca',
    '☝🏻' => 'índex que apunta cap amunt: pell molt clara',
    '☝🏼' => 'índex que apunta cap amunt: pell bastant clara',
    '☝🏽' => 'índex que apunta cap amunt: pell morena',
    '☝🏾' => 'índex que apunta cap amunt: pell fosca',
    '☝🏿' => 'índex que apunta cap amunt: pell molt fosca',
    '🫵🏻' => 'índex que assenyala l’espectador: pell molt clara',
    '🫵🏼' => 'índex que assenyala l’espectador: pell bastant clara',
    '🫵🏽' => 'índex que assenyala l’espectador: pell morena',
    '🫵🏾' => 'índex que assenyala l’espectador: pell fosca',
    '🫵🏿' => 'índex que assenyala l’espectador: pell molt fosca',
    '👍🏻' => 'polze cap amunt: pell molt clara',
    '👍🏼' => 'polze cap amunt: pell bastant clara',
    '👍🏽' => 'polze cap amunt: pell morena',
    '👍🏾' => 'polze cap amunt: pell fosca',
    '👍🏿' => 'polze cap amunt: pell molt fosca',
    '👎🏻' => 'polze cap avall: pell molt clara',
    '👎🏼' => 'polze cap avall: pell bastant clara',
    '👎🏽' => 'polze cap avall: pell morena',
    '👎🏾' => 'polze cap avall: pell fosca',
    '👎🏿' => 'polze cap avall: pell molt fosca',
    '✊🏻' => 'puny alçat: pell molt clara',
    '✊🏼' => 'puny alçat: pell bastant clara',
    '✊🏽' => 'puny alçat: pell morena',
    '✊🏾' => 'puny alçat: pell fosca',
    '✊🏿' => 'puny alçat: pell molt fosca',
    '👊🏻' => 'cop de puny: pell molt clara',
    '👊🏼' => 'cop de puny: pell bastant clara',
    '👊🏽' => 'cop de puny: pell morena',
    '👊🏾' => 'cop de puny: pell fosca',
    '👊🏿' => 'cop de puny: pell molt fosca',
    '🤛🏻' => 'puny dret: pell molt clara',
    '🤛🏼' => 'puny dret: pell bastant clara',
    '🤛🏽' => 'puny dret: pell morena',
    '🤛🏾' => 'puny dret: pell fosca',
    '🤛🏿' => 'puny dret: pell molt fosca',
    '🤜🏻' => 'puny esquerre: pell molt clara',
    '🤜🏼' => 'puny esquerre: pell bastant clara',
    '🤜🏽' => 'puny esquerre: pell morena',
    '🤜🏾' => 'puny esquerre: pell fosca',
    '🤜🏿' => 'puny esquerre: pell molt fosca',
    '👏🏻' => 'mans que aplaudeixen: pell molt clara',
    '👏🏼' => 'mans que aplaudeixen: pell bastant clara',
    '👏🏽' => 'mans que aplaudeixen: pell morena',
    '👏🏾' => 'mans que aplaudeixen: pell fosca',
    '👏🏿' => 'mans que aplaudeixen: pell molt fosca',
    '🙌🏻' => 'mans enlaire: pell molt clara',
    '🙌🏼' => 'mans enlaire: pell bastant clara',
    '🙌🏽' => 'mans enlaire: pell morena',
    '🙌🏾' => 'mans enlaire: pell fosca',
    '🙌🏿' => 'mans enlaire: pell molt fosca',
    '🫶🏻' => 'mans que formen un cor: pell molt clara',
    '🫶🏼' => 'mans que formen un cor: pell bastant clara',
    '🫶🏽' => 'mans que formen un cor: pell morena',
    '🫶🏾' => 'mans que formen un cor: pell fosca',
    '🫶🏿' => 'mans que formen un cor: pell molt fosca',
    '👐🏻' => 'mans obertes: pell molt clara',
    '👐🏼' => 'mans obertes: pell bastant clara',
    '👐🏽' => 'mans obertes: pell morena',
    '👐🏾' => 'mans obertes: pell fosca',
    '👐🏿' => 'mans obertes: pell molt fosca',
    '🤲🏻' => 'mans juntes amb els palmells cap amunt: pell molt clara',
    '🤲🏼' => 'mans juntes amb els palmells cap amunt: pell bastant clara',
    '🤲🏽' => 'mans juntes amb els palmells cap amunt: pell morena',
    '🤲🏾' => 'mans juntes amb els palmells cap amunt: pell fosca',
    '🤲🏿' => 'mans juntes amb els palmells cap amunt: pell molt fosca',
    '🤝🏻' => 'encaixada de mans: pell molt clara',
    '🤝🏼' => 'encaixada de mans: pell bastant clara',
    '🤝🏽' => 'encaixada de mans: pell morena',
    '🤝🏾' => 'encaixada de mans: pell fosca',
    '🤝🏿' => 'encaixada de mans: pell molt fosca',
    '🙏🏻' => 'mans ajuntades: pell molt clara',
    '🙏🏼' => 'mans ajuntades: pell bastant clara',
    '🙏🏽' => 'mans ajuntades: pell morena',
    '🙏🏾' => 'mans ajuntades: pell fosca',
    '🙏🏿' => 'mans ajuntades: pell molt fosca',
    '✍🏻' => 'mà que escriu: pell molt clara',
    '✍🏼' => 'mà que escriu: pell bastant clara',
    '✍🏽' => 'mà que escriu: pell morena',
    '✍🏾' => 'mà que escriu: pell fosca',
    '✍🏿' => 'mà que escriu: pell molt fosca',
    '💅🏻' => 'esmalt d’ungles: pell molt clara',
    '💅🏼' => 'esmalt d’ungles: pell bastant clara',
    '💅🏽' => 'esmalt d’ungles: pell morena',
    '💅🏾' => 'esmalt d’ungles: pell fosca',
    '💅🏿' => 'esmalt d’ungles: pell molt fosca',
    '🤳🏻' => 'autofoto: pell molt clara',
    '🤳🏼' => 'autofoto: pell bastant clara',
    '🤳🏽' => 'autofoto: pell morena',
    '🤳🏾' => 'autofoto: pell fosca',
    '🤳🏿' => 'autofoto: pell molt fosca',
    '💪🏻' => 'bíceps tensat: pell molt clara',
    '💪🏼' => 'bíceps tensat: pell bastant clara',
    '💪🏽' => 'bíceps tensat: pell morena',
    '💪🏾' => 'bíceps tensat: pell fosca',
    '💪🏿' => 'bíceps tensat: pell molt fosca',
    '🦵🏻' => 'cama: pell molt clara',
    '🦵🏼' => 'cama: pell bastant clara',
    '🦵🏽' => 'cama: pell morena',
    '🦵🏾' => 'cama: pell fosca',
    '🦵🏿' => 'cama: pell molt fosca',
    '🦶🏻' => 'peu: pell molt clara',
    '🦶🏼' => 'peu: pell bastant clara',
    '🦶🏽' => 'peu: pell morena',
    '🦶🏾' => 'peu: pell fosca',
    '🦶🏿' => 'peu: pell molt fosca',
    '👂🏻' => 'orella: pell molt clara',
    '👂🏼' => 'orella: pell bastant clara',
    '👂🏽' => 'orella: pell morena',
    '👂🏾' => 'orella: pell fosca',
    '👂🏿' => 'orella: pell molt fosca',
    '🦻🏻' => 'orella amb audiòfon: pell molt clara',
    '🦻🏼' => 'orella amb audiòfon: pell bastant clara',
    '🦻🏽' => 'orella amb audiòfon: pell morena',
    '🦻🏾' => 'orella amb audiòfon: pell fosca',
    '🦻🏿' => 'orella amb audiòfon: pell molt fosca',
    '👃🏻' => 'nas: pell molt clara',
    '👃🏼' => 'nas: pell bastant clara',
    '👃🏽' => 'nas: pell morena',
    '👃🏾' => 'nas: pell fosca',
    '👃🏿' => 'nas: pell molt fosca',
    '👶🏻' => 'nadó: pell molt clara',
    '👶🏼' => 'nadó: pell bastant clara',
    '👶🏽' => 'nadó: pell morena',
    '👶🏾' => 'nadó: pell fosca',
    '👶🏿' => 'nadó: pell molt fosca',
    '🧒🏻' => 'criatura: pell molt clara',
    '🧒🏼' => 'criatura: pell bastant clara',
    '🧒🏽' => 'criatura: pell morena',
    '🧒🏾' => 'criatura: pell fosca',
    '🧒🏿' => 'criatura: pell molt fosca',
    '👦🏻' => 'noi: pell molt clara',
    '👦🏼' => 'noi: pell bastant clara',
    '👦🏽' => 'noi: pell morena',
    '👦🏾' => 'noi: pell fosca',
    '👦🏿' => 'noi: pell molt fosca',
    '👧🏻' => 'noia: pell molt clara',
    '👧🏼' => 'noia: pell bastant clara',
    '👧🏽' => 'noia: pell morena',
    '👧🏾' => 'noia: pell fosca',
    '👧🏿' => 'noia: pell molt fosca',
    '🧑🏻' => 'persona: pell molt clara',
    '🧑🏼' => 'persona: pell bastant clara',
    '🧑🏽' => 'persona: pell morena',
    '🧑🏾' => 'persona: pell fosca',
    '🧑🏿' => 'persona: pell molt fosca',
    '👱🏻' => 'persona: pell molt clara i cabells rossos',
    '👱🏼' => 'persona: pell bastant clara i cabells rossos',
    '👱🏽' => 'persona: pell morena i cabells rossos',
    '👱🏾' => 'persona: pell fosca i cabells rossos',
    '👱🏿' => 'persona: pell molt fosca i cabells rossos',
    '👨🏻' => 'home: pell molt clara',
    '👨🏼' => 'home: pell bastant clara',
    '👨🏽' => 'home: pell morena',
    '👨🏾' => 'home: pell fosca',
    '👨🏿' => 'home: pell molt fosca',
    '🧔🏻' => 'persona: pell molt clara i barba',
    '🧔🏼' => 'persona: pell bastant clara i barba',
    '🧔🏽' => 'persona: pell morena i barba',
    '🧔🏾' => 'persona: pell fosca i barba',
    '🧔🏿' => 'persona: pell molt fosca i barba',
    '👩🏻' => 'dona: pell molt clara',
    '👩🏼' => 'dona: pell bastant clara',
    '👩🏽' => 'dona: pell morena',
    '👩🏾' => 'dona: pell fosca',
    '👩🏿' => 'dona: pell molt fosca',
    '🧓🏻' => 'persona gran: pell molt clara',
    '🧓🏼' => 'persona gran: pell bastant clara',
    '🧓🏽' => 'persona gran: pell morena',
    '🧓🏾' => 'persona gran: pell fosca',
    '🧓🏿' => 'persona gran: pell molt fosca',
    '👴🏻' => 'home gran: pell molt clara',
    '👴🏼' => 'home gran: pell bastant clara',
    '👴🏽' => 'home gran: pell morena',
    '👴🏾' => 'home gran: pell fosca',
    '👴🏿' => 'home gran: pell molt fosca',
    '👵🏻' => 'dona gran: pell molt clara',
    '👵🏼' => 'dona gran: pell bastant clara',
    '👵🏽' => 'dona gran: pell morena',
    '👵🏾' => 'dona gran: pell fosca',
    '👵🏿' => 'dona gran: pell molt fosca',
    '🙍🏻' => 'persona emmurriada: pell molt clara',
    '🙍🏼' => 'persona emmurriada: pell bastant clara',
    '🙍🏽' => 'persona emmurriada: pell morena',
    '🙍🏾' => 'persona emmurriada: pell fosca',
    '🙍🏿' => 'persona emmurriada: pell molt fosca',
    '🙎🏻' => 'persona enutjada: pell molt clara',
    '🙎🏼' => 'persona enutjada: pell bastant clara',
    '🙎🏽' => 'persona enutjada: pell morena',
    '🙎🏾' => 'persona enutjada: pell fosca',
    '🙎🏿' => 'persona enutjada: pell molt fosca',
    '🙅🏻' => 'gest de negació: pell molt clara',
    '🙅🏼' => 'gest de negació: pell bastant clara',
    '🙅🏽' => 'gest de negació: pell morena',
    '🙅🏾' => 'gest de negació: pell fosca',
    '🙅🏿' => 'gest de negació: pell molt fosca',
    '🙆🏻' => 'gest d’aprovació: pell molt clara',
    '🙆🏼' => 'gest d’aprovació: pell bastant clara',
    '🙆🏽' => 'gest d’aprovació: pell morena',
    '🙆🏾' => 'gest d’aprovació: pell fosca',
    '🙆🏿' => 'gest d’aprovació: pell molt fosca',
    '💁🏻' => 'persona amb mà inclinada cap amunt: pell molt clara',
    '💁🏼' => 'persona amb mà inclinada cap amunt: pell bastant clara',
    '💁🏽' => 'persona amb mà inclinada cap amunt: pell morena',
    '💁🏾' => 'persona amb mà inclinada cap amunt: pell fosca',
    '💁🏿' => 'persona amb mà inclinada cap amunt: pell molt fosca',
    '🙋🏻' => 'persona amb la mà aixecada: pell molt clara',
    '🙋🏼' => 'persona amb la mà aixecada: pell bastant clara',
    '🙋🏽' => 'persona amb la mà aixecada: pell morena',
    '🙋🏾' => 'persona amb la mà aixecada: pell fosca',
    '🙋🏿' => 'persona amb la mà aixecada: pell molt fosca',
    '🧏🏻' => 'persona sorda: pell molt clara',
    '🧏🏼' => 'persona sorda: pell bastant clara',
    '🧏🏽' => 'persona sorda: pell morena',
    '🧏🏾' => 'persona sorda: pell fosca',
    '🧏🏿' => 'persona sorda: pell molt fosca',
    '🙇🏻' => 'persona capcota: pell molt clara',
    '🙇🏼' => 'persona capcota: pell bastant clara',
    '🙇🏽' => 'persona capcota: pell morena',
    '🙇🏾' => 'persona capcota: pell fosca',
    '🙇🏿' => 'persona capcota: pell molt fosca',
    '🤦🏻' => 'persona amb la mà a la cara: pell molt clara',
    '🤦🏼' => 'persona amb la mà a la cara: pell bastant clara',
    '🤦🏽' => 'persona amb la mà a la cara: pell morena',
    '🤦🏾' => 'persona amb la mà a la cara: pell fosca',
    '🤦🏿' => 'persona amb la mà a la cara: pell molt fosca',
    '🤷🏻' => 'persona que arronsa les espatlles: pell molt clara',
    '🤷🏼' => 'persona que arronsa les espatlles: pell bastant clara',
    '🤷🏽' => 'persona que arronsa les espatlles: pell morena',
    '🤷🏾' => 'persona que arronsa les espatlles: pell fosca',
    '🤷🏿' => 'persona que arronsa les espatlles: pell molt fosca',
    '👮🏻' => 'agent de policia: pell molt clara',
    '👮🏼' => 'agent de policia: pell bastant clara',
    '👮🏽' => 'agent de policia: pell morena',
    '👮🏾' => 'agent de policia: pell fosca',
    '👮🏿' => 'agent de policia: pell molt fosca',
    '🕵🏻' => 'detectiu: pell molt clara',
    '🕵🏼' => 'detectiu: pell bastant clara',
    '🕵🏽' => 'detectiu: pell morena',
    '🕵🏾' => 'detectiu: pell fosca',
    '🕵🏿' => 'detectiu: pell molt fosca',
    '💂🏻' => 'guarda: pell molt clara',
    '💂🏼' => 'guarda: pell bastant clara',
    '💂🏽' => 'guarda: pell morena',
    '💂🏾' => 'guarda: pell fosca',
    '💂🏿' => 'guarda: pell molt fosca',
    '🥷🏻' => 'ninja: pell molt clara',
    '🥷🏼' => 'ninja: pell bastant clara',
    '🥷🏽' => 'ninja: pell morena',
    '🥷🏾' => 'ninja: pell fosca',
    '🥷🏿' => 'ninja: pell molt fosca',
    '👷🏻' => 'treballador de la construcció: pell molt clara',
    '👷🏼' => 'treballador de la construcció: pell bastant clara',
    '👷🏽' => 'treballador de la construcció: pell morena',
    '👷🏾' => 'treballador de la construcció: pell fosca',
    '👷🏿' => 'treballador de la construcció: pell molt fosca',
    '🫅🏻' => 'persona amb corona: pell molt clara',
    '🫅🏼' => 'persona amb corona: pell bastant clara',
    '🫅🏽' => 'persona amb corona: pell morena',
    '🫅🏾' => 'persona amb corona: pell fosca',
    '🫅🏿' => 'persona amb corona: pell molt fosca',
    '🤴🏻' => 'príncep: pell molt clara',
    '🤴🏼' => 'príncep: pell bastant clara',
    '🤴🏽' => 'príncep: pell morena',
    '🤴🏾' => 'príncep: pell fosca',
    '🤴🏿' => 'príncep: pell molt fosca',
    '👸🏻' => 'princesa: pell molt clara',
    '👸🏼' => 'princesa: pell bastant clara',
    '👸🏽' => 'princesa: pell morena',
    '👸🏾' => 'princesa: pell fosca',
    '👸🏿' => 'princesa: pell molt fosca',
    '👳🏻' => 'persona amb turbant: pell molt clara',
    '👳🏼' => 'persona amb turbant: pell bastant clara',
    '👳🏽' => 'persona amb turbant: pell morena',
    '👳🏾' => 'persona amb turbant: pell fosca',
    '👳🏿' => 'persona amb turbant: pell molt fosca',
    '👲🏻' => 'home amb barret xinès: pell molt clara',
    '👲🏼' => 'home amb barret xinès: pell bastant clara',
    '👲🏽' => 'home amb barret xinès: pell morena',
    '👲🏾' => 'home amb barret xinès: pell fosca',
    '👲🏿' => 'home amb barret xinès: pell molt fosca',
    '🧕🏻' => 'dona amb el cap cobert: pell molt clara',
    '🧕🏼' => 'dona amb el cap cobert: pell bastant clara',
    '🧕🏽' => 'dona amb el cap cobert: pell morena',
    '🧕🏾' => 'dona amb el cap cobert: pell fosca',
    '🧕🏿' => 'dona amb el cap cobert: pell molt fosca',
    '🤵🏻' => 'persona amb esmòquing: pell molt clara',
    '🤵🏼' => 'persona amb esmòquing: pell bastant clara',
    '🤵🏽' => 'persona amb esmòquing: pell morena',
    '🤵🏾' => 'persona amb esmòquing: pell fosca',
    '🤵🏿' => 'persona amb esmòquing: pell molt fosca',
    '👰🏻' => 'persona amb vel: pell molt clara',
    '👰🏼' => 'persona amb vel: pell bastant clara',
    '👰🏽' => 'persona amb vel: pell morena',
    '👰🏾' => 'persona amb vel: pell fosca',
    '👰🏿' => 'persona amb vel: pell molt fosca',
    '🤰🏻' => 'dona embarassada: pell molt clara',
    '🤰🏼' => 'dona embarassada: pell bastant clara',
    '🤰🏽' => 'dona embarassada: pell morena',
    '🤰🏾' => 'dona embarassada: pell fosca',
    '🤰🏿' => 'dona embarassada: pell molt fosca',
    '🫃🏻' => 'home embarassat: pell molt clara',
    '🫃🏼' => 'home embarassat: pell bastant clara',
    '🫃🏽' => 'home embarassat: pell morena',
    '🫃🏾' => 'home embarassat: pell fosca',
    '🫃🏿' => 'home embarassat: pell molt fosca',
    '🫄🏻' => 'persona embarassada: pell molt clara',
    '🫄🏼' => 'persona embarassada: pell bastant clara',
    '🫄🏽' => 'persona embarassada: pell morena',
    '🫄🏾' => 'persona embarassada: pell fosca',
    '🫄🏿' => 'persona embarassada: pell molt fosca',
    '🤱🏻' => 'dona que alleta: pell molt clara',
    '🤱🏼' => 'dona que alleta: pell bastant clara',
    '🤱🏽' => 'dona que alleta: pell morena',
    '🤱🏾' => 'dona que alleta: pell fosca',
    '🤱🏿' => 'dona que alleta: pell molt fosca',
    '👼🏻' => 'angelet: pell molt clara',
    '👼🏼' => 'angelet: pell bastant clara',
    '👼🏽' => 'angelet: pell morena',
    '👼🏾' => 'angelet: pell fosca',
    '👼🏿' => 'angelet: pell molt fosca',
    '🎅🏻' => 'pare Noel: pell molt clara',
    '🎅🏼' => 'pare Noel: pell bastant clara',
    '🎅🏽' => 'pare Noel: pell morena',
    '🎅🏾' => 'pare Noel: pell fosca',
    '🎅🏿' => 'pare Noel: pell molt fosca',
    '🤶🏻' => 'mare Noel: pell molt clara',
    '🤶🏼' => 'mare Noel: pell bastant clara',
    '🤶🏽' => 'mare Noel: pell morena',
    '🤶🏾' => 'mare Noel: pell fosca',
    '🤶🏿' => 'mare Noel: pell molt fosca',
    '🦸🏻' => 'superheroi: pell molt clara',
    '🦸🏼' => 'superheroi: pell bastant clara',
    '🦸🏽' => 'superheroi: pell morena',
    '🦸🏾' => 'superheroi: pell fosca',
    '🦸🏿' => 'superheroi: pell molt fosca',
    '🦹🏻' => 'superdolent: pell molt clara',
    '🦹🏼' => 'superdolent: pell bastant clara',
    '🦹🏽' => 'superdolent: pell morena',
    '🦹🏾' => 'superdolent: pell fosca',
    '🦹🏿' => 'superdolent: pell molt fosca',
    '🧙🏻' => 'mag: pell molt clara',
    '🧙🏼' => 'mag: pell bastant clara',
    '🧙🏽' => 'mag: pell morena',
    '🧙🏾' => 'mag: pell fosca',
    '🧙🏿' => 'mag: pell molt fosca',
    '🧚🏻' => 'fada: pell molt clara',
    '🧚🏼' => 'fada: pell bastant clara',
    '🧚🏽' => 'fada: pell morena',
    '🧚🏾' => 'fada: pell fosca',
    '🧚🏿' => 'fada: pell molt fosca',
    '🧛🏻' => 'vampir: pell molt clara',
    '🧛🏼' => 'vampir: pell bastant clara',
    '🧛🏽' => 'vampir: pell morena',
    '🧛🏾' => 'vampir: pell fosca',
    '🧛🏿' => 'vampir: pell molt fosca',
    '🧜🏻' => 'persona sirena: pell molt clara',
    '🧜🏼' => 'persona sirena: pell bastant clara',
    '🧜🏽' => 'persona sirena: pell morena',
    '🧜🏾' => 'persona sirena: pell fosca',
    '🧜🏿' => 'persona sirena: pell molt fosca',
    '🧝🏻' => 'elf: pell molt clara',
    '🧝🏼' => 'elf: pell bastant clara',
    '🧝🏽' => 'elf: pell morena',
    '🧝🏾' => 'elf: pell fosca',
    '🧝🏿' => 'elf: pell molt fosca',
    '💆🏻' => 'persona que rep un massatge al cap: pell molt clara',
    '💆🏼' => 'persona que rep un massatge al cap: pell bastant clara',
    '💆🏽' => 'persona que rep un massatge al cap: pell morena',
    '💆🏾' => 'persona que rep un massatge al cap: pell fosca',
    '💆🏿' => 'persona que rep un massatge al cap: pell molt fosca',
    '💇🏻' => 'persona que es talla els cabells: pell molt clara',
    '💇🏼' => 'persona que es talla els cabells: pell bastant clara',
    '💇🏽' => 'persona que es talla els cabells: pell morena',
    '💇🏾' => 'persona que es talla els cabells: pell fosca',
    '💇🏿' => 'persona que es talla els cabells: pell molt fosca',
    '🚶🏻' => 'persona que camina: pell molt clara',
    '🚶🏼' => 'persona que camina: pell bastant clara',
    '🚶🏽' => 'persona que camina: pell morena',
    '🚶🏾' => 'persona que camina: pell fosca',
    '🚶🏿' => 'persona que camina: pell molt fosca',
    '🧍🏻' => 'persona dreta: pell molt clara',
    '🧍🏼' => 'persona dreta: pell bastant clara',
    '🧍🏽' => 'persona dreta: pell morena',
    '🧍🏾' => 'persona dreta: pell fosca',
    '🧍🏿' => 'persona dreta: pell molt fosca',
    '🧎🏻' => 'persona agenollada: pell molt clara',
    '🧎🏼' => 'persona agenollada: pell bastant clara',
    '🧎🏽' => 'persona agenollada: pell morena',
    '🧎🏾' => 'persona agenollada: pell fosca',
    '🧎🏿' => 'persona agenollada: pell molt fosca',
    '🏃🏻' => 'persona que corre: pell molt clara',
    '🏃🏼' => 'persona que corre: pell bastant clara',
    '🏃🏽' => 'persona que corre: pell morena',
    '🏃🏾' => 'persona que corre: pell fosca',
    '🏃🏿' => 'persona que corre: pell molt fosca',
    '💃🏻' => 'dona que balla: pell molt clara',
    '💃🏼' => 'dona que balla: pell bastant clara',
    '💃🏽' => 'dona que balla: pell morena',
    '💃🏾' => 'dona que balla: pell fosca',
    '💃🏿' => 'dona que balla: pell molt fosca',
    '🕺🏻' => 'home que balla: pell molt clara',
    '🕺🏼' => 'home que balla: pell bastant clara',
    '🕺🏽' => 'home que balla: pell morena',
    '🕺🏾' => 'home que balla: pell fosca',
    '🕺🏿' => 'home que balla: pell molt fosca',
    '🕴🏻' => 'home de negocis que levita: pell molt clara',
    '🕴🏼' => 'home de negocis que levita: pell bastant clara',
    '🕴🏽' => 'home de negocis que levita: pell morena',
    '🕴🏾' => 'home de negocis que levita: pell fosca',
    '🕴🏿' => 'home de negocis que levita: pell molt fosca',
    '👯🏻' => 'persones que ballen disfressades: pell molt clara',
    '👯🏼' => 'persones que ballen disfressades: pell bastant clara',
    '👯🏽' => 'persones que ballen disfressades: pell morena',
    '👯🏾' => 'persones que ballen disfressades: pell fosca',
    '👯🏿' => 'persones que ballen disfressades: pell molt fosca',
    '🧖🏻' => 'persona a la sauna: pell molt clara',
    '🧖🏼' => 'persona a la sauna: pell bastant clara',
    '🧖🏽' => 'persona a la sauna: pell morena',
    '🧖🏾' => 'persona a la sauna: pell fosca',
    '🧖🏿' => 'persona a la sauna: pell molt fosca',
    '🧗🏻' => 'persona que escala: pell molt clara',
    '🧗🏼' => 'persona que escala: pell bastant clara',
    '🧗🏽' => 'persona que escala: pell morena',
    '🧗🏾' => 'persona que escala: pell fosca',
    '🧗🏿' => 'persona que escala: pell molt fosca',
    '🏇🏻' => 'curses de cavalls: pell molt clara',
    '🏇🏼' => 'curses de cavalls: pell bastant clara',
    '🏇🏽' => 'curses de cavalls: pell morena',
    '🏇🏾' => 'curses de cavalls: pell fosca',
    '🏇🏿' => 'curses de cavalls: pell molt fosca',
    '🏂🏻' => 'surfista de neu: pell molt clara',
    '🏂🏼' => 'surfista de neu: pell bastant clara',
    '🏂🏽' => 'surfista de neu: pell morena',
    '🏂🏾' => 'surfista de neu: pell fosca',
    '🏂🏿' => 'surfista de neu: pell molt fosca',
    '🏌🏻' => 'golfista: pell molt clara',
    '🏌🏼' => 'golfista: pell bastant clara',
    '🏌🏽' => 'golfista: pell morena',
    '🏌🏾' => 'golfista: pell fosca',
    '🏌🏿' => 'golfista: pell molt fosca',
    '🏄🏻' => 'persona que fa surf: pell molt clara',
    '🏄🏼' => 'persona que fa surf: pell bastant clara',
    '🏄🏽' => 'persona que fa surf: pell morena',
    '🏄🏾' => 'persona que fa surf: pell fosca',
    '🏄🏿' => 'persona que fa surf: pell molt fosca',
    '🚣🏻' => 'persona que rema en una barca: pell molt clara',
    '🚣🏼' => 'persona que rema en una barca: pell bastant clara',
    '🚣🏽' => 'persona que rema en una barca: pell morena',
    '🚣🏾' => 'persona que rema en una barca: pell fosca',
    '🚣🏿' => 'persona que rema en una barca: pell molt fosca',
    '🏊🏻' => 'persona que neda: pell molt clara',
    '🏊🏼' => 'persona que neda: pell bastant clara',
    '🏊🏽' => 'persona que neda: pell morena',
    '🏊🏾' => 'persona que neda: pell fosca',
    '🏊🏿' => 'persona que neda: pell molt fosca',
    '⛹🏻' => 'persona amb una pilota: pell molt clara',
    '⛹🏼' => 'persona amb una pilota: pell bastant clara',
    '⛹🏽' => 'persona amb una pilota: pell morena',
    '⛹🏾' => 'persona amb una pilota: pell fosca',
    '⛹🏿' => 'persona amb una pilota: pell molt fosca',
    '🏋🏻' => 'persona que aixeca pesos: pell molt clara',
    '🏋🏼' => 'persona que aixeca pesos: pell bastant clara',
    '🏋🏽' => 'persona que aixeca pesos: pell morena',
    '🏋🏾' => 'persona que aixeca pesos: pell fosca',
    '🏋🏿' => 'persona que aixeca pesos: pell molt fosca',
    '🚴🏻' => 'ciclista: pell molt clara',
    '🚴🏼' => 'ciclista: pell bastant clara',
    '🚴🏽' => 'ciclista: pell morena',
    '🚴🏾' => 'ciclista: pell fosca',
    '🚴🏿' => 'ciclista: pell molt fosca',
    '🚵🏻' => 'ciclista de muntanya: pell molt clara',
    '🚵🏼' => 'ciclista de muntanya: pell bastant clara',
    '🚵🏽' => 'ciclista de muntanya: pell morena',
    '🚵🏾' => 'ciclista de muntanya: pell fosca',
    '🚵🏿' => 'ciclista de muntanya: pell molt fosca',
    '🤸🏻' => 'persona que fa la roda: pell molt clara',
    '🤸🏼' => 'persona que fa la roda: pell bastant clara',
    '🤸🏽' => 'persona que fa la roda: pell morena',
    '🤸🏾' => 'persona que fa la roda: pell fosca',
    '🤸🏿' => 'persona que fa la roda: pell molt fosca',
    '🤼🏻' => 'persones que lluiten: pell molt clara',
    '🤼🏼' => 'persones que lluiten: pell bastant clara',
    '🤼🏽' => 'persones que lluiten: pell morena',
    '🤼🏾' => 'persones que lluiten: pell fosca',
    '🤼🏿' => 'persones que lluiten: pell molt fosca',
    '🤽🏻' => 'persona que juga a waterpolo: pell molt clara',
    '🤽🏼' => 'persona que juga a waterpolo: pell bastant clara',
    '🤽🏽' => 'persona que juga a waterpolo: pell morena',
    '🤽🏾' => 'persona que juga a waterpolo: pell fosca',
    '🤽🏿' => 'persona que juga a waterpolo: pell molt fosca',
    '🤾🏻' => 'persona que juga a handbol: pell molt clara',
    '🤾🏼' => 'persona que juga a handbol: pell bastant clara',
    '🤾🏽' => 'persona que juga a handbol: pell morena',
    '🤾🏾' => 'persona que juga a handbol: pell fosca',
    '🤾🏿' => 'persona que juga a handbol: pell molt fosca',
    '🤹🏻' => 'persona que fa malabars: pell molt clara',
    '🤹🏼' => 'persona que fa malabars: pell bastant clara',
    '🤹🏽' => 'persona que fa malabars: pell morena',
    '🤹🏾' => 'persona que fa malabars: pell fosca',
    '🤹🏿' => 'persona que fa malabars: pell molt fosca',
    '🧘🏻' => 'persona en la posició de lotus: pell molt clara',
    '🧘🏼' => 'persona en la posició de lotus: pell bastant clara',
    '🧘🏽' => 'persona en la posició de lotus: pell morena',
    '🧘🏾' => 'persona en la posició de lotus: pell fosca',
    '🧘🏿' => 'persona en la posició de lotus: pell molt fosca',
    '🛀🏻' => 'persona a la banyera: pell molt clara',
    '🛀🏼' => 'persona a la banyera: pell bastant clara',
    '🛀🏽' => 'persona a la banyera: pell morena',
    '🛀🏾' => 'persona a la banyera: pell fosca',
    '🛀🏿' => 'persona a la banyera: pell molt fosca',
    '🛌🏻' => 'persona al llit: pell molt clara',
    '🛌🏼' => 'persona al llit: pell bastant clara',
    '🛌🏽' => 'persona al llit: pell morena',
    '🛌🏾' => 'persona al llit: pell fosca',
    '🛌🏿' => 'persona al llit: pell molt fosca',
    '👭🏻' => 'dones que s’agafen de la mà: pell molt clara',
    '👭🏼' => 'dones que s’agafen de la mà: pell bastant clara',
    '👭🏽' => 'dones que s’agafen de la mà: pell morena',
    '👭🏾' => 'dones que s’agafen de la mà: pell fosca',
    '👭🏿' => 'dones que s’agafen de la mà: pell molt fosca',
    '👫🏻' => 'home i dona que s’agafen de la mà: pell molt clara',
    '👫🏼' => 'home i dona que s’agafen de la mà: pell bastant clara',
    '👫🏽' => 'home i dona que s’agafen de la mà: pell morena',
    '👫🏾' => 'home i dona que s’agafen de la mà: pell fosca',
    '👫🏿' => 'home i dona que s’agafen de la mà: pell molt fosca',
    '👬🏻' => 'homes que s’agafen de la mà: pell molt clara',
    '👬🏼' => 'homes que s’agafen de la mà: pell bastant clara',
    '👬🏽' => 'homes que s’agafen de la mà: pell morena',
    '👬🏾' => 'homes que s’agafen de la mà: pell fosca',
    '👬🏿' => 'homes que s’agafen de la mà: pell molt fosca',
    '💏🏻' => 'petó: pell molt clara',
    '💏🏼' => 'petó: pell bastant clara',
    '💏🏽' => 'petó: pell morena',
    '💏🏾' => 'petó: pell fosca',
    '💏🏿' => 'petó: pell molt fosca',
    '💑🏻' => 'parella amb un cor: pell molt clara',
    '💑🏼' => 'parella amb un cor: pell bastant clara',
    '💑🏽' => 'parella amb un cor: pell morena',
    '💑🏾' => 'parella amb un cor: pell fosca',
    '💑🏿' => 'parella amb un cor: pell molt fosca',
    '🇦🇨' => 'bandera: Illa de l’Ascensió',
    '🇦🇩' => 'bandera: Andorra',
    '🇦🇪' => 'bandera: Emirats Àrabs Units',
    '🇦🇫' => 'bandera: Afganistan',
    '🇦🇬' => 'bandera: Antigua i Barbuda',
    '🇦🇮' => 'bandera: Anguilla',
    '🇦🇱' => 'bandera: Albània',
    '🇦🇲' => 'bandera: Armènia',
    '🇦🇴' => 'bandera: Angola',
    '🇦🇶' => 'bandera: Antàrtida',
    '🇦🇷' => 'bandera: Argentina',
    '🇦🇸' => 'bandera: Samoa Americana',
    '🇦🇹' => 'bandera: Àustria',
    '🇦🇺' => 'bandera: Austràlia',
    '🇦🇼' => 'bandera: Aruba',
    '🇦🇽' => 'bandera: Illes Åland',
    '🇦🇿' => 'bandera: Azerbaidjan',
    '🇧🇦' => 'bandera: Bòsnia i Hercegovina',
    '🇧🇧' => 'bandera: Barbados',
    '🇧🇩' => 'bandera: Bangladesh',
    '🇧🇪' => 'bandera: Bèlgica',
    '🇧🇫' => 'bandera: Burkina Faso',
    '🇧🇬' => 'bandera: Bulgària',
    '🇧🇭' => 'bandera: Bahrain',
    '🇧🇮' => 'bandera: Burundi',
    '🇧🇯' => 'bandera: Benín',
    '🇧🇱' => 'bandera: Saint-Barthélemy',
    '🇧🇲' => 'bandera: Bermudes',
    '🇧🇳' => 'bandera: Brunei',
    '🇧🇴' => 'bandera: Bolívia',
    '🇧🇶' => 'bandera: Carib Neerlandès',
    '🇧🇷' => 'bandera: Brasil',
    '🇧🇸' => 'bandera: Bahames',
    '🇧🇹' => 'bandera: Bhutan',
    '🇧🇻' => 'bandera: Illa Bouvet',
    '🇧🇼' => 'bandera: Botswana',
    '🇧🇾' => 'bandera: Belarús',
    '🇧🇿' => 'bandera: Belize',
    '🇨🇦' => 'bandera: Canadà',
    '🇨🇨' => 'bandera: Illes Cocos (Keeling)',
    '🇨🇩' => 'bandera: Congo - Kinshasa',
    '🇨🇫' => 'bandera: República Centreafricana',
    '🇨🇬' => 'bandera: Congo - Brazzaville',
    '🇨🇭' => 'bandera: Suïssa',
    '🇨🇮' => 'bandera: Côte d’Ivoire',
    '🇨🇰' => 'bandera: Illes Cook',
    '🇨🇱' => 'bandera: Xile',
    '🇨🇲' => 'bandera: Camerun',
    '🇨🇳' => 'bandera: Xina',
    '🇨🇴' => 'bandera: Colòmbia',
    '🇨🇵' => 'bandera: Illa Clipperton',
    '🇨🇶' => 'bandera: Sark',
    '🇨🇷' => 'bandera: Costa Rica',
    '🇨🇺' => 'bandera: Cuba',
    '🇨🇻' => 'bandera: Cap Verd',
    '🇨🇼' => 'bandera: Curaçao',
    '🇨🇽' => 'bandera: Illa Christmas',
    '🇨🇾' => 'bandera: Xipre',
    '🇨🇿' => 'bandera: Txèquia',
    '🇩🇪' => 'bandera: Alemanya',
    '🇩🇬' => 'bandera: Diego Garcia',
    '🇩🇯' => 'bandera: Djibouti',
    '🇩🇰' => 'bandera: Dinamarca',
    '🇩🇲' => 'bandera: Dominica',
    '🇩🇴' => 'bandera: República Dominicana',
    '🇩🇿' => 'bandera: Algèria',
    '🇪🇦' => 'bandera: Ceuta i Melilla',
    '🇪🇨' => 'bandera: Equador',
    '🇪🇪' => 'bandera: Estònia',
    '🇪🇬' => 'bandera: Egipte',
    '🇪🇭' => 'bandera: Sàhara Occidental',
    '🇪🇷' => 'bandera: Eritrea',
    '🇪🇸' => 'bandera: Espanya',
    '🇪🇹' => 'bandera: Etiòpia',
    '🇪🇺' => 'bandera: Unió Europea',
    '🇫🇮' => 'bandera: Finlàndia',
    '🇫🇯' => 'bandera: Fiji',
    '🇫🇰' => 'bandera: Illes Falkland',
    '🇫🇲' => 'bandera: Micronèsia',
    '🇫🇴' => 'bandera: Illes Fèroe',
    '🇫🇷' => 'bandera: França',
    '🇬🇦' => 'bandera: Gabon',
    '🇬🇧' => 'bandera: Regne Unit',
    '🇬🇩' => 'bandera: Grenada',
    '🇬🇪' => 'bandera: Geòrgia',
    '🇬🇫' => 'bandera: Guaiana Francesa',
    '🇬🇬' => 'bandera: Guernsey',
    '🇬🇭' => 'bandera: Ghana',
    '🇬🇮' => 'bandera: Gibraltar',
    '🇬🇱' => 'bandera: Groenlàndia',
    '🇬🇲' => 'bandera: Gàmbia',
    '🇬🇳' => 'bandera: Guinea',
    '🇬🇵' => 'bandera: Guadalupe',
    '🇬🇶' => 'bandera: Guinea Equatorial',
    '🇬🇷' => 'bandera: Grècia',
    '🇬🇸' => 'bandera: Illes Geòrgia del Sud i Sandwich del Sud',
    '🇬🇹' => 'bandera: Guatemala',
    '🇬🇺' => 'bandera: Guam',
    '🇬🇼' => 'bandera: Guinea Bissau',
    '🇬🇾' => 'bandera: Guyana',
    '🇭🇰' => 'bandera: Hong Kong (RAE Xina)',
    '🇭🇲' => 'bandera: Illes Heard i McDonald',
    '🇭🇳' => 'bandera: Hondures',
    '🇭🇷' => 'bandera: Croàcia',
    '🇭🇹' => 'bandera: Haití',
    '🇭🇺' => 'bandera: Hongria',
    '🇮🇨' => 'bandera: Illes Canàries',
    '🇮🇩' => 'bandera: Indonèsia',
    '🇮🇪' => 'bandera: Irlanda',
    '🇮🇱' => 'bandera: Israel',
    '🇮🇲' => 'bandera: Illa de Man',
    '🇮🇳' => 'bandera: Índia',
    '🇮🇴' => 'bandera: Territori Britànic de l’Oceà Índic',
    '🇮🇶' => 'bandera: Iraq',
    '🇮🇷' => 'bandera: Iran',
    '🇮🇸' => 'bandera: Islàndia',
    '🇮🇹' => 'bandera: Itàlia',
    '🇯🇪' => 'bandera: Jersey',
    '🇯🇲' => 'bandera: Jamaica',
    '🇯🇴' => 'bandera: Jordània',
    '🇯🇵' => 'bandera: Japó',
    '🇰🇪' => 'bandera: Kenya',
    '🇰🇬' => 'bandera: Kirguizstan',
    '🇰🇭' => 'bandera: Cambodja',
    '🇰🇮' => 'bandera: Kiribati',
    '🇰🇲' => 'bandera: Comores',
    '🇰🇳' => 'bandera: Saint Kitts i Nevis',
    '🇰🇵' => 'bandera: Corea del Nord',
    '🇰🇷' => 'bandera: Corea del Sud',
    '🇰🇼' => 'bandera: Kuwait',
    '🇰🇾' => 'bandera: Illes Caiman',
    '🇰🇿' => 'bandera: Kazakhstan',
    '🇱🇦' => 'bandera: Lao',
    '🇱🇧' => 'bandera: Líban',
    '🇱🇨' => 'bandera: Saint Lucia',
    '🇱🇮' => 'bandera: Liechtenstein',
    '🇱🇰' => 'bandera: Sri Lanka',
    '🇱🇷' => 'bandera: Libèria',
    '🇱🇸' => 'bandera: Lesotho',
    '🇱🇹' => 'bandera: Lituània',
    '🇱🇺' => 'bandera: Luxemburg',
    '🇱🇻' => 'bandera: Letònia',
    '🇱🇾' => 'bandera: Líbia',
    '🇲🇦' => 'bandera: Marroc',
    '🇲🇨' => 'bandera: Mònaco',
    '🇲🇩' => 'bandera: Moldàvia',
    '🇲🇪' => 'bandera: Montenegro',
    '🇲🇫' => 'bandera: Saint Martin',
    '🇲🇬' => 'bandera: Madagascar',
    '🇲🇭' => 'bandera: Illes Marshall',
    '🇲🇰' => 'bandera: Macedònia del Nord',
    '🇲🇱' => 'bandera: Mali',
    '🇲🇲' => 'bandera: Myanmar (Birmània)',
    '🇲🇳' => 'bandera: Mongòlia',
    '🇲🇴' => 'bandera: Macau (RAE Xina)',
    '🇲🇵' => 'bandera: Illes Marianes del Nord',
    '🇲🇶' => 'bandera: Martinica',
    '🇲🇷' => 'bandera: Mauritània',
    '🇲🇸' => 'bandera: Montserrat',
    '🇲🇹' => 'bandera: Malta',
    '🇲🇺' => 'bandera: Maurici',
    '🇲🇻' => 'bandera: Maldives',
    '🇲🇼' => 'bandera: Malawi',
    '🇲🇽' => 'bandera: Mèxic',
    '🇲🇾' => 'bandera: Malàisia',
    '🇲🇿' => 'bandera: Moçambic',
    '🇳🇦' => 'bandera: Namíbia',
    '🇳🇨' => 'bandera: Nova Caledònia',
    '🇳🇪' => 'bandera: Níger',
    '🇳🇫' => 'bandera: Illa Norfolk',
    '🇳🇬' => 'bandera: Nigèria',
    '🇳🇮' => 'bandera: Nicaragua',
    '🇳🇱' => 'bandera: Països Baixos',
    '🇳🇴' => 'bandera: Noruega',
    '🇳🇵' => 'bandera: Nepal',
    '🇳🇷' => 'bandera: Nauru',
    '🇳🇺' => 'bandera: Niue',
    '🇳🇿' => 'bandera: Nova Zelanda',
    '🇴🇲' => 'bandera: Oman',
    '🇵🇦' => 'bandera: Panamà',
    '🇵🇪' => 'bandera: Perú',
    '🇵🇫' => 'bandera: Polinèsia Francesa',
    '🇵🇬' => 'bandera: Papua Nova Guinea',
    '🇵🇭' => 'bandera: Filipines',
    '🇵🇰' => 'bandera: Pakistan',
    '🇵🇱' => 'bandera: Polònia',
    '🇵🇲' => 'bandera: Saint-Pierre-et-Miquelon',
    '🇵🇳' => 'bandera: Illes Pitcairn',
    '🇵🇷' => 'bandera: Puerto Rico',
    '🇵🇸' => 'bandera: Territoris palestins',
    '🇵🇹' => 'bandera: Portugal',
    '🇵🇼' => 'bandera: Palau',
    '🇵🇾' => 'bandera: Paraguai',
    '🇶🇦' => 'bandera: Qatar',
    '🇷🇪' => 'bandera: Illa de la Reunió',
    '🇷🇴' => 'bandera: Romania',
    '🇷🇸' => 'bandera: Sèrbia',
    '🇷🇺' => 'bandera: Rússia',
    '🇷🇼' => 'bandera: Ruanda',
    '🇸🇦' => 'bandera: Aràbia Saudí',
    '🇸🇧' => 'bandera: Illes Salomó',
    '🇸🇨' => 'bandera: Seychelles',
    '🇸🇩' => 'bandera: Sudan',
    '🇸🇪' => 'bandera: Suècia',
    '🇸🇬' => 'bandera: Singapur',
    '🇸🇭' => 'bandera: Santa Helena',
    '🇸🇮' => 'bandera: Eslovènia',
    '🇸🇯' => 'bandera: Svalbard i Jan Mayen',
    '🇸🇰' => 'bandera: Eslovàquia',
    '🇸🇱' => 'bandera: Sierra Leone',
    '🇸🇲' => 'bandera: San Marino',
    '🇸🇳' => 'bandera: Senegal',
    '🇸🇴' => 'bandera: Somàlia',
    '🇸🇷' => 'bandera: Surinam',
    '🇸🇸' => 'bandera: Sudan del Sud',
    '🇸🇹' => 'bandera: São Tomé i Príncipe',
    '🇸🇻' => 'bandera: El Salvador',
    '🇸🇽' => 'bandera: Sint Maarten',
    '🇸🇾' => 'bandera: Síria',
    '🇸🇿' => 'bandera: Eswatini',
    '🇹🇦' => 'bandera: Tristan da Cunha',
    '🇹🇨' => 'bandera: Illes Turks i Caicos',
    '🇹🇩' => 'bandera: Txad',
    '🇹🇫' => 'bandera: Terres Australs Antàrtiques Franceses',
    '🇹🇬' => 'bandera: Togo',
    '🇹🇭' => 'bandera: Tailàndia',
    '🇹🇯' => 'bandera: Tadjikistan',
    '🇹🇰' => 'bandera: Tokelau',
    '🇹🇱' => 'bandera: Timor-Leste',
    '🇹🇲' => 'bandera: Turkmenistan',
    '🇹🇳' => 'bandera: Tunísia',
    '🇹🇴' => 'bandera: Tonga',
    '🇹🇷' => 'bandera: Turquia',
    '🇹🇹' => 'bandera: Trinidad i Tobago',
    '🇹🇻' => 'bandera: Tuvalu',
    '🇹🇼' => 'bandera: Taiwan',
    '🇹🇿' => 'bandera: Tanzània',
    '🇺🇦' => 'bandera: Ucraïna',
    '🇺🇬' => 'bandera: Uganda',
    '🇺🇲' => 'bandera: Illes Menors Allunyades dels Estats Units',
    '🇺🇳' => 'bandera: Nacions Unides',
    '🇺🇸' => 'bandera: Estats Units',
    '🇺🇾' => 'bandera: Uruguai',
    '🇺🇿' => 'bandera: Uzbekistan',
    '🇻🇦' => 'bandera: Ciutat del Vaticà',
    '🇻🇨' => 'bandera: Saint Vincent i les Grenadines',
    '🇻🇪' => 'bandera: Veneçuela',
    '🇻🇬' => 'bandera: Illes Verges Britàniques',
    '🇻🇮' => 'bandera: Illes Verges dels Estats Units',
    '🇻🇳' => 'bandera: Vietnam',
    '🇻🇺' => 'bandera: Vanuatu',
    '🇼🇫' => 'bandera: Wallis i Futuna',
    '🇼🇸' => 'bandera: Samoa',
    '🇽🇰' => 'bandera: Kosovo',
    '🇾🇪' => 'bandera: Iemen',
    '🇾🇹' => 'bandera: Mayotte',
    '🇿🇦' => 'bandera: Sud-àfrica',
    '🇿🇲' => 'bandera: Zàmbia',
    '🇿🇼' => 'bandera: Zimbàbue',
    '🔟' => 'tecla: 10',
    '🏻' => 'pell molt clara',
    '🏼' => 'pell bastant clara',
    '🏽' => 'pell morena',
    '🏾' => 'pell fosca',
    '🏿' => 'pell molt fosca',
    '😀' => 'cara molt somrient',
    '😃' => 'cara molt somrient amb els ulls ben oberts',
    '😄' => 'cara amb rialla i els ulls somrients',
    '😁' => 'cara molt somrient amb els ulls alegres',
    '😆' => 'cara somrient amb els ulls tancats fortament',
    '😅' => 'cara somrient amb una gota de suor',
    '🤣' => 'cara que es peta de riure',
    '😂' => 'cara amb llàgrimes d’alegria',
    '🙂' => 'cara que somriu una mica',
    '🙃' => 'cara de cap per avall',
    '🫠' => 'cara que es desfà',
    '😉' => 'cara que pica l’ullet',
    '😊' => 'cara somrient amb els ulls alegres',
    '😇' => 'cara somrient amb aurèola',
    '🥰' => 'cara somrient amb 3 cors',
    '😍' => 'cara somrient amb ulls en forma de cor',
    '🤩' => 'cara amb estrelles als ulls',
    '😘' => 'cara que llança un petó',
    '😗' => 'cara que fa un petó',
    '☺' => 'cara somrient',
    '😚' => 'cara que fa un petó amb els ulls tancats',
    '😙' => 'cara que fa un petó amb els ulls alegres',
    '🥲' => 'cara somrient amb una llàgrima',
    '😋' => 'cara que assaboreix menjar',
    '😛' => 'cara que fa llengotes',
    '😜' => 'cara que fa llengotes i pica l’ullet',
    '🤪' => 'cara de bogeria',
    '😝' => 'cara amb els ulls tancats i la llengua fora',
    '🤑' => 'cara de diners',
    '🤗' => 'cara amb abraçada',
    '🤭' => 'cara amb la mà sobre la boca',
    '🫢' => 'cara amb ulls oberts i mà sobre la boca',
    '🫣' => 'cara tapada que espia amb un ull',
    '🤫' => 'cara que demana silenci',
    '🤔' => 'cara pensativa',
    '🫡' => 'cara que saluda',
    '🤐' => 'cara amb cremallera a la boca',
    '🤨' => 'cara amb una cella aixecada',
    '😐' => 'cara neutra',
    '😑' => 'cara inexpressiva',
    '😶' => 'cara sense boca',
    '🫥' => 'cara amb línia de punts',
    '😏' => 'cara somrient amb superioritat',
    '😒' => 'cara de desaprovació',
    '🙄' => 'cara amb els ulls en blanc',
    '😬' => 'cara que fa una ganyota amb les dents',
    '🤥' => 'cara de mentider',
    '🫨' => 'cara que tremola',
    '😌' => 'cara d’alleujament',
    '😔' => 'cara desanimada',
    '😪' => 'cara de son',
    '🤤' => 'cara que baveja',
    '😴' => 'cara de dormir',
    '🫩' => 'cara ullerosa',
    '😷' => 'cara amb mascareta',
    '🤒' => 'cara amb termòmetre',
    '🤕' => 'cara amb el cap embenat',
    '🤢' => 'cara de nàusees',
    '🤮' => 'cara que vomita',
    '🤧' => 'cara que esternuda',
    '🥵' => 'cara de calor',
    '🥶' => 'cara de fred',
    '🥴' => 'cara de mareig',
    '😵' => 'cara marejada',
    '🤯' => 'cap que explota',
    '🤠' => 'cara amb barret de vaquer',
    '🥳' => 'cara festiva',
    '🥸' => 'cara disfressada',
    '😎' => 'cara somrient amb ulleres de sol',
    '🤓' => 'cara de setciències',
    '🧐' => 'cara amb monocle',
    '😕' => 'cara de confusió',
    '🫤' => 'cara amb la boca en diagonal',
    '😟' => 'cara de preocupació',
    '🙁' => 'cara una mica arrufada',
    '☹' => 'cara arrufada',
    '😮' => 'cara amb la boca oberta',
    '😯' => 'cara de sorpresa',
    '😲' => 'cara estupefacta',
    '😳' => 'cara enrojolada',
    '🫪' => 'cara distorsionada',
    '🥺' => 'cara de súplica',
    '🥹' => 'cara que s’aguanta les llàgrimes',
    '😦' => 'cara emmurriada amb la boca oberta',
    '😧' => 'cara d’angoixa',
    '😨' => 'cara de por',
    '😰' => 'cara amb la boca oberta i suor freda',
    '😥' => 'cara de decepció, però alleujada',
    '😢' => 'cara que plora',
    '😭' => 'cara que plora desconsoladament',
    '😱' => 'cara que crida de por',
    '😖' => 'cara de frustració',
    '😣' => 'cara de perseverança',
    '😞' => 'cara de decepció',
    '😓' => 'cara amb suor freda',
    '😩' => 'cara d’esgotament',
    '😫' => 'cara de cansament',
    '🥱' => 'cara que badalla',
    '😤' => 'cara que treu fum del nas',
    '😡' => 'cara enutjada',
    '😠' => 'cara enfadada',
    '🤬' => 'cara amb símbols a la boca',
    '😈' => 'cara somrient amb banyes',
    '👿' => 'cara enfadada amb banyes',
    '💀' => 'crani',
    '☠' => 'crani amb ossos',
    '💩' => 'caca amb ulls',
    '🤡' => 'cara de pallasso',
    '👹' => 'ogre japonès',
    '👺' => 'follet japonès',
    '👻' => 'fantasma',
    '👽' => 'alienígena',
    '👾' => 'monstre alienígena',
    '🤖' => 'robot',
    '😺' => 'gat somrient amb la boca oberta',
    '😸' => 'gat somrient amb els ulls alegres',
    '😹' => 'gat amb llàgrimes d’alegria',
    '😻' => 'gat somrient amb cors als ulls',
    '😼' => 'gat amb somriure irònic',
    '😽' => 'gat que fa un petó',
    '🙀' => 'gat sorprès',
    '😿' => 'gat que plora',
    '😾' => 'gat enutjat',
    '🙈' => 'mona que no mira',
    '🙉' => 'mona que no escolta',
    '🙊' => 'mona que no parla',
    '💌' => 'carta d’amor',
    '💘' => 'cor amb fletxa',
    '💝' => 'cor amb un llaç',
    '💖' => 'cor espurnejant',
    '💗' => 'cor que creix',
    '💓' => 'cor que batega',
    '💞' => 'cors que giren',
    '💕' => 'dos cors',
    '💟' => 'cor decoratiu',
    '❣' => 'exclamació en forma de cor',
    '💔' => 'cor trencat',
    '❤' => 'cor vermell',
    '🩷' => 'cor rosa',
    '🧡' => 'cor taronja',
    '💛' => 'cor groc',
    '💚' => 'cor verd',
    '💙' => 'cor blau',
    '🩵' => 'cor blau cel',
    '💜' => 'cor lila',
    '🤎' => 'cor marró',
    '🖤' => 'cor negre',
    '🩶' => 'cor gris',
    '🤍' => 'cor blanc',
    '💋' => 'marca de petó',
    '💯' => '100 punts',
    '💢' => 'símbol d’enuig',
    '🫯' => 'núvol de baralla',
    '💥' => 'col·lisió',
    '💫' => 'mareig',
    '💦' => 'gotes de suor',
    '💨' => 'sortir corrent',
    '🕳' => 'forat',
    '💬' => 'bafarada de parlar',
    '🗨' => 'bafarada de parlar cap a l’esquerra',
    '🗯' => 'bafarada d’enuig cap a la dreta',
    '💭' => 'bafarada de pensar',
    '💤' => 'zzz',
    '👋' => 'mà que saluda',
    '🤚' => 'revers de la mà',
    '🖐' => 'mà oberta',
    '✋' => 'mà aixecada',
    '🖖' => 'salutació vulcaniana',
    '🫱' => 'mà cap a la dreta',
    '🫲' => 'mà cap a l’esquerra',
    '🫳' => 'mà amb el palmell cap avall',
    '🫴' => 'mà amb el palmell cap amunt',
    '🫷' => 'mà que empeny cap a l’esquerra',
    '🫸' => 'mà que empeny cap a la dreta',
    '👌' => 'senyal d’aprovació amb la mà',
    '🤌' => 'dits junts',
    '🤏' => 'mà que pessiga',
    '✌' => 'senyal de la victòria',
    '🤞' => 'dits creuats',
    '🫰' => 'mà amb el dit índex i el polze creuats',
    '🤟' => 'gest de t’estimo',
    '🤘' => 'dits en forma de banyes',
    '🤙' => 'mà que representa una trucada',
    '👈' => 'dit índex que apunta cap a l’esquerra',
    '👉' => 'dit índex que apunta cap a la dreta',
    '👆' => 'dit índex que apunta cap amunt',
    '🖕' => 'dit del cor',
    '👇' => 'dit índex que apunta cap avall',
    '☝' => 'índex que apunta cap amunt',
    '🫵' => 'índex que assenyala l’espectador',
    '👍' => 'polze cap amunt',
    '👎' => 'polze cap avall',
    '✊' => 'puny alçat',
    '👊' => 'cop de puny',
    '🤛' => 'puny dret',
    '🤜' => 'puny esquerre',
    '👏' => 'mans que aplaudeixen',
    '🙌' => 'mans enlaire',
    '🫶' => 'mans que formen un cor',
    '👐' => 'mans obertes',
    '🤲' => 'mans juntes amb els palmells cap amunt',
    '🤝' => 'encaixada de mans',
    '🙏' => 'mans ajuntades',
    '✍' => 'mà que escriu',
    '💅' => 'esmalt d’ungles',
    '🤳' => 'autofoto',
    '💪' => 'bíceps tensat',
    '🦾' => 'pròtesi de braç',
    '🦿' => 'pròtesi de cama',
    '🦵' => 'cama',
    '🦶' => 'peu',
    '👂' => 'orella',
    '🦻' => 'orella amb audiòfon',
    '👃' => 'nas',
    '🧠' => 'cervell',
    '🫀' => 'cor',
    '🫁' => 'pulmons',
    '🦷' => 'dent',
    '🦴' => 'os',
    '👀' => 'ulls',
    '👁' => 'ull',
    '👅' => 'llengua',
    '👄' => 'boca',
    '🫦' => 'boca que es mossega el llavi',
    '👶' => 'nadó',
    '🧒' => 'criatura',
    '👦' => 'noi',
    '👧' => 'noia',
    '🧑' => 'persona',
    '👱' => 'persona: cabells rossos',
    '👨' => 'home',
    '🧔' => 'persona: barba',
    '👩' => 'dona',
    '🧓' => 'persona gran',
    '👴' => 'home gran',
    '👵' => 'dona gran',
    '🙍' => 'persona emmurriada',
    '🙎' => 'persona enutjada',
    '🙅' => 'gest de negació',
    '🙆' => 'gest d’aprovació',
    '💁' => 'persona amb mà inclinada cap amunt',
    '🙋' => 'persona amb la mà aixecada',
    '🧏' => 'persona sorda',
    '🙇' => 'persona capcota',
    '🤦' => 'persona amb la mà a la cara',
    '🤷' => 'persona que arronsa les espatlles',
    '👮' => 'agent de policia',
    '🕵' => 'detectiu',
    '💂' => 'guarda',
    '🥷' => 'ninja',
    '👷' => 'treballador de la construcció',
    '🫅' => 'persona amb corona',
    '🤴' => 'príncep',
    '👸' => 'princesa',
    '👳' => 'persona amb turbant',
    '👲' => 'home amb barret xinès',
    '🧕' => 'dona amb el cap cobert',
    '🤵' => 'persona amb esmòquing',
    '👰' => 'persona amb vel',
    '🤰' => 'dona embarassada',
    '🫃' => 'home embarassat',
    '🫄' => 'persona embarassada',
    '🤱' => 'dona que alleta',
    '👼' => 'angelet',
    '🎅' => 'pare Noel',
    '🤶' => 'mare Noel',
    '🦸' => 'superheroi',
    '🦹' => 'superdolent',
    '🧙' => 'mag',
    '🧚' => 'fada',
    '🧛' => 'vampir',
    '🧜' => 'persona sirena',
    '🧝' => 'elf',
    '🧞' => 'geni',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'criatura peluda',
    '💆' => 'persona que rep un massatge al cap',
    '💇' => 'persona que es talla els cabells',
    '🚶' => 'persona que camina',
    '🧍' => 'persona dreta',
    '🧎' => 'persona agenollada',
    '🏃' => 'persona que corre',
    '💃' => 'dona que balla',
    '🕺' => 'home que balla',
    '🕴' => 'home de negocis que levita',
    '👯' => 'persones que ballen disfressades',
    '🧖' => 'persona a la sauna',
    '🧗' => 'persona que escala',
    '🤺' => 'persona que fa esgrima',
    '🏇' => 'curses de cavalls',
    '⛷' => 'esquiador',
    '🏂' => 'surfista de neu',
    '🏌' => 'golfista',
    '🏄' => 'persona que fa surf',
    '🚣' => 'persona que rema en una barca',
    '🏊' => 'persona que neda',
    '⛹' => 'persona amb una pilota',
    '🏋' => 'persona que aixeca pesos',
    '🚴' => 'ciclista',
    '🚵' => 'ciclista de muntanya',
    '🤸' => 'persona que fa la roda',
    '🤼' => 'persones que lluiten',
    '🤽' => 'persona que juga a waterpolo',
    '🤾' => 'persona que juga a handbol',
    '🤹' => 'persona que fa malabars',
    '🧘' => 'persona en la posició de lotus',
    '🛀' => 'persona a la banyera',
    '🛌' => 'persona al llit',
    '👭' => 'dones que s’agafen de la mà',
    '👫' => 'home i dona que s’agafen de la mà',
    '👬' => 'homes que s’agafen de la mà',
    '💏' => 'petó',
    '💑' => 'parella amb un cor',
    '🗣' => 'persona que parla',
    '👤' => 'silueta d’un bust',
    '👥' => 'silueta de bustos',
    '🫂' => 'persones que s’abracen',
    '👪' => 'família',
    '👣' => 'petjades',
    '🫆' => 'empremta dactilar',
    '🦰' => 'cabells vermells',
    '🦱' => 'cabells arrissats',
    '🦳' => 'cabells blancs',
    '🦲' => 'calvície',
    '🐵' => 'cara de mona',
    '🐒' => 'mico',
    '🦍' => 'goril·la',
    '🦧' => 'orangutan',
    '🐶' => 'cara de gos',
    '🐕' => 'gos',
    '🦮' => 'gos pigall',
    '🐩' => 'caniche',
    '🐺' => 'llop',
    '🦊' => 'guineu',
    '🦝' => 'os rentador',
    '🐱' => 'cara de gat',
    '🐈' => 'gat',
    '🦁' => 'cara de lleó',
    '🐯' => 'cara de tigre',
    '🐅' => 'tigre',
    '🐆' => 'lleopard',
    '🐴' => 'cara de cavall',
    '🫎' => 'ant',
    '🫏' => 'ase',
    '🐎' => 'cavall',
    '🦄' => 'unicorn',
    '🦓' => 'zebra',
    '🦌' => 'cérvol',
    '🦬' => 'bisó',
    '🐮' => 'cara de vaca',
    '🐂' => 'bou',
    '🐃' => 'búfal aquàtic',
    '🐄' => 'vaca',
    '🐷' => 'cara de porc',
    '🐖' => 'porc',
    '🐗' => 'senglar',
    '🐽' => 'nas de porc',
    '🐏' => 'marrà',
    '🐑' => 'ovella',
    '🐐' => 'cabra',
    '🐪' => 'dromedari',
    '🐫' => 'camell',
    '🦙' => 'llama',
    '🦒' => 'girafa',
    '🐘' => 'elefant',
    '🦣' => 'mamut',
    '🦏' => 'rinoceront',
    '🦛' => 'hipopòtam',
    '🐭' => 'cara de ratolí',
    '🐁' => 'ratolí',
    '🐀' => 'rata',
    '🐹' => 'hàmster',
    '🐰' => 'cara de conill',
    '🐇' => 'conill',
    '🐿' => 'esquirol',
    '🦫' => 'castor',
    '🦔' => 'eriçó',
    '🦇' => 'ratapinyada',
    '🐻' => 'cara d’os',
    '🐨' => 'coala',
    '🐼' => 'panda',
    '🦥' => 'peresós',
    '🦦' => 'llúdria',
    '🦨' => 'mofeta',
    '🦘' => 'cangur',
    '🦡' => 'teixó',
    '🐾' => 'petjades d’animal',
    '🦃' => 'gall dindi',
    '🐔' => 'pollastre',
    '🐓' => 'gall',
    '🐣' => 'pollet que surt de l’ou',
    '🐤' => 'pollet de perfil',
    '🐥' => 'pollet de cara',
    '🐦' => 'ocell',
    '🐧' => 'pingüí',
    '🕊' => 'colom',
    '🦅' => 'àliga',
    '🦆' => 'ànec',
    '🦢' => 'cigne',
    '🦉' => 'mussol',
    '🦤' => 'dodo',
    '🪶' => 'ploma',
    '🦩' => 'flamenc',
    '🦚' => 'paó',
    '🦜' => 'lloro',
    '🪽' => 'ala',
    '🪿' => 'oca',
    '🐸' => 'granota',
    '🐊' => 'cocodril',
    '🐢' => 'tortuga',
    '🦎' => 'llangardaix',
    '🐍' => 'serp',
    '🐲' => 'cara de drac',
    '🐉' => 'drac',
    '🦕' => 'sauròpode',
    '🦖' => 'tiranosaure',
    '🐳' => 'balena que treu aigua',
    '🐋' => 'balena',
    '🐬' => 'dofí',
    '🫍' => 'orca',
    '🦭' => 'foca',
    '🐟' => 'peix',
    '🐠' => 'peix tropical',
    '🐡' => 'peix globus',
    '🦈' => 'tauró',
    '🐙' => 'pop',
    '🐚' => 'cargol de mar',
    '🪸' => 'corall',
    '🪼' => 'medusa',
    '🦀' => 'cranc',
    '🦞' => 'llagosta',
    '🦐' => 'gamba',
    '🦑' => 'calamar',
    '🦪' => 'ostra',
    '🐌' => 'cargol',
    '🦋' => 'papallona',
    '🐛' => 'eruga',
    '🐜' => 'formiga',
    '🐝' => 'abella',
    '🪲' => 'escarabat',
    '🐞' => 'marieta',
    '🦗' => 'grill',
    '🪳' => 'panerola',
    '🕷' => 'aranya',
    '🕸' => 'teranyina',
    '🦂' => 'escorpí',
    '🦟' => 'mosquit',
    '🪰' => 'mosca',
    '🪱' => 'cuc',
    '🦠' => 'microbi',
    '💐' => 'ram de flors',
    '🌸' => 'flor de cirerer',
    '💮' => 'flor blanca',
    '🪷' => 'lotus',
    '🏵' => 'roseta',
    '🌹' => 'rosa',
    '🥀' => 'rosa pansida',
    '🌺' => 'hibisc',
    '🌻' => 'gira-sol',
    '🌼' => 'flor',
    '🌷' => 'tulipa',
    '🪻' => 'jacint',
    '🌱' => 'brot',
    '🪴' => 'planta amb test',
    '🌲' => 'arbre de fulla perenne',
    '🌳' => 'arbre de fulla caduca',
    '🌴' => 'palmera',
    '🌵' => 'cactus',
    '🌾' => 'espiga d’arròs',
    '🌿' => 'herba',
    '☘' => 'trèvol',
    '🍀' => 'trèvol de quatre fulles',
    '🍁' => 'fulla d’auró',
    '🍂' => 'fulla seca',
    '🍃' => 'fulla que vola amb el vent',
    '🪹' => 'niu buit',
    '🪺' => 'niu amb ous',
    '🍄' => 'bolet',
    '🪾' => 'arbre sense fulles',
    '🍇' => 'raïm',
    '🍈' => 'meló',
    '🍉' => 'síndria',
    '🍊' => 'mandarina',
    '🍋' => 'llimona',
    '🍌' => 'plàtan',
    '🍍' => 'pinya',
    '🥭' => 'mango',
    '🍎' => 'poma vermella',
    '🍏' => 'poma verda',
    '🍐' => 'pera',
    '🍑' => 'préssec',
    '🍒' => 'cireres',
    '🍓' => 'maduixa',
    '🫐' => 'nabius',
    '🥝' => 'kiwi',
    '🍅' => 'tomàquet',
    '🫒' => 'oliva',
    '🥥' => 'coco',
    '🥑' => 'alvocat',
    '🍆' => 'albergínia',
    '🥔' => 'patata',
    '🥕' => 'pastanaga',
    '🌽' => 'panotxa',
    '🌶' => 'bitxo',
    '🫑' => 'pebrot verd',
    '🥒' => 'cogombre',
    '🥬' => 'fulla verda',
    '🥦' => 'bròcoli',
    '🧄' => 'all',
    '🧅' => 'ceba',
    '🥜' => 'cacauets',
    '🫘' => 'fesols',
    '🌰' => 'castanya',
    '🫚' => 'arrel de gingebre',
    '🫛' => 'beina de pèsol',
    '🫜' => 'tubercle',
    '🍞' => 'pa',
    '🥐' => 'croissant',
    '🥖' => 'baguet',
    '🫓' => 'pa de coca',
    '🥨' => 'brètzel',
    '🥯' => 'bagel',
    '🥞' => 'creps americanes',
    '🧇' => 'gofra',
    '🧀' => 'tall de formatge',
    '🍖' => 'carn amb os',
    '🍗' => 'cuixa de pollastre',
    '🥩' => 'tall de carn',
    '🥓' => 'bacó',
    '🍔' => 'hamburguesa',
    '🍟' => 'patates fregides',
    '🍕' => 'pizza',
    '🌭' => 'frankfurt',
    '🥪' => 'entrepà',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'durum',
    '🧆' => 'falàfel',
    '🥚' => 'ou',
    '🍳' => 'ou ferrat',
    '🥘' => 'paella',
    '🍲' => 'cassola de menjar',
    '🫕' => 'fondue',
    '🥣' => 'bol amb cullera',
    '🥗' => 'amanida',
    '🍿' => 'crispetes',
    '🧈' => 'mantega',
    '🧂' => 'sal',
    '🥫' => 'llauna de conserva',
    '🍱' => 'caixa de bento',
    '🍘' => 'galeta d’arròs',
    '🍙' => 'bola d’arròs',
    '🍚' => 'arròs bullit',
    '🍛' => 'arròs al curri',
    '🍜' => 'bol fumejant',
    '🍝' => 'espaguetis',
    '🍠' => 'moniato rostit',
    '🍢' => 'broqueta de marisc',
    '🍣' => 'sushi',
    '🍤' => 'gamba fregida',
    '🍥' => 'pastís de peix amb remolí',
    '🥮' => 'pastisset de lluna',
    '🍡' => 'broqueta dolça japonesa',
    '🥟' => 'cresta xinesa',
    '🥠' => 'galeta de la sort',
    '🥡' => 'menjar per emportar',
    '🍦' => 'gelat de màquina',
    '🍧' => 'granissat',
    '🍨' => 'gelat',
    '🍩' => 'dònut',
    '🍪' => 'galeta',
    '🎂' => 'pastís d’aniversari',
    '🍰' => 'porció de pastís',
    '🧁' => 'cupcake',
    '🥧' => 'coca',
    '🍫' => 'rajola de xocolata',
    '🍬' => 'caramel',
    '🍭' => 'piruleta',
    '🍮' => 'flam',
    '🍯' => 'pot de mel',
    '🍼' => 'biberó',
    '🥛' => 'got de llet',
    '☕' => 'beguda calenta',
    '🫖' => 'tetera',
    '🍵' => 'tassa de te',
    '🍶' => 'sake',
    '🍾' => 'ampolla de cava',
    '🍷' => 'copa de vi',
    '🍸' => 'copa de còctel',
    '🍹' => 'beguda tropical',
    '🍺' => 'gerra de cervesa',
    '🍻' => 'brindis amb gerra de cervesa',
    '🥂' => 'brindis',
    '🥃' => 'got de licor',
    '🫗' => 'got que aboca un líquid',
    '🥤' => 'got amb canya',
    '🧋' => 'te amb bombolles',
    '🧃' => 'bric',
    '🧉' => 'mate',
    '🧊' => 'glaçó',
    '🥢' => 'bastonets xinesos',
    '🍽' => 'forquilla, ganivet i plat',
    '🍴' => 'forquilla i ganivet',
    '🥄' => 'cullera',
    '🔪' => 'ganivet de cuina',
    '🫙' => 'pot',
    '🏺' => 'àmfora',
    '🌍' => 'globus terraqüi amb Europa i Àfrica',
    '🌎' => 'globus terraqüi amb Amèrica',
    '🌏' => 'globus terraqüi amb Àsia i Austràlia',
    '🌐' => 'globus terraqüi amb meridians',
    '🗺' => 'mapa del món',
    '🗾' => 'mapa del Japó',
    '🧭' => 'brúixola',
    '🏔' => 'muntanya amb neu al cim',
    '⛰' => 'muntanya',
    '🛘' => 'esllevissada',
    '🌋' => 'volcà',
    '🗻' => 'mont Fuji',
    '🏕' => 'acampada',
    '🏖' => 'platja amb para-sol',
    '🏜' => 'desert',
    '🏝' => 'illa deserta',
    '🏞' => 'parc nacional',
    '🏟' => 'estadi',
    '🏛' => 'edifici clàssic',
    '🏗' => 'construcció d’edificis',
    '🧱' => 'totxo',
    '🪨' => 'roca',
    '🪵' => 'llenya',
    '🛖' => 'cabana',
    '🏘' => 'cases',
    '🏚' => 'casa abandonada',
    '🏠' => 'casa',
    '🏡' => 'casa amb jardí',
    '🏢' => 'edifici d’oficines',
    '🏣' => 'oficina de correus japonesa',
    '🏤' => 'oficina de correus europea',
    '🏥' => 'hospital',
    '🏦' => 'banc',
    '🏨' => 'hotel',
    '🏩' => 'hotel de cites',
    '🏪' => 'botiga a l’abast',
    '🏫' => 'escola',
    '🏬' => 'centre comercial',
    '🏭' => 'fàbrica',
    '🏯' => 'castell japonès',
    '🏰' => 'castell',
    '💒' => 'casament',
    '🗼' => 'torre de Tòquio',
    '🗽' => 'estàtua de la Llibertat',
    '⛪' => 'església',
    '🕌' => 'mesquita',
    '🛕' => 'temple hindú',
    '🕍' => 'sinagoga',
    '⛩' => 'santuari xintoista',
    '🕋' => 'Ka’ba',
    '⛲' => 'font',
    '⛺' => 'tenda',
    '🌁' => 'paisatge emboirat',
    '🌃' => 'nit estrellada',
    '🏙' => 'paisatge urbà',
    '🌄' => 'alba sobre les muntanyes',
    '🌅' => 'alba',
    '🌆' => 'paisatge urbà al vespre',
    '🌇' => 'posta de sol',
    '🌉' => 'pont de nit',
    '♨' => 'fonts termals',
    '🎠' => 'cavallets',
    '🛝' => 'togoban',
    '🎡' => 'roda de fira',
    '🎢' => 'muntanya russa',
    '💈' => 'barberia',
    '🎪' => 'carpa de circ',
    '🚂' => 'locomotora',
    '🚃' => 'vagó de tren elèctric',
    '🚄' => 'tren d’alta velocitat',
    '🚅' => 'tren bala',
    '🚆' => 'tren',
    '🚇' => 'metro',
    '🚈' => 'tren lleuger',
    '🚉' => 'estació',
    '🚊' => 'tramvia',
    '🚝' => 'monocarril',
    '🚞' => 'ferrocarril de muntanya',
    '🚋' => 'vagó de tramvia',
    '🚌' => 'autobús',
    '🚍' => 'autobús que arriba',
    '🚎' => 'troleibús',
    '🚐' => 'microbús',
    '🚑' => 'ambulància',
    '🚒' => 'cotxe de bombers',
    '🚓' => 'cotxe de policia',
    '🚔' => 'cotxe de policia que arriba',
    '🚕' => 'taxi',
    '🚖' => 'taxi que arriba',
    '🚗' => 'automòbil',
    '🚘' => 'automòbil que arriba',
    '🚙' => 'vehicle tot camí',
    '🛻' => 'camioneta descoberta',
    '🚚' => 'camió de repartiment',
    '🚛' => 'camió articulat',
    '🚜' => 'tractor',
    '🏎' => 'cotxe de curses',
    '🏍' => 'motocicleta',
    '🛵' => 'escúter',
    '🦽' => 'cadira de rodes manual',
    '🦼' => 'cadira de rodes elèctrica',
    '🛺' => 'bicitaxi amb motor',
    '🚲' => 'bicicleta',
    '🛴' => 'patinet',
    '🛹' => 'monopatí',
    '🛼' => 'patí de rodes',
    '🚏' => 'parada d’autobús',
    '🛣' => 'autopista',
    '🛤' => 'via de tren',
    '🛢' => 'bidó de petroli',
    '⛽' => 'assortidor de gasolina',
    '🛞' => 'roda',
    '🚨' => 'llum de cotxe de policia',
    '🚥' => 'semàfor horitzontal',
    '🚦' => 'semàfor vertical',
    '🛑' => 'senyal d’estop',
    '🚧' => 'obres',
    '⚓' => 'àncora',
    '🛟' => 'salvavides',
    '⛵' => 'veler',
    '🛶' => 'canoa',
    '🚤' => 'llanxa ràpida',
    '🛳' => 'vaixell de passatgers',
    '⛴' => 'ferri',
    '🛥' => 'llanxa de motor',
    '🚢' => 'vaixell',
    '✈' => 'avió',
    '🛩' => 'avioneta',
    '🛫' => 'enlairament d’avió',
    '🛬' => 'aterratge d’avió',
    '🪂' => 'paracaigudes',
    '💺' => 'seient',
    '🚁' => 'helicòpter',
    '🚟' => 'ferrocarril de suspensió',
    '🚠' => 'telefèric de muntanya',
    '🚡' => 'telefèric',
    '🛰' => 'satèl·lit',
    '🚀' => 'coet',
    '🛸' => 'plat volador',
    '🛎' => 'timbre del grum',
    '🧳' => 'maleta',
    '⌛' => 'rellotge de sorra',
    '⏳' => 'rellotge amb sorra que cau',
    '⌚' => 'rellotge',
    '⏰' => 'despertador',
    '⏱' => 'cronòmetre',
    '⏲' => 'temporitzador',
    '🕰' => 'rellotge de taula',
    '🕛' => 'les dotze en punt',
    '🕧' => 'dos quarts d’una',
    '🕐' => 'la una en punt',
    '🕜' => 'dos quarts de dues',
    '🕑' => 'les dues en punt',
    '🕝' => 'dos quarts de tres',
    '🕒' => 'les tres en punt',
    '🕞' => 'dos quarts de quatre',
    '🕓' => 'les quatre en punt',
    '🕟' => 'dos quarts de cinc',
    '🕔' => 'les cinc en punt',
    '🕠' => 'dos quarts de sis',
    '🕕' => 'les sis en punt',
    '🕡' => 'dos quarts de set',
    '🕖' => 'les set en punt',
    '🕢' => 'dos quarts de vuit',
    '🕗' => 'les vuit en punt',
    '🕣' => 'dos quarts de nou',
    '🕘' => 'les nou en punt',
    '🕤' => 'dos quarts de deu',
    '🕙' => 'les deu en punt',
    '🕥' => 'dos quarts d’onze',
    '🕚' => 'les onze en punt',
    '🕦' => 'dos quarts de dotze',
    '🌑' => 'lluna nova',
    '🌒' => 'lluna en quart creixent',
    '🌓' => 'lluna en el primer quart creixent',
    '🌔' => 'lluna gibosa creixent',
    '🌕' => 'lluna plena',
    '🌖' => 'lluna gibosa minvant',
    '🌗' => 'lluna en l’últim quart minvant',
    '🌘' => 'lluna minvant',
    '🌙' => 'lluna creixent',
    '🌚' => 'cara de lluna nova',
    '🌛' => 'lluna en el primer quart amb cara',
    '🌜' => 'lluna en l’últim quart amb cara',
    '🌡' => 'termòmetre',
    '☀' => 'sol',
    '🌝' => 'lluna plena amb cara',
    '🌞' => 'sol amb cara',
    '🪐' => 'planeta amb anell',
    '⭐' => 'estrella',
    '🌟' => 'estrella brillant',
    '🌠' => 'estel fugaç',
    '🌌' => 'Via Làctia',
    '☁' => 'núvol',
    '⛅' => 'sol darrere un núvol',
    '⛈' => 'núvol amb llamp i pluja',
    '🌤' => 'sol darrere d’un núvol petit',
    '🌥' => 'sol darrere d’un núvol gran',
    '🌦' => 'sol darrere d’un núvol amb pluja',
    '🌧' => 'núvol amb pluja',
    '🌨' => 'núvol amb neu',
    '🌩' => 'núvol amb llamp',
    '🌪' => 'tornado',
    '🌫' => 'boira',
    '🌬' => 'vent',
    '🌀' => 'cicló',
    '🌈' => 'arc de Sant Martí',
    '🌂' => 'paraigua tancat',
    '☂' => 'paraigua',
    '☔' => 'paraigua amb gotes de pluja',
    '⛱' => 'para-sol a la sorra',
    '⚡' => 'alta tensió',
    '❄' => 'floc de neu',
    '☃' => 'ninot de neu',
    '⛄' => 'ninot de neu sense neu',
    '☄' => 'cometa',
    '🔥' => 'foc',
    '💧' => 'gota',
    '🌊' => 'onada',
    '🎃' => 'carabassa de Halloween',
    '🎄' => 'arbre de Nadal',
    '🎆' => 'focs d’artifici',
    '🎇' => 'bengala',
    '🧨' => 'petard',
    '✨' => 'espurnes',
    '🎈' => 'globus',
    '🎉' => 'tub de confeti',
    '🎊' => 'bola de confeti',
    '🎋' => 'arbre dels desitjos de Tanabata',
    '🎍' => 'decoració de pi',
    '🎎' => 'nines japoneses',
    '🎏' => 'banderins de carpes',
    '🎐' => 'campaneta de vent',
    '🎑' => 'cerimònia de la lluna',
    '🧧' => 'sobre vermell',
    '🎀' => 'llaç',
    '🎁' => 'regal embolicat',
    '🎗' => 'llaç commemoratiu',
    '🎟' => 'bitllet d’entrada',
    '🎫' => 'tiquet',
    '🎖' => 'medalla militar',
    '🏆' => 'trofeu',
    '🏅' => 'medalla esportiva',
    '🥇' => 'medalla d’or',
    '🥈' => 'medalla de plata',
    '🥉' => 'medalla de bronze',
    '⚽' => 'pilota de futbol',
    '⚾' => 'pilota de beisbol',
    '🥎' => 'pilota de softbol',
    '🏀' => 'pilota de bàsquet',
    '🏐' => 'pilota de voleibol',
    '🏈' => 'pilota de futbol americà',
    '🏉' => 'pilota de rugbi',
    '🎾' => 'tennis',
    '🥏' => 'disc volador',
    '🎳' => 'bitlles',
    '🏏' => 'criquet',
    '🏑' => 'hoquei sobre herba',
    '🏒' => 'hoquei sobre gel',
    '🥍' => 'lacrosse',
    '🏓' => 'tennis de taula',
    '🏸' => 'bàdminton',
    '🥊' => 'guant de boxa',
    '🥋' => 'quimono d’arts marcials',
    '🥅' => 'porteria',
    '⛳' => 'banderí al forat',
    '⛸' => 'patinatge sobre gel',
    '🎣' => 'canya de pescar',
    '🤿' => 'ulleres de busseig',
    '🎽' => 'samarreta per córrer',
    '🎿' => 'esquís',
    '🛷' => 'trineu',
    '🥌' => 'pedra de cúrling',
    '🎯' => 'dards',
    '🪀' => 'io-io',
    '🪁' => 'estel',
    '🔫' => 'pistola d’aigua',
    '🎱' => 'bola de billar',
    '🔮' => 'bola de vidre',
    '🪄' => 'vareta màgica',
    '🎮' => 'videojoc',
    '🕹' => 'palanca de control',
    '🎰' => 'màquina escurabutxaques',
    '🎲' => 'daus',
    '🧩' => 'peces de trencaclosques',
    '🧸' => 'os de peluix',
    '🪅' => 'pinyata',
    '🪩' => 'bola de miralls',
    '🪆' => 'nines russes',
    '♠' => 'pal de piques',
    '♥' => 'pal de cors',
    '♦' => 'pal de diamants',
    '♣' => 'pal de trèvols',
    '♟' => 'peó d’escacs',
    '🃏' => 'comodí',
    '🀄' => 'drac vermell de mahjong',
    '🎴' => 'cartes de les flors',
    '🎭' => 'arts interpretatives',
    '🖼' => 'quadre emmarcat',
    '🎨' => 'paleta d’artista',
    '🧵' => 'fil',
    '🪡' => 'agulla de cosir',
    '🧶' => 'llana',
    '🪢' => 'nus',
    '👓' => 'ulleres',
    '🕶' => 'ulleres de sol',
    '🥽' => 'ulleres de piscina',
    '🥼' => 'bata de laboratori',
    '🦺' => 'armilla salvavides',
    '👔' => 'corbata',
    '👕' => 'samarreta',
    '👖' => 'texans',
    '🧣' => 'bufanda',
    '🧤' => 'guants',
    '🧥' => 'abric',
    '🧦' => 'mitjons',
    '👗' => 'vestit',
    '👘' => 'quimono',
    '🥻' => 'sari',
    '🩱' => 'banyador',
    '🩲' => 'eslip',
    '🩳' => 'pantalons curts',
    '👙' => 'biquini',
    '👚' => 'roba de dona',
    '🪭' => 'ventall',
    '👛' => 'moneder',
    '👜' => 'bossa de mà',
    '👝' => 'bossa',
    '🛍' => 'bosses de compres',
    '🎒' => 'motxilla d’escola',
    '🩴' => 'xancleta de dit',
    '👞' => 'sabata d’home',
    '👟' => 'sabatilla de córrer',
    '🥾' => 'bota de muntanya',
    '🥿' => 'sabata plana',
    '👠' => 'sabata de taló',
    '👡' => 'sandàlia de dona',
    '🩰' => 'sabatilles de ballet',
    '👢' => 'bota de dona',
    '🪮' => 'pinta',
    '👑' => 'corona',
    '👒' => 'barret de dona',
    '🎩' => 'barret de copa',
    '🎓' => 'barret de graduació',
    '🧢' => 'gorra',
    '🪖' => 'casc militar',
    '⛑' => 'casc amb creu blanca',
    '📿' => 'rosari',
    '💄' => 'pintallavis',
    '💍' => 'anell',
    '💎' => 'gemma',
    '🔇' => 'altaveu desactivat',
    '🔈' => 'altaveu amb el volum baix',
    '🔉' => 'altaveu amb el volum mitjà',
    '🔊' => 'altaveu amb el volum alt',
    '📢' => 'altaveu de megafonia',
    '📣' => 'megàfon',
    '📯' => 'corn de posta',
    '🔔' => 'campana',
    '🔕' => 'campana silenciada',
    '🎼' => 'pentagrama',
    '🎵' => 'nota musical',
    '🎶' => 'notes musicals',
    '🎙' => 'micròfon d’estudi',
    '🎚' => 'control lliscant de nivell',
    '🎛' => 'botons de control',
    '🎤' => 'micròfon',
    '🎧' => 'auricular',
    '📻' => 'ràdio',
    '🎷' => 'saxofon',
    '🎺' => 'trompeta',
    '🪊' => 'trombó',
    '🪗' => 'acordió',
    '🎸' => 'guitarra',
    '🎹' => 'teclat musical',
    '🎻' => 'violí',
    '🪕' => 'banjo',
    '🥁' => 'tambor',
    '🪘' => 'conga',
    '🪇' => 'maraques',
    '🪈' => 'flauta',
    '🪉' => 'arpa',
    '📱' => 'telèfon mòbil',
    '📲' => 'telèfon mòbil amb fletxa',
    '☎' => 'telèfon',
    '📞' => 'auricular de telèfon',
    '📟' => 'buscapersones',
    '📠' => 'fax',
    '🔋' => 'bateria',
    '🪫' => 'bateria baixa',
    '🔌' => 'endoll',
    '💻' => 'ordinador portàtil',
    '🖥' => 'ordinador d’escriptori',
    '🖨' => 'impressora',
    '⌨' => 'teclat',
    '🖱' => 'ratolí d’ordinador',
    '🖲' => 'ratolí de bola',
    '💽' => 'minidisc',
    '💾' => 'disquet',
    '💿' => 'disc òptic',
    '📀' => 'DVD',
    '🧮' => 'àbac',
    '🎥' => 'càmera cinematogràfica',
    '🎞' => 'fotograma de pel·lícula',
    '📽' => 'projector cinematogràfic',
    '🎬' => 'claqueta',
    '📺' => 'televisió',
    '📷' => 'càmera',
    '📸' => 'càmera amb flaix',
    '📹' => 'càmera de vídeo',
    '📼' => 'videocasset',
    '🔍' => 'lupa cap a l’esquerra',
    '🔎' => 'lupa cap a la dreta',
    '🕯' => 'espelma',
    '💡' => 'bombeta',
    '🔦' => 'llanterna',
    '🏮' => 'fanal de paper vermell',
    '🪔' => 'llum d’oli',
    '📔' => 'quadern amb coberta decorativa',
    '📕' => 'llibre tancat',
    '📖' => 'llibre obert',
    '📗' => 'llibre verd',
    '📘' => 'llibre blau',
    '📙' => 'llibre taronja',
    '📚' => 'llibres',
    '📓' => 'llibreta',
    '📒' => 'llibre de comptabilitat',
    '📃' => 'pàgina que es cargola',
    '📜' => 'pergamí',
    '📄' => 'pàgina',
    '📰' => 'diari',
    '🗞' => 'diari enrotllat',
    '📑' => 'marcadors',
    '🔖' => 'punt de llibre',
    '🏷' => 'etiqueta',
    '🪙' => 'moneda',
    '💰' => 'bossa de diners',
    '🪎' => 'bagul del tresor',
    '💴' => 'bitllets de ien',
    '💵' => 'bitllets de dòlar',
    '💶' => 'bitllets d’euro',
    '💷' => 'bitllets de lliura',
    '💸' => 'diners amb ales',
    '💳' => 'targeta de crèdit',
    '🧾' => 'rebut',
    '💹' => 'gràfic d’augment amb el signe del ien',
    '✉' => 'sobre',
    '📧' => 'correu electrònic',
    '📨' => 'sobre que arriba',
    '📩' => 'sobre amb fletxa',
    '📤' => 'safata de sortida',
    '📥' => 'safata d’entrada',
    '📦' => 'paquet',
    '📫' => 'bústia tancada amb la bandera aixecada',
    '📪' => 'bústia tancada amb la bandera abaixada',
    '📬' => 'bústia plena amb la bandera aixecada',
    '📭' => 'bústia oberta amb la bandera abaixada',
    '📮' => 'bústia',
    '🗳' => 'urna amb vot',
    '✏' => 'llapis',
    '✒' => 'ploma negra',
    '🖋' => 'ploma estilogràfica',
    '🖊' => 'bolígraf',
    '🖌' => 'pinzell',
    '🖍' => 'llapis de color',
    '📝' => 'nota',
    '💼' => 'maletí',
    '📁' => 'carpeta de fitxers',
    '📂' => 'carpeta de fitxers oberta',
    '🗂' => 'separadors per a organitzador de targetes',
    '📅' => 'calendari',
    '📆' => 'calendari de bloc',
    '🗒' => 'bloc de notes d’espiral',
    '🗓' => 'calendari d’espiral',
    '📇' => 'organitzador de targetes',
    '📈' => 'gràfic d’augment',
    '📉' => 'gràfic de disminució',
    '📊' => 'gràfic de barres',
    '📋' => 'portanotes',
    '📌' => 'xinxeta',
    '📍' => 'xinxeta rodona',
    '📎' => 'clip',
    '🖇' => 'clips enganxats',
    '📏' => 'regle',
    '📐' => 'esquadra',
    '✂' => 'tisores',
    '🗃' => 'arxivador de targetes',
    '🗄' => 'arxivador',
    '🗑' => 'paperera',
    '🔒' => 'cadenat tancat',
    '🔓' => 'cadenat obert',
    '🔏' => 'cadenat amb ploma',
    '🔐' => 'cadenat tancat amb clau',
    '🔑' => 'clau',
    '🗝' => 'clau antiga',
    '🔨' => 'martell',
    '🪓' => 'destral',
    '⛏' => 'pic',
    '⚒' => 'martell i pic',
    '🛠' => 'martell i clau anglesa',
    '🗡' => 'daga',
    '⚔' => 'espases creuades',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'arc i fletxa',
    '🛡' => 'escut',
    '🪚' => 'xerrac',
    '🔧' => 'clau anglesa',
    '🪛' => 'tornavís',
    '🔩' => 'cargol i femella',
    '⚙' => 'engranatge',
    '🗜' => 'serjant',
    '⚖' => 'balança (aparell)',
    '🦯' => 'bastó per a invidents',
    '🔗' => 'enllaç',
    '⛓' => 'cadenes',
    '🪝' => 'ham',
    '🧰' => 'caixa d’eines',
    '🧲' => 'imant',
    '🪜' => 'escala de mà',
    '🪏' => 'pala',
    '⚗' => 'alambí',
    '🧪' => 'tub d’assaig',
    '🧫' => 'placa de Petri',
    '🧬' => 'adn',
    '🔬' => 'microscopi',
    '🔭' => 'telescopi',
    '📡' => 'antena de satèl·lit',
    '💉' => 'xeringa',
    '🩸' => 'gota de sang',
    '💊' => 'píndola',
    '🩹' => 'tireta',
    '🩼' => 'crossa',
    '🩺' => 'estetoscopi',
    '🩻' => 'radiografia',
    '🚪' => 'porta',
    '🛗' => 'ascensor',
    '🪞' => 'mirall',
    '🪟' => 'finestra',
    '🛏' => 'llit',
    '🛋' => 'sofà i làmpada',
    '🪑' => 'cadira',
    '🚽' => 'lavabo',
    '🪠' => 'desembossador',
    '🚿' => 'dutxa',
    '🛁' => 'banyera',
    '🪤' => 'ratera',
    '🪒' => 'maquineta d’afaitar',
    '🧴' => 'ampolla de crema',
    '🧷' => 'imperdible',
    '🧹' => 'escombra',
    '🧺' => 'cistella',
    '🧻' => 'rotlle de paper',
    '🪣' => 'cubell',
    '🧼' => 'sabó',
    '🫧' => 'bombolles',
    '🪥' => 'raspall de dents',
    '🧽' => 'esponja',
    '🧯' => 'extintor',
    '🛒' => 'carretó',
    '🚬' => 'cigarreta',
    '⚰' => 'taüt',
    '🪦' => 'làpida',
    '⚱' => 'urna funerària',
    '🧿' => 'nazar',
    '🪬' => 'mà de Fàtima',
    '🗿' => 'moai',
    '🪧' => 'pancarta',
    '🪪' => 'targeta d’identificació',
    '🏧' => 'signe de caixer automàtic',
    '🚮' => 'signe de paperera',
    '🚰' => 'aigua potable',
    '♿' => 'símbol de cadira de rodes',
    '🚹' => 'lavabo d’homes',
    '🚺' => 'lavabo de dones',
    '🚻' => 'lavabos',
    '🚼' => 'símbol de nadó',
    '🚾' => 'vàter',
    '🛂' => 'control de passaports',
    '🛃' => 'duana',
    '🛄' => 'recollida d’equipatges',
    '🛅' => 'consigna',
    '⚠' => 'advertència',
    '🚸' => 'nens que creuen',
    '⛔' => 'prohibit entrar',
    '🚫' => 'prohibit',
    '🚳' => 'bicicletes prohibides',
    '🚭' => 'prohibit fumar',
    '🚯' => 'prohibit llençar brossa',
    '🚱' => 'aigua no potable',
    '🚷' => 'prohibit el pas als vianants',
    '📵' => 'prohibits els telèfons mòbils',
    '🔞' => 'prohibit a menors d’edat',
    '☢' => 'radioactiu',
    '☣' => 'risc biològic',
    '⬆' => 'fletxa cap amunt',
    '↗' => 'fletxa cap amunt a la dreta',
    '➡' => 'fletxa cap a la dreta',
    '↘' => 'fletxa cap avall a la dreta',
    '⬇' => 'fletxa cap avall',
    '↙' => 'fletxa cap avall a l’esquerra',
    '⬅' => 'fletxa cap a l’esquerra',
    '↖' => 'fletxa cap amunt a l’esquerra',
    '↕' => 'fletxa cap amunt i cap avall',
    '↔' => 'fletxa cap a l’esquerra i cap a la dreta',
    '↩' => 'fletxa dreta que gira cap a l’esquerra',
    '↪' => 'fletxa esquerra que gira cap a la dreta',
    '⤴' => 'fletxa dreta que gira cap amunt',
    '⤵' => 'fletxa dreta que gira cap avall',
    '🔃' => 'fletxes que giren cap a la dreta',
    '🔄' => 'botó de fletxes que giren cap a l’esquerra',
    '🔙' => 'fletxa amb la paraula Back',
    '🔚' => 'fletxa amb la paraula End',
    '🔛' => 'fletxa amb la paraula ON!',
    '🔜' => 'fletxa amb la paraula Soon',
    '🔝' => 'fletxa amb la paraula Top',
    '🛐' => 'lloc de culte',
    '⚛' => 'símbol d’àtom',
    '🕉' => 'símbol d’om',
    '✡' => 'estrella de David',
    '☸' => 'roda del dharma',
    '☯' => 'yin-yang',
    '✝' => 'creu llatina',
    '☦' => 'creu ortodoxa',
    '☪' => 'creixent lunar i estel',
    '☮' => 'símbol de la pau',
    '🕎' => 'canelobre de set braços',
    '🔯' => 'estrella de sis puntes amb punt',
    '🪯' => 'khanda',
    '♈' => 'Àries',
    '♉' => 'Taure',
    '♊' => 'Bessons',
    '♋' => 'Càncer',
    '♌' => 'Lleó',
    '♍' => 'Verge',
    '♎' => 'Balança',
    '♏' => 'Escorpió',
    '♐' => 'Sagitari',
    '♑' => 'Capricorn',
    '♒' => 'Aquari',
    '♓' => 'Peixos',
    '⛎' => 'Ofiüc',
    '🔀' => 'botó de reproducció aleatòria',
    '🔁' => 'botó de repetició',
    '🔂' => 'botó de repetició única',
    '▶' => 'botó de reproducció',
    '⏩' => 'botó d’avançar ràpidament',
    '⏭' => 'botó de pista següent',
    '⏯' => 'botó de pausa o de reproducció',
    '◀' => 'botó de retrocedir',
    '⏪' => 'botó de retrocedir ràpidament',
    '⏮' => 'botó de pista anterior',
    '🔼' => 'botó d’anar amunt',
    '⏫' => 'botó d’anar amunt ràpidament',
    '🔽' => 'botó d’anar avall',
    '⏬' => 'botó d’anar avall ràpidament',
    '⏸' => 'botó de pausa',
    '⏹' => 'botó d’aturada',
    '⏺' => 'botó d’enregistrar',
    '⏏' => 'botó d’expulsar',
    '🎦' => 'cinema',
    '🔅' => 'botó d’atenuar la brillantor',
    '🔆' => 'botó d’augmentar la brillantor',
    '📶' => 'barres de cobertura',
    '🛜' => 'sense fil',
    '📳' => 'mode de vibració',
    '📴' => 'telèfon mòbil desactivat',
    '♀' => 'símbol femení',
    '♂' => 'símbol masculí',
    '⚧' => 'símbol transgènere',
    '✖' => 'signe de multiplicar',
    '➕' => 'signe de sumar',
    '➖' => 'signe de restar',
    '➗' => 'signe de dividir',
    '🟰' => 'signe d’igual gran',
    '♾' => 'infinit',
    '‼' => 'signe d’exclamació doble',
    '⁉' => 'signe d’exclamació i d’interrogació',
    '❓' => 'signe d’interrogació vermell',
    '❔' => 'signe d’interrogació blanc',
    '❕' => 'signe d’exclamació blanc',
    '❗' => 'signe d’exclamació vermell',
    '〰' => 'guió ondulat',
    '💱' => 'canvi de divisa',
    '💲' => 'signe de dòlar gran',
    '⚕' => 'símbol mèdic',
    '♻' => 'símbol de reciclatge',
    '⚜' => 'flor de lis',
    '🔱' => 'marca de trident',
    '📛' => 'etiqueta identificadora',
    '🔰' => 'símbol japonès de principiant',
    '⭕' => 'cercle buit vermell',
    '✅' => 'botó de marca de verificació',
    '☑' => 'casella amb marca de verificació',
    '✔' => 'marca de verificació',
    '❌' => 'marca de creu',
    '❎' => 'botó de creu',
    '➰' => 'llaç arrissat',
    '➿' => 'bucle doble',
    '〽' => 'signe d’alternança',
    '✳' => 'asterisc de vuit radis',
    '✴' => 'estrella de vuit puntes',
    '❇' => 'espurna',
    '™' => 'marca comercial',
    '🫟' => 'esquitx',
    '🔠' => 'botó de lletres llatines en majúscules',
    '🔡' => 'botó de lletres llatines en minúscules',
    '🔢' => 'botó de números',
    '🔣' => 'botó de símbols',
    '🔤' => 'botó de lletres llatines',
    '🅰' => 'botó A (grup sanguini)',
    '🆎' => 'botó AB (grup sanguini)',
    '🅱' => 'botó B (grup sanguini)',
    '🆑' => 'botó CL',
    '🆒' => 'botó COOL',
    '🆓' => 'botó FREE',
    'ℹ' => 'informació',
    '🆔' => 'botó ID',
    'Ⓜ' => 'lletra M en cercle',
    '🆕' => 'botó NEW',
    '🆖' => 'botó NG',
    '🅾' => 'botó O (grup sanguini)',
    '🆗' => 'botó OK',
    '🅿' => 'botó P',
    '🆘' => 'botó SOS',
    '🆙' => 'botó amb la paraula Up!',
    '🆚' => 'botó VS',
    '🈁' => 'botó japonès "aquí"',
    '🈂' => 'botó japonès "càrrec per servei"',
    '🈷' => 'botó japonès "import mensual"',
    '🈶' => 'botó japonès "de pagament"',
    '🈯' => 'botó japonès "reservat"',
    '🉐' => 'botó japonès "ganga"',
    '🈹' => 'botó japonès "descompte"',
    '🈚' => 'botó japonès "gratis"',
    '🈲' => 'botó japonès "prohibit"',
    '🉑' => 'botó japonès "acceptable"',
    '🈸' => 'botó japonès "aplicació"',
    '🈴' => 'botó japonès "qualificació d’aprovat"',
    '🈳' => 'botó japonès "plaça lliure"',
    '㊗' => 'botó japonès "enhorabona"',
    '㊙' => 'botó japonès "secret"',
    '🈺' => 'botó japonès "negoci obert"',
    '🈵' => 'botó japonès "cap plaça lliure"',
    '🔴' => 'cercle vermell',
    '🟠' => 'cercle taronja',
    '🟡' => 'cercle groc',
    '🟢' => 'cercle verd',
    '🔵' => 'cercle blau',
    '🟣' => 'cercle lila',
    '🟤' => 'cercle marró',
    '⚫' => 'cercle negre',
    '⚪' => 'cercle blanc',
    '🟥' => 'quadrat vermell',
    '🟧' => 'quadrat taronja',
    '🟨' => 'quadrat groc',
    '🟩' => 'quadrat verd',
    '🟦' => 'quadrat blau',
    '🟪' => 'quadrat lila',
    '🟫' => 'quadrat marró',
    '⬛' => 'quadrat gran negre',
    '⬜' => 'quadrat gran blanc',
    '◼' => 'quadrat mitjà negre',
    '◻' => 'quadrat mitjà blanc',
    '◾' => 'quadrat negre petit-mitjà',
    '◽' => 'quadrat blanc petit-mitjà',
    '▪' => 'quadrat negre petit',
    '▫' => 'quadrat blanc petit',
    '🔶' => 'rombe gran taronja',
    '🔷' => 'rombe gran blau',
    '🔸' => 'rombe petit taronja',
    '🔹' => 'rombe petit blau',
    '🔺' => 'triangle vermell cap amunt',
    '🔻' => 'triangle vermell cap avall',
    '💠' => 'rombe amb punt',
    '🔘' => 'botó d’opció',
    '🔳' => 'botó de quadrat blanc',
    '🔲' => 'botó de quadrat negre',
    '🏁' => 'bandera de quadres',
    '🚩' => 'bandera triangular',
    '🎌' => 'banderes creuades',
    '🏴' => 'bandera negra',
    '🏳' => 'bandera blanca',
];
